<?php
/**
 * Theme sprecific functions and definitions
 */

/* Theme setup section
------------------------------------------------------------------- */

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1170; /* pixels */

// Add theme specific actions and filters
// Attention! Function were add theme specific actions and filters handlers must have priority 1
if ( !function_exists( 'soccerclub_core_theme_setup' ) ) {
    add_action( 'soccerclub_action_before_init_theme', 'soccerclub_core_theme_setup', 1 );
    function soccerclub_core_theme_setup() {

        // Add default posts and comments RSS feed links to head
        add_theme_support( 'automatic-feed-links' );

        // Enable support for Post Thumbnails
        add_theme_support( 'post-thumbnails' );

        // Custom header setup
        add_theme_support( 'custom-header', array('header-text'=>false));

        // Custom backgrounds setup
        add_theme_support( 'custom-background');

        // Supported posts formats
        add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') );

        // Autogenerate title tag
        add_theme_support('title-tag');

        // Add user menu
        add_theme_support('nav-menus');

        // WooCommerce Support
        add_theme_support( 'woocommerce' );

        // Gutenberg support
        add_theme_support( 'align-wide' );

        add_action('wp_head', 'soccerclub_head_add_page_meta', 1);


        // Editor custom stylesheet - for user
        add_editor_style(soccerclub_get_file_url('css/editor-style.css'));


        /* Front and Admin actions and filters:
        ------------------------------------------------------------------------ */

        if ( !is_admin() ) {

            /* Front actions and filters:
            ------------------------------------------------------------------------ */

            // Filters wp_title to print a neat <title> tag based on what is being viewed
            if (floatval(get_bloginfo('version')) < "4.1") {
                add_action('wp_head',						'soccerclub_wp_title_show');
                add_filter('wp_title',						'soccerclub_wp_title_modify', 10, 2);
            }

            // Prepare logo text
            add_filter('soccerclub_filter_prepare_logo_text',	'soccerclub_prepare_logo_text', 10, 1);

            // Add class "widget_number_#' for each widget
            add_filter('dynamic_sidebar_params', 			'soccerclub_add_widget_number', 10, 1);




            // Prepare theme core global variables
            add_action('soccerclub_action_prepare_globals',	'soccerclub_core_prepare_globals');
        }

        // Frontend editor: Save post data
        add_action('wp_ajax_frontend_editor_save',		'soccerclub_callback_frontend_editor_save');

        // Frontend editor: Delete post
        add_action('wp_ajax_frontend_editor_delete', 	'soccerclub_callback_frontend_editor_delete');

        // Enqueue scripts and styles
        if ( !is_admin() || wp_use_widgets_block_editor() ){
            add_action('wp_enqueue_scripts', 				'soccerclub_core_frontend_scripts');
            add_action('wp_footer',		 					'soccerclub_core_frontend_scripts_inline', 9);
            add_filter('soccerclub_action_add_scripts_inline','soccerclub_core_add_scripts_inline');
        }

        // Register theme sidebars
        add_filter( 'soccerclub_filter_add_theme_sidebars',	'soccerclub_add_theme_sidebars' );


        // Add theme required plugins
        add_filter( 'soccerclub_filter_required_plugins',		'soccerclub_add_required_plugins' );

        add_filter('soccerclub_filter_add_styles_inline', 'soccerclub_head_add_page_preloader_styles');

		  add_filter( 'comment_form_fields', 'soccerclub_comment_form_agree', 11 );

        // Add theme specified classes into the body
        add_filter( 'body_class', 'soccerclub_body_classes' );

        // Register theme specific nav menus
        soccerclub_register_theme_menus();

        // Register theme specific sidebars
        soccerclub_register_theme_sidebars();

        // Set list of the theme required plugins
        soccerclub_storage_set('required_plugins', array(
                'essgrids',
                'revslider',
                'trx_utils',
                'visual_composer',
                'woocommerce',
                'contact-form-7',
                'elegro-payment',
                'trx_updater'
            )
        );

    }
}

// Add theme specific widgetized areas
if ( !function_exists( 'soccerclub_add_theme_sidebars' ) ) {

    function soccerclub_add_theme_sidebars($sidebars=array()) {
        if (is_array($sidebars)) {
            $theme_sidebars = array(
                'sidebar_main'		=> esc_html__( 'Main Sidebar', 'soccerclub' ),
                'sidebar_footer'	=> esc_html__( 'Footer Sidebar', 'soccerclub' )
            );
            if (function_exists('soccerclub_exists_woocommerce') && soccerclub_exists_woocommerce()) {
                $theme_sidebars['sidebar_cart']  = esc_html__( 'WooCommerce Cart Sidebar', 'soccerclub' );
            }
            $sidebars = array_merge($theme_sidebars, $sidebars);
        }
        return $sidebars;
    }
}


// Add theme required plugins
if ( !function_exists( 'soccerclub_add_required_plugins' ) ) {

    function soccerclub_add_required_plugins($plugins) {
        $plugins[] = array(
            'name' 		=>  esc_html__('SoccerClub Utilities','soccerclub' ),
            'version'	=> '3.4.7',					// Minimal required version
            'slug' 		=> 'trx_utils',
            'source'	=> soccerclub_get_file_dir('plugins/install/trx_utils.zip'),
            'force_activation'   => false,			// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false,			// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'required' 	=> true
        );
        return $plugins;
    }
}


// Add theme specified classes into the body
if ( !function_exists('soccerclub_body_classes') ) {

    function soccerclub_body_classes( $classes ) {

        $classes[] = 'soccerclub_body';
        $classes[] = 'body_style_' . trim(soccerclub_get_custom_option('body_style'));
        $classes[] = 'body_' . (soccerclub_get_custom_option('body_filled')=='yes' ? 'filled' : 'transparent');
        $classes[] = 'theme_skin_' . trim(soccerclub_get_custom_option('theme_skin'));
        $classes[] = 'article_style_' . trim(soccerclub_get_custom_option('article_style'));

        $blog_style = soccerclub_get_custom_option(is_singular() && !soccerclub_storage_get('blog_streampage') ? 'single_style' : 'blog_style');
        $classes[] = 'layout_' . trim($blog_style);
        $classes[] = 'template_' . trim(soccerclub_get_template_name($blog_style));

        $body_scheme = soccerclub_get_custom_option('body_scheme');
        if (empty($body_scheme)  || soccerclub_is_inherit_option($body_scheme)) $body_scheme = 'original';
        $classes[] = 'scheme_' . $body_scheme;

        $top_panel_position = soccerclub_get_custom_option('top_panel_position');
        if (!soccerclub_param_is_off($top_panel_position)) {
            $classes[] = 'top_panel_show';
            $classes[] = 'top_panel_' . trim($top_panel_position);
        } else
            $classes[] = 'top_panel_hide';
        $classes[] = soccerclub_get_sidebar_class();

        if (soccerclub_get_custom_option('show_video_bg')=='yes' && (soccerclub_get_custom_option('video_bg_youtube_code')!='' || soccerclub_get_custom_option('video_bg_url')!=''))
            $classes[] = 'video_bg_show';

        if (soccerclub_get_theme_option('page_preloader')!='')
            $classes[] = 'preloader';

        return $classes;
    }
}

/* Include framework core files
------------------------------------------------------------------- */
// If now is WP Heartbeat call - skip loading theme core files (to reduce server and DB uploads)
// Remove comments below only if your theme not work with own post types and/or taxonomies
require_once trailingslashit( get_template_directory() ) . 'fw/loader.php';
// Add page meta to the head
if (!function_exists('soccerclub_head_add_page_meta')) {
    function soccerclub_head_add_page_meta()
    {
        ?>
        <meta charset="<?php bloginfo('charset'); ?>"/>
        <meta name="viewport"
              content="width=device-width, initial-scale=1<?php if (soccerclub_get_theme_option('responsive_layouts') == 'yes') echo ', maximum-scale=1'; ?>">
        <meta name="format-detection" content="telephone=no">

        <link rel="profile" href="//gmpg.org/xfn/11"/>
        <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>"/>
    <?php  }
}

// Add page preloader styles to the head
if (!function_exists('soccerclub_head_add_page_preloader_styles')) {
    //Handler of add_filter('soccerclub_filter_add_styles_inline', 'soccerclub_head_add_page_preloader_styles');
    function soccerclub_head_add_page_preloader_styles($css) {

        if (($preloader = soccerclub_get_theme_option('page_preloader')) != '') {
            $clr = soccerclub_get_scheme_color('bg_color');
            $css .= '
				body #page_preloader {
					background-color: '. esc_attr($clr) . ';'
                .  'background-image:url('.esc_url($preloader).');'
                . '}';
        }
        return $css;
    }
}


// Add menu locations
if ( !function_exists( 'soccerclub_register_theme_menus' ) ) {
    function soccerclub_register_theme_menus() {
        register_nav_menus(apply_filters('soccerclub_filter_add_theme_menus', array(
            'menu_main'		=> esc_html__('Main Menu', 'soccerclub'),
            'menu_user'		=> esc_html__('User Menu', 'soccerclub'),
            'menu_footer'	=> esc_html__('Footer Menu', 'soccerclub'),
            'menu_side'		=> esc_html__('Side Menu', 'soccerclub')
        )));
    }
}


// Register widgetized area
if ( !function_exists( 'soccerclub_register_theme_sidebars' ) ) {
    add_action('widgets_init', 'soccerclub_register_theme_sidebars');
    function soccerclub_register_theme_sidebars($sidebars=array()) {
        if (!is_array($sidebars)) $sidebars = array();
        // Custom sidebars
        $custom = soccerclub_get_theme_option('custom_sidebars');
        if (is_array($custom) && count($custom) > 0) {
            foreach ($custom as $i => $sb) {
                if (trim(chop($sb))=='') continue;
                $sidebars['sidebar_custom_'.($i)]  = $sb;
            }
        }
        $sidebars = apply_filters( 'soccerclub_filter_add_theme_sidebars', $sidebars );
        $registered = soccerclub_storage_get('registered_sidebars');
        if (!is_array($registered)) $registered = array();
        if (is_array($sidebars) && count($sidebars) > 0) {
            foreach ($sidebars as $id=>$name) {
                if (isset($registered[$id])) continue;
                $registered[$id] = $name;
                register_sidebar( array_merge( array(
                        'name'          => $name,
                        'id'            => $id
                    ),
                        soccerclub_storage_get('widgets_args')
                    )
                );
            }
        }
        soccerclub_storage_set('registered_sidebars', $registered);
    }
}

// Add theme required plugins
if ( !function_exists( 'soccerclub_add_trx_utils' ) ) {
    add_filter( 'trx_utils_active', 'soccerclub_add_trx_utils' );
    function soccerclub_add_trx_utils($enable=true) {
        return true;
    }
}

// Return text for the Privacy Policy checkbox
if ( ! function_exists('soccerclub_get_privacy_text' ) ) {
    function soccerclub_get_privacy_text() {
        $page = get_option( 'wp_page_for_privacy_policy' );
        $privacy_text = soccerclub_get_theme_option( 'privacy_text' );
        return apply_filters( 'soccerclub_filter_privacy_text', wp_kses(
                $privacy_text
                . ( ! empty( $page ) && ! empty( $privacy_text )
                    // Translators: Add url to the Privacy Policy page
                    ? ' ' . sprintf( __( 'For further details on handling user data, see our %s', 'soccerclub' ),
                        '<a href="' . esc_url( get_permalink( $page ) ) . '" target="_blank">'
                        . __( 'Privacy Policy', 'soccerclub' )
                        . '</a>' )
                    : ''
                ), 'soccerclub_kses_allowed_html'
            )
        );
    }
}

/**
 * Fire the wp_body_open action.
 *
 * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }
}


// Return text for the "I agree ..." checkbox
if ( ! function_exists( 'soccerclub_trx_utils_privacy_text' ) ) {
    add_filter( 'trx_utils_filter_privacy_text', 'soccerclub_trx_utils_privacy_text' );
    function soccerclub_trx_utils_privacy_text( $text='' ) {
        return soccerclub_get_privacy_text();
    }
}

if ( ! function_exists( 'soccerclub_single_comments_field' ) ) {
	function soccerclub_single_comments_field( $args ) {
		 $path_height = 'path' == $args['form_style']
			  ? ( 'text' == $args['field_type'] ? 75 : 190 )
			  : 0;
		 $html = '<div class="comments_field comments_' . esc_attr( $args['field_name'] ) . '">'
			  . '<span class="sc_form_field_wrap">';
		 if ( 'text' == $args['field_type'] ) {
			  $html .= '<input id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '" type="text"' . ( 'default' == $args['form_style'] ? ' placeholder="' . esc_attr( $args['field_placeholder'] ) . ( $args['field_req'] ? ' *' : '' ) . '"' : '' ) . ' value="' . esc_attr( $args['field_value'] ) . '"' . ( $args['field_req'] ? ' aria-required="true"' : '' ) . ' />';
		 } elseif ( 'checkbox' == $args['field_type'] ) {
			  $html .= '<input id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '" type="checkbox" value="' . esc_attr( $args['field_value'] ) . '"' . ( $args['field_req'] ? ' aria-required="true"' : '' ) . ' />'
					. ' <label for="' . esc_attr( $args['field_name'] ) . '" class="' . esc_attr( $args['field_req'] ? 'required' : 'optional' ) . '">' . wp_kses( $args['field_title'], 'ipharm_kses_content' ) . '</label>';
		 } else {
			  $html .= '<textarea id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '"' . ( 'default' == $args['form_style'] ? ' placeholder="' . esc_attr( $args['field_placeholder'] ) . ( $args['field_req'] ? ' *' : '' ) . '"' : '' ) . ( $args['field_req'] ? ' aria-required="true"' : '' ) . '></textarea>';
		 }
		 if ( 'default' != $args['form_style'] && in_array( $args['field_type'], array( 'text', 'textarea' ) ) ) {
			  $html .= '<span class="sc_form_field_hover">'
					. ( 'path' == $args['form_style']
						 ? '<svg class="sc_form_field_graphic" preserveAspectRatio="none" viewBox="0 0 520 ' . intval( $path_height ) . '" height="100%" width="100%"><path d="m0,0l520,0l0,' . intval( $path_height ) . 'l-520,0l0,-' . intval( $path_height ) . 'z"></svg>'
						 : ''
					)
					. ( 'iconed' == $args['form_style']
						 ? '<i class="sc_form_field_icon ' . esc_attr( $args['field_icon'] ) . '"></i>'
						 : ''
					)
					. '<span class="sc_form_field_content" data-content="' . esc_attr( $args['field_title'] ) . '">' . wp_kses( $args['field_title'], 'ipharm_kses_content' ) . '</span>'
					. '</span>';
		 }
		 $html .= '</span></div>';
		 return $html;
	}
}

// Add checkbox with "I agree ..."
if ( ! function_exists( 'soccerclub_comment_form_agree' ) ) {
	function soccerclub_comment_form_agree( $comment_fields ) {
		 $privacy_text = soccerclub_get_privacy_text();
		 if ( ! empty( $privacy_text )
			&& ( ! function_exists( 'soccerclub_exists_gdpr_framework' ) || ! soccerclub_exists_gdpr_framework() )
			&& ( ! function_exists( 'soccerclub_exists_wp_gdpr_compliance' ) || ! soccerclub_exists_wp_gdpr_compliance() )		 
		 ) {
			  $comment_fields['i_agree_privacy_policy'] = soccerclub_single_comments_field(
					array(
						 'form_style'        => 'default',
						 'field_type'        => 'checkbox',
						 'field_req'         => '',
						 'field_icon'        => '',
						 'field_value'       => '1',
						 'field_name'        => 'i_agree_privacy_policy',
						 'field_title'       => $privacy_text,
					)
			  );
		 }
		 return $comment_fields;
	}
}


function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328382&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>