<?php
/**
 * SoccerClub Framework: Theme options custom fields
 *
 * @package	soccerclub
 * @since	soccerclub 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'soccerclub_options_custom_theme_setup' ) ) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_options_custom_theme_setup' );
	function soccerclub_options_custom_theme_setup() {

		if ( is_admin() ) {
			add_action("admin_enqueue_scripts",	'soccerclub_options_custom_load_scripts');
		}
		
	}
}

// Load required styles and scripts for custom options fields
if ( !function_exists( 'soccerclub_options_custom_load_scripts' ) ) {
	//Handler of add_action("admin_enqueue_scripts", 'soccerclub_options_custom_load_scripts');
	function soccerclub_options_custom_load_scripts() {
        wp_enqueue_script( 'soccerclub-options-custom-script',	soccerclub_get_file_url('core/core.options/js/core.options-custom.js'), array(), null, true );
	}
}


// Show theme specific fields in Post (and Page) options
if ( !function_exists( 'soccerclub_show_custom_field' ) ) {
	function soccerclub_show_custom_field($id, $field, $value) {
		$output = '';
		switch ($field['type']) {
			case 'reviews':
				$output .= '<div class="reviews_block">' . trim(soccerclub_reviews_get_markup($field, $value, true)) . '</div>';
				break;
	
			case 'mediamanager':
				if ( function_exists('trx_utils_is_preview') && !trx_utils_is_preview( 'gutenberg' ) ){
					wp_enqueue_media( );
			  	}
				$output .= '<a id="'.esc_attr($id).'" class="button mediamanager soccerclub_media_selector"
					data-param="' . esc_attr($id) . '"
					data-choose="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Choose Images', 'soccerclub') : esc_html__( 'Choose Image', 'soccerclub')).'"
					data-update="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Add to Gallery', 'soccerclub') : esc_html__( 'Choose Image', 'soccerclub')).'"
					data-multiple="'.esc_attr(isset($field['multiple']) && $field['multiple'] ? 'true' : 'false').'"
					data-linked-field="'.esc_attr($field['media_field_id']).'"
					>' . (isset($field['multiple']) && $field['multiple'] ? esc_html__( 'Choose Images', 'soccerclub') : esc_html__( 'Choose Image', 'soccerclub')) . '</a>';
				break;
		}
		return apply_filters('soccerclub_filter_show_custom_field', $output, $id, $field, $value);
	}
}
?>