<?php
/**
 * SoccerClub Framework: strings manipulations
 *
 * @package	soccerclub
 * @since	soccerclub 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Check multibyte functions
if ( ! defined( 'SOCCERCLUB_MULTIBYTE' ) ) define( 'SOCCERCLUB_MULTIBYTE', function_exists('mb_strpos') ? 'UTF-8' : false );

if (!function_exists('soccerclub_strlen')) {
	function soccerclub_strlen($text) {
		return SOCCERCLUB_MULTIBYTE ? mb_strlen($text) : strlen($text);
	}
}

if (!function_exists('soccerclub_strpos')) {
	function soccerclub_strpos($text, $char, $from=0) {
		return SOCCERCLUB_MULTIBYTE ? mb_strpos($text, $char, $from) : strpos($text, $char, $from);
	}
}

if (!function_exists('soccerclub_strrpos')) {
	function soccerclub_strrpos($text, $char, $from=0) {
		return SOCCERCLUB_MULTIBYTE ? mb_strrpos($text, $char, $from) : strrpos($text, $char, $from);
	}
}

if (!function_exists('soccerclub_substr')) {
	function soccerclub_substr($text, $from, $len=-999999) {
		if ($len==-999999) { 
			if ($from < 0)
				$len = -$from; 
			else
				$len = soccerclub_strlen($text)-$from;
		}
		return SOCCERCLUB_MULTIBYTE ? mb_substr($text, $from, $len) : substr($text, $from, $len);
	}
}

if (!function_exists('soccerclub_strtolower')) {
	function soccerclub_strtolower($text) {
		return SOCCERCLUB_MULTIBYTE ? mb_strtolower($text) : strtolower($text);
	}
}

if (!function_exists('soccerclub_strtoupper')) {
	function soccerclub_strtoupper($text) {
		return SOCCERCLUB_MULTIBYTE ? mb_strtoupper($text) : strtoupper($text);
	}
}

if (!function_exists('soccerclub_strtoproper')) {
	function soccerclub_strtoproper($text) { 
		$rez = ''; $last = ' ';
		for ($i=0; $i<soccerclub_strlen($text); $i++) {
			$ch = soccerclub_substr($text, $i, 1);
			$rez .= soccerclub_strpos(' .,:;?!()[]{}+=', $last)!==false ? soccerclub_strtoupper($ch) : soccerclub_strtolower($ch);
			$last = $ch;
		}
		return $rez;
	}
}

if (!function_exists('soccerclub_strrepeat')) {
	function soccerclub_strrepeat($str, $n) {
		$rez = '';
		for ($i=0; $i<$n; $i++)
			$rez .= $str;
		return $rez;
	}
}

if (!function_exists('soccerclub_strshort')) {
	function soccerclub_strshort($str, $maxlength, $add='...') {
		if ($maxlength < 0) 
			return $str;
		if ($maxlength == 0) 
			return '';
		if ($maxlength >= soccerclub_strlen($str)) 
			return strip_tags($str);
		$str = soccerclub_substr(strip_tags($str), 0, $maxlength - soccerclub_strlen($add));
		$ch = soccerclub_substr($str, $maxlength - soccerclub_strlen($add), 1);
		if ($ch != ' ') {
			for ($i = soccerclub_strlen($str) - 1; $i > 0; $i--)
				if (soccerclub_substr($str, $i, 1) == ' ') break;
			$str = trim(soccerclub_substr($str, 0, $i));
		}
		if (!empty($str) && soccerclub_strpos(',.:;-', soccerclub_substr($str, -1))!==false) $str = soccerclub_substr($str, 0, -1);
		return ($str) . ($add);
	}
}

// Clear string from spaces, line breaks and tags (only around text)
if (!function_exists('soccerclub_strclear')) {
	function soccerclub_strclear($text, $tags=array()) {
		if (empty($text)) return $text;
		if (!is_array($tags)) {
			if ($tags != '')
				$tags = explode($tags, ',');
			else
				$tags = array();
		}
		$text = trim(chop($text));
		if (is_array($tags) && count($tags) > 0) {
			foreach ($tags as $tag) {
				$open  = '<'.esc_attr($tag);
				$close = '</'.esc_attr($tag).'>';
				if (soccerclub_substr($text, 0, soccerclub_strlen($open))==$open) {
					$pos = soccerclub_strpos($text, '>');
					if ($pos!==false) $text = soccerclub_substr($text, $pos+1);
				}
				if (soccerclub_substr($text, -soccerclub_strlen($close))==$close) $text = soccerclub_substr($text, 0, soccerclub_strlen($text) - soccerclub_strlen($close));
				$text = trim(chop($text));
			}
		}
		return $text;
	}
}

// Return slug for the any title string
if (!function_exists('soccerclub_get_slug')) {
	function soccerclub_get_slug($title) {
		return soccerclub_strtolower(str_replace(array('\\','/','-',' ','.'), '_', $title));
	}
}

// Replace macros in the string
if (!function_exists('soccerclub_strmacros')) {
	function soccerclub_strmacros($str) {
		return str_replace(array("{{", "}}", "((", "))", "||"), array("<i>", "</i>", "<b>", "</b>", "<br>"), $str);
	}
}

// Unserialize string (try replace \n with \r\n)
if (!function_exists('soccerclub_unserialize')) {
	function soccerclub_unserialize($str) {
		if ( is_serialized($str) ) {
			try {
				$data = unserialize($str);
			} catch (Exception $e) {
				dcl($e->getMessage());
				$data = false;
			}
			if ($data===false) {
				try {
					$data = unserialize(str_replace("\n", "\r\n", $str));
				} catch (Exception $e) {
					dcl($e->getMessage());
					$data = false;
				}
			}
			return $data;
		} else
			return $str;
	}
}
?>