<?php
/**
 * SoccerClub Framework: Theme specific actions
 *
 * @package	soccerclub
 * @since	soccerclub 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

// Default Theme Options
if ( !function_exists( 'soccerclub_core_theme_setup1' ) ) {
    // Priority 1 for add soccerclub_filter handlers
    add_action( 'soccerclub_action_before_init_theme', 'soccerclub_core_theme_setup1', 1 );
    function soccerclub_core_theme_setup1() {
        // Make theme available for translation
        // Translations can be filled in the /languages directory
        load_theme_textdomain( 'soccerclub', soccerclub_get_folder_dir('languages') );
    }
}


if ( !function_exists( 'soccerclub_core_theme_setup' ) ) {
    add_action( 'soccerclub_action_before_init_theme', 'soccerclub_core_theme_setup', 11 );
}




/* Theme init
------------------------------------------------------------------------ */

// Init theme template
function soccerclub_core_init_theme() {
    if (soccerclub_storage_get('theme_inited')===true) return;
    soccerclub_storage_set('theme_inited', true);

    if (!is_admin()) soccerclub_profiler_add_point(esc_html__('After WP INIT actions', 'soccerclub'), false);

    // Load custom options from GET and post/page/cat options
    if (isset($_GET['set']) && $_GET['set']==1) {
        foreach ($_GET as $k=>$v) {
            if (soccerclub_get_theme_option($k, null) !== null) {
                setcookie($k, $v, 0, '/');
                $_COOKIE[$k] = $v;
            }
        }
    }

    // Get custom options from current category / page / post / shop / event
    soccerclub_load_custom_options();

    // Load skin
    $skin = sanitize_file_name(soccerclub_get_custom_option('theme_skin'));
    soccerclub_storage_set('theme_skin', $skin);
    if ( file_exists(soccerclub_get_file_dir('skins/'.($skin).'/skin.php')) ) {
        get_template_part(soccerclub_get_file_slug('skins/'.($skin).'/skin.php'));
    }

    // Fire init theme actions (after skin and custom options are loaded)
    do_action('soccerclub_action_init_theme');

    // Prepare theme core global variables
    do_action('soccerclub_action_prepare_globals');

    // Fire after init theme actions
    do_action('soccerclub_action_after_init_theme');
    soccerclub_profiler_add_point(esc_html__('After Theme Init', 'soccerclub'));
}


// Prepare theme global variables
if ( !function_exists( 'soccerclub_core_prepare_globals' ) ) {
    function soccerclub_core_prepare_globals() {
        if (!is_admin()) {
            // Logo text and slogan
            soccerclub_storage_set('logo_text', apply_filters('soccerclub_filter_prepare_logo_text', soccerclub_get_custom_option('logo_text')));
            soccerclub_storage_set('logo_slogan', get_bloginfo('description'));

            // Logo image and icons from skin
            $logo        = soccerclub_get_logo_icon('logo');
            $logo_side   = soccerclub_get_logo_icon('logo_side');
            $logo_fixed  = soccerclub_get_logo_icon('logo_fixed');
            $logo_footer = soccerclub_get_logo_icon('logo_footer');
            soccerclub_storage_set('logo', $logo);
            soccerclub_storage_set('logo_icon',   soccerclub_get_logo_icon('logo_icon'));
            soccerclub_storage_set('logo_side',   $logo_side   ? $logo_side   : $logo);
            soccerclub_storage_set('logo_fixed',  $logo_fixed  ? $logo_fixed  : $logo);
            soccerclub_storage_set('logo_footer', $logo_footer ? $logo_footer : $logo);

            $shop_mode = '';
            if (soccerclub_get_custom_option('show_mode_buttons')=='yes')
                $shop_mode = soccerclub_get_value_gpc('soccerclub_shop_mode');
            if (empty($shop_mode))
                $shop_mode = soccerclub_get_custom_option('shop_mode', '');
            if (empty($shop_mode) || !is_archive())
                $shop_mode = 'thumbs';
            soccerclub_storage_set('shop_mode', $shop_mode);
        }
    }
}


// Return url for the uploaded logo image or (if not uploaded) - to image from skin folder
if ( !function_exists( 'soccerclub_get_logo_icon' ) ) {
    function soccerclub_get_logo_icon($slug) {
        $mult = soccerclub_get_retina_multiplier();
        $logo_icon = '';
        if ($mult > 1) 			$logo_icon = soccerclub_get_custom_option($slug.'_retina');
        if (empty($logo_icon))	$logo_icon = soccerclub_get_custom_option($slug);
        return $logo_icon;
    }
}


// Display logo image with text and slogan (if specified)
if ( !function_exists( 'soccerclub_show_logo' ) ) {
    function soccerclub_show_logo($logo_main=true, $logo_fixed=false, $logo_footer=false, $logo_side=false, $logo_text=true, $logo_slogan=true) {
        if ($logo_main===true)		$logo_main   = soccerclub_storage_get('logo');
        if ($logo_fixed===true)		$logo_fixed  = soccerclub_storage_get('logo_fixed');
        if ($logo_footer===true)	$logo_footer = soccerclub_storage_get('logo_footer');
        if ($logo_side===true)		$logo_side   = soccerclub_storage_get('logo_side');
        if ($logo_text===true)		$logo_text   = soccerclub_storage_get('logo_text');
        if ($logo_slogan===true)	$logo_slogan = soccerclub_storage_get('logo_slogan');
        if (empty($logo_main) && empty($logo_fixed) && empty($logo_footer) && empty($logo_side) && empty($logo_text)){
            $logo_text = get_bloginfo('name');
        }
        if ($logo_main || $logo_fixed || $logo_footer || $logo_side || $logo_text) {
            ?>
            <div class="logo">
                <a href="<?php echo esc_url(home_url('/')); ?>"><?php
                    if (!empty($logo_main)) {
                        $attr = soccerclub_getimagesize($logo_main);
                        echo '<img src="'.esc_url($logo_main).'" class="logo_main" alt="'.esc_attr__('Logo', 'soccerclub').'"'.(!empty($attr[3]) ? ' '.trim($attr[3]) : '').'>';
                    }
                    if (!empty($logo_fixed)) {
                        $attr = soccerclub_getimagesize($logo_fixed);
                        echo '<img src="'.esc_url($logo_fixed).'" class="logo_fixed" alt="'.esc_attr__('Logo', 'soccerclub').'"'.(!empty($attr[3]) ? ' '.trim($attr[3]) : '').'>';
                    }
                    if (!empty($logo_footer)) {
                        $attr = soccerclub_getimagesize($logo_footer);
                        echo '<img src="'.esc_url($logo_footer).'" class="logo_footer" alt="'.esc_attr__('Logo', 'soccerclub').'"'.(!empty($attr[3]) ? ' '.trim($attr[3]) : '').'>';
                    }
                    if (!empty($logo_side)) {
                        $attr = soccerclub_getimagesize($logo_side);
                        echo '<img src="'.esc_url($logo_side).'" class="logo_side" alt="'.esc_attr__('Logo', 'soccerclub').'"'.(!empty($attr[3]) ? ' '.trim($attr[3]) : '').'>';
                    }
                    echo !empty($logo_text) ? '<div class="logo_text">'.trim($logo_text).'</div>' : '';
                    echo !empty($logo_slogan) ? '<br><div class="logo_slogan">' . esc_html($logo_slogan) . '</div>' : '';
                    ?></a>
            </div>
            <?php
        }
    }
}







/* Front actions and filters:
------------------------------------------------------------------------ */

//  Enqueue scripts and styles
if ( !function_exists( 'soccerclub_core_frontend_scripts' ) ) {
    function soccerclub_core_frontend_scripts() {

        // Modernizr will load in head before other scripts and styles
        // Use older version (from photostack)
        wp_enqueue_script(  'modernizr', soccerclub_get_file_url('js/photostack/modernizr.min.js'), array(), null, true );

        // Enqueue styles
        //-----------------------------------------------------------------------------------------------------

        // Prepare custom fonts
        $fonts = soccerclub_get_list_fonts(false);
        $theme_fonts = array();
        $custom_fonts = soccerclub_get_custom_fonts();
        if (is_array($custom_fonts) && count($custom_fonts) > 0) {
            foreach ($custom_fonts as $s=>$f) {
                if (!empty($f['font-family']) && !soccerclub_is_inherit_option($f['font-family'])) $theme_fonts[$f['font-family']] = 1;
            }
        }
        // Prepare current skin fonts
        $theme_fonts = apply_filters('soccerclub_filter_used_fonts', $theme_fonts);
        // Link to selected fonts
        if (is_array($theme_fonts) && count($theme_fonts) > 0) {
            $google_fonts = '';
            foreach ($theme_fonts as $font=>$v) {
                if (isset($fonts[$font])) {
                    $font_name = ($pos=soccerclub_strpos($font,' ('))!==false ? soccerclub_substr($font, 0, $pos) : $font;
                    if (!empty($fonts[$font]['css'])) {
                        $css = $fonts[$font]['css'];
                        wp_enqueue_style( 'soccerclub-font-'.str_replace(' ', '-', $font_name).'-style', $css, array(), null );
                    } else {
                        // Attention! Using '%7C' instead '|' damage loading second+ fonts
                        $google_fonts .= ($google_fonts ? '|' : '')
                            . (!empty($fonts[$font]['link']) ? $fonts[$font]['link'] : str_replace(' ', '+', $font_name).':300,300italic,400,400italic,700,700italic,900');
                    }
                }
            }
            if ($google_fonts)
                /*
               Translators: If there are characters in your language that are not supported
               by chosen font(s), translate this to 'off'. Do not translate into your own language.
               */
                $google_fonts_enabled = ( 'off' !== esc_html_x( 'on', 'Google fonts: on or off', 'soccerclub' ) );
            if ( $google_fonts_enabled ) {
                wp_enqueue_style('soccerclub-font-google-fonts-style', soccerclub_get_protocol() . '://fonts.googleapis.com/css?family=' . $google_fonts . '&subset=' . soccerclub_get_theme_option('fonts_subset'), array(), null);
            }
        }

        // Fontello styles must be loaded before main stylesheet
        wp_enqueue_style( 'fontello-style',  soccerclub_get_file_url('css/fontello/css/fontello.css'),  array(), null);

        // Main stylesheet
        wp_enqueue_style( 'soccerclub-main-style', get_stylesheet_uri(), array(), null );

        // Animations
        if (soccerclub_get_theme_option('css_animation')=='yes' && (soccerclub_get_theme_option('animation_on_mobile')=='yes' || !wp_is_mobile()) && !soccerclub_vc_is_frontend())
            wp_enqueue_style( 'soccerclub-animation-style',	soccerclub_get_file_url('css/core.animation.css'), array(), null );

        // Theme skin stylesheet
        do_action('soccerclub_action_add_styles');

        // Theme customizer stylesheet and inline styles
        soccerclub_enqueue_custom_styles();

        // Responsive
        if (soccerclub_get_theme_option('responsive_layouts') == 'yes') {
            $suffix = soccerclub_param_is_off(soccerclub_get_custom_option('show_sidebar_outer')) ? '' : '-outer';
            wp_enqueue_style( 'soccerclub-responsive-style', soccerclub_get_file_url('css/responsive'.($suffix).'.css'), array(), null );
            do_action('soccerclub_action_add_responsive');
            if (soccerclub_get_custom_option('theme_skin')!='') {
                $css = apply_filters('soccerclub_filter_add_responsive_inline', '');
                if (!empty($css)) wp_add_inline_style( 'soccerclub-responsive-style', $css );
            }
        }

        // Disable loading JQuery UI CSS
        wp_deregister_style('jquery_ui');
        wp_deregister_style('date-picker-css');


        // Enqueue scripts
        //----------------------------------------------------------------------------------------------------------------------------

        // Load separate theme scripts
        wp_enqueue_script( 'superfish', soccerclub_get_file_url('js/superfish.js'), array('jquery'), null, true );
        if (soccerclub_get_theme_option('menu_slider')=='yes') {
            wp_enqueue_script( 'slidemenu-script', soccerclub_get_file_url('js/jquery.slidemenu.js'), array('jquery'), null, true );
        }

        wp_enqueue_script( 'soccerclub-core-utils-script',	soccerclub_get_file_url('js/core.utils.js'), array('jquery'), null, true );
        wp_enqueue_script( 'soccerclub-core-init-script',	soccerclub_get_file_url('js/core.init.js'), array('jquery'), null, true );
        wp_enqueue_script( 'soccerclub-theme-init-script',	soccerclub_get_file_url('js/theme.init.js'), array('jquery'), null, true );

        // Media elements library
        if (soccerclub_get_theme_option('use_mediaelement')=='yes') {
            wp_enqueue_style ( 'mediaelement' );
            wp_enqueue_style ( 'wp-mediaelement' );
            wp_enqueue_script( 'mediaelement' );
            wp_enqueue_script( 'wp-mediaelement' );
        }

        // Video background
        if (soccerclub_get_custom_option('show_video_bg') == 'yes' && soccerclub_get_custom_option('video_bg_youtube_code') != '') {
            wp_enqueue_script( 'video-bg-script', soccerclub_get_file_url('js/jquery.tubular.1.0.js'), array('jquery'), null, true );
        }


        // Social share buttons
        if (is_singular() && !soccerclub_storage_get('blog_streampage') && soccerclub_get_custom_option('show_share')!='hide') {
            wp_enqueue_script( 'social-share-script', soccerclub_get_file_url('js/social/social-share.js'), array('jquery'), null, true );
        }

        // Comments
        if ( is_singular() && !soccerclub_storage_get('blog_streampage') && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply', false, array(), null, true );
        }

        // Custom panel
        if (soccerclub_get_theme_option('show_theme_customizer') == 'yes') {
            if (file_exists(soccerclub_get_file_dir('core/core.customizer/front.customizer.css')))
                wp_enqueue_style(  'soccerclub-customizer-style',  soccerclub_get_file_url('core/core.customizer/front.customizer.css'), array(), null );
            if (file_exists(soccerclub_get_file_dir('core/core.customizer/front.customizer.js')))
                wp_enqueue_script( 'soccerclub-customizer-script', soccerclub_get_file_url('core/core.customizer/front.customizer.js'), array(), null, true );
        }

        //Debug utils
        if (soccerclub_get_theme_option('debug_mode')=='yes') {
            wp_enqueue_script( 'soccerclub-core-debug-script', soccerclub_get_file_url('js/core.debug.js'), array(), null, true );
        }

        // Theme skin script
        do_action('soccerclub_action_add_scripts');
    }
}

//  Enqueue Swiper Slider scripts and styles
if ( !function_exists( 'soccerclub_enqueue_slider' ) ) {
    function soccerclub_enqueue_slider($engine='all') {
        if ($engine=='all' || $engine=='swiper') {
            wp_enqueue_style(  'swiperslider-style', 			soccerclub_get_file_url('js/swiper/swiper.css'), array(), null );
            wp_enqueue_script( 'swiperslider-script', 			soccerclub_get_file_url('js/swiper/swiper.js'), array(), null, true );
        }
    }
}

//  Enqueue Photostack gallery
if ( !function_exists( 'soccerclub_enqueue_polaroid' ) ) {
    function soccerclub_enqueue_polaroid() {
        wp_enqueue_style(  'polaroid-style', 	soccerclub_get_file_url('js/photostack/component.css'), array(), null );
        wp_enqueue_script( 'classie-script',		soccerclub_get_file_url('js/photostack/classie.js'), array(), null, true );
        wp_enqueue_script( 'polaroid-script',	soccerclub_get_file_url('js/photostack/photostack.js'), array(), null, true );
    }
}

//  Enqueue Messages scripts and styles
if ( !function_exists( 'soccerclub_enqueue_messages' ) ) {
    function soccerclub_enqueue_messages() {
        wp_enqueue_style(  'soccerclub-messages-style',		soccerclub_get_file_url('js/core.messages/core.messages.css'), array(), null );
        wp_enqueue_script( 'soccerclub-messages-script',	soccerclub_get_file_url('js/core.messages/core.messages.js'),  array('jquery'), null, true );
    }
}

//  Enqueue Portfolio hover scripts and styles
if ( !function_exists( 'soccerclub_enqueue_portfolio' ) ) {
    function soccerclub_enqueue_portfolio($hover='') {
        wp_enqueue_style( 'soccerclub-portfolio-style',  soccerclub_get_file_url('css/core.portfolio.css'), array(), null );
        if (soccerclub_strpos($hover, 'effect_dir')!==false)
            wp_enqueue_script( 'hoverdir', soccerclub_get_file_url('js/hover/jquery.hoverdir.js'), array(), null, true );
    }
}

//  Enqueue Charts and Diagrams scripts and styles
if ( !function_exists( 'soccerclub_enqueue_diagram' ) ) {
    function soccerclub_enqueue_diagram($type='all') {
        if ($type=='all' || $type=='pie') wp_enqueue_script( 'diagram-chart-script',	soccerclub_get_file_url('js/diagram/chart.min.js'), array(), null, true );
        if ($type=='all' || $type=='arc') wp_enqueue_script( 'diagram-raphael-script',	soccerclub_get_file_url('js/diagram/diagram.raphael.min.js'), array(), 'no-compose', true );
    }
}

// Enqueue Theme Popup scripts and styles
// Link must have attribute: data-rel="popup" or data-rel="popup[gallery]"
if ( !function_exists( 'soccerclub_enqueue_popup' ) ) {
    function soccerclub_enqueue_popup($engine='') {
        if ($engine=='pretty' || (empty($engine) && soccerclub_get_theme_option('popup_engine')=='pretty')) {
            wp_enqueue_style(  'prettyphoto-style',	soccerclub_get_file_url('js/prettyphoto/css/prettyPhoto.css'), array(), null );
            wp_enqueue_script( 'prettyphoto-script',	soccerclub_get_file_url('js/prettyphoto/jquery.prettyPhoto.min.js'), array('jquery'), 'no-compose', true );
        } else if ($engine=='magnific' || (empty($engine) && soccerclub_get_theme_option('popup_engine')=='magnific')) {
            wp_enqueue_style(  'magnific-style',	soccerclub_get_file_url('js/magnific/magnific-popup.css'), array(), null );
            wp_enqueue_script( 'magnific-script',soccerclub_get_file_url('js/magnific/jquery.magnific-popup.min.js'), array('jquery'), '', true );
        } else if ($engine=='internal' || (empty($engine) && soccerclub_get_theme_option('popup_engine')=='internal')) {
            soccerclub_enqueue_messages();
        }
    }
}

//  Add inline scripts in the footer hook
if ( !function_exists( 'soccerclub_core_frontend_scripts_inline' ) ) {
    //Handler of add_action('wp_footer', 'soccerclub_core_frontend_scripts_inline', 9);
    function soccerclub_core_frontend_scripts_inline() {
        $vars = soccerclub_storage_get('js_vars');
        if (empty($vars) || !is_array($vars)) $vars = array();
        wp_localize_script('soccerclub-core-init-script', 'SOCCERCLUB_STORAGE', apply_filters('soccerclub_action_add_scripts_inline', $vars));
    }
}

//  Add property="stylesheet" into all tags <link> in the footer
if (!function_exists('soccerclub_core_add_property_to_link')) {
    //Handler of add_filter('style_loader_tag', 'soccerclub_core_add_property_to_link', 10, 3);
    function soccerclub_core_add_property_to_link($link, $handle='', $href='') {
        return str_replace('<link ', '<link property="stylesheet" ', $link);
    }
}

//  Add inline scripts in the footer
if (!function_exists('soccerclub_core_add_scripts_inline')) {
    function soccerclub_core_add_scripts_inline($vars = array()) {

        $msg = soccerclub_get_system_message(true);
        if (!empty($msg['message'])) soccerclub_enqueue_messages();

        // AJAX parameters
        $vars['ajax_url'] = esc_url(admin_url('admin-ajax.php'));
        $vars['ajax_nonce'] = esc_attr(wp_create_nonce(admin_url('admin-ajax.php')));

        // Site base url
        $vars['site_url'] = esc_url(get_site_url());

        // VC frontend edit mode
        $vars['vc_edit_mode'] = function_exists('soccerclub_vc_is_frontend') && soccerclub_vc_is_frontend();

        // Theme base font
        $vars['theme_font'] = soccerclub_get_custom_font_settings('p', 'font-family');

        // Theme skin
        $vars['theme_skin'] = esc_attr(soccerclub_get_custom_option('theme_skin'));
        $vars['theme_skin_color'] = soccerclub_get_scheme_color('text_dark');
        $vars['theme_skin_bg_color'] = soccerclub_get_scheme_color('bg_color');

        // Slider height
        $vars['slider_height'] = max(100, soccerclub_get_custom_option('slider_height'));

        // System message
        $vars['system_message']    = $msg;

        // User logged in
        $vars['user_logged_in']    = is_user_logged_in();

        // Show table of content for the current page
        $vars['toc_menu'] = soccerclub_get_custom_option('menu_toc');
        $vars['toc_menu_home'] = soccerclub_get_custom_option('menu_toc')!='hide' && soccerclub_get_custom_option('menu_toc_home')=='yes';
        $vars['toc_menu_top'] = soccerclub_get_custom_option('menu_toc')!='hide' && soccerclub_get_custom_option('menu_toc_top')=='yes';

        // Fix main menu
        $vars['menu_fixed'] = soccerclub_get_theme_option('menu_attachment')=='fixed';

        // Use responsive version for main menu
        $vars['menu_mobile'] = soccerclub_get_theme_option('responsive_layouts') == 'yes' ? max(0, (int) soccerclub_get_theme_option('menu_mobile')) : 0;
        $vars['menu_slider'] = soccerclub_get_theme_option('menu_slider')=='yes';

        // Menu cache is used
        $vars['menu_cache']    = soccerclub_get_theme_option('use_menu_cache')=='yes';

        // Right panel demo timer
        $vars['demo_time'] = soccerclub_get_theme_option('show_theme_customizer')=='yes' ? max(0, (int) soccerclub_get_theme_option('customizer_demo')) : 0;

        // Video and Audio tag wrapper
        $vars['media_elements_enabled'] = soccerclub_get_theme_option('use_mediaelement')=='yes';

        // Use AJAX search
        $vars['ajax_search_enabled'] = soccerclub_get_theme_option('use_ajax_search')=='yes';
        $vars['ajax_search_min_length']    = min(3, soccerclub_get_theme_option('ajax_search_min_length'));
        $vars['ajax_search_delay'] = min(200, max(1000, soccerclub_get_theme_option('ajax_search_delay')));

        // AJAX posts counter
        $vars['use_ajax_views_counter'] = is_singular() && soccerclub_get_theme_option('use_ajax_views_counter')=='yes';
        if (is_singular() && soccerclub_get_theme_option('use_ajax_views_counter')=='yes') {
            $vars['post_id'] = (int) get_the_ID();
            $vars['views'] = (int) apply_filters('trx_utils_filter_get_post_views', 0, soccerclub_get_post_views(get_the_ID()) + 1);
        }

        // Use CSS animation
        $vars['css_animation'] = soccerclub_get_theme_option('css_animation')=='yes';
        $vars['menu_animation_in'] = soccerclub_get_theme_option('menu_animation_in');
        $vars['menu_animation_out'] = soccerclub_get_theme_option('menu_animation_out');

        // Popup windows engine
        $vars['popup_engine'] = soccerclub_get_theme_option('popup_engine');

        // E-mail mask
        $vars['email_mask'] = '^([a-zA-Z0-9_\\-]+\\.)*[a-zA-Z0-9_\\-]+@[a-z0-9_\\-]+(\\.[a-z0-9_\\-]+)*\\.[a-z]{2,6}$';

        // Messages max length
        $vars['contacts_maxlength']    = intval(soccerclub_get_theme_option('message_maxlength_contacts'));
        $vars['comments_maxlength']    = intval(soccerclub_get_theme_option('message_maxlength_comments'));

        // Remember visitors settings
        $vars['remember_visitors_settings']    = soccerclub_get_theme_option('remember_visitors_settings')=='yes';

        // Internal vars - do not change it!
        // Flag for review mechanism
        $vars['admin_mode'] = false;
        // Max scale factor for the portfolio and other isotope elements before relayout
        $vars['isotope_resize_delta'] = 0.3;
        // jQuery object for the message box in the form
        $vars['error_message_box'] = null;
        // Waiting for the viewmore results
        $vars['viewmore_busy'] = false;
        $vars['video_resize_inited'] = false;
        $vars['top_panel_height'] = 0;

        return $vars;
    }
}


//  Enqueue Custom styles (main Theme options settings)
if ( !function_exists( 'soccerclub_enqueue_custom_styles' ) ) {
    function soccerclub_enqueue_custom_styles() {
        // Custom stylesheet
        $custom_css = '';
        wp_enqueue_style( 'soccerclub-custom-style', $custom_css ? $custom_css : soccerclub_get_file_url('css/custom-style.css'), array(), null );
        // Custom inline styles
        wp_add_inline_style( 'soccerclub-custom-style', soccerclub_prepare_custom_styles() );
    }
}

// Add class "widget_number_#' for each widget
if ( !function_exists( 'soccerclub_add_widget_number' ) ) {
    //Handler of add_filter('dynamic_sidebar_params', 'soccerclub_add_widget_number', 10, 1);
    function soccerclub_add_widget_number($prm) {
        if (is_admin()) return $prm;
        static $num=0, $last_sidebar='', $last_sidebar_id='', $last_sidebar_columns=0, $last_sidebar_count=0, $sidebars_widgets=array();
        $cur_sidebar = soccerclub_storage_get('current_sidebar');
        if (empty($cur_sidebar)) $cur_sidebar = 'undefined';
        if (count($sidebars_widgets) == 0)
            $sidebars_widgets = wp_get_sidebars_widgets();
        if ($last_sidebar != $cur_sidebar) {
            $num = 0;
            $last_sidebar = $cur_sidebar;
            $last_sidebar_id = $prm[0]['id'];
            $last_sidebar_columns = max(1, (int) soccerclub_get_custom_option('sidebar_'.($cur_sidebar).'_columns'));
            $last_sidebar_count = count($sidebars_widgets[$last_sidebar_id]);
        }
        $num++;
        $prm[0]['before_widget'] = str_replace(' class="', ' class="widget_number_'.esc_attr($num).($last_sidebar_columns > 1 ? ' column-1_'.esc_attr($last_sidebar_columns) : '').' ', $prm[0]['before_widget']);
        return $prm;
    }
}


// Show <title> tag under old WP (version < 4.1)
if ( !function_exists( 'soccerclub_wp_title_show' ) ) {
    //Handler of add_action('wp_head', 'soccerclub_wp_title_show');
    function soccerclub_wp_title_show() {
        ?><title><?php wp_title( '|', true, 'right' ); ?></title><?php
    }
}

// Filters wp_title to print a neat <title> tag based on what is being viewed.
if ( !function_exists( 'soccerclub_wp_title_modify' ) ) {
    //Handler of add_filter( 'wp_title', 'soccerclub_wp_title_modify', 10, 2 );
    function soccerclub_wp_title_modify( $title, $sep ) {
        global $page, $paged;
        if ( is_feed() ) return $title;
        // Add the blog name
        $title .= get_bloginfo( 'name' );
        // Add the blog description for the home/front page.
        if ( is_home() || is_front_page() ) {
            $site_description = get_bloginfo( 'description', 'display' );
            if ( $site_description )
                $title .= " $sep $site_description";
        }
        // Add a page number if necessary:
        if ( $paged >= 2 || $page >= 2 )
            $title .= " $sep " . sprintf( esc_html__( 'Page %s', 'soccerclub' ), max( $paged, $page ) );
        return $title;
    }
}

// Add main menu classes
if ( !function_exists( 'soccerclub_add_mainmenu_classes' ) ) {
    //Handler of add_filter('wp_nav_menu_objects', 'soccerclub_add_mainmenu_classes', 10, 2);
    function soccerclub_add_mainmenu_classes($items, $args) {
        if (is_admin()) return $items;
        if ($args->menu_id == 'mainmenu' && soccerclub_get_theme_option('menu_colored')=='yes' && is_array($items) && count($items) > 0) {
            foreach($items as $k=>$item) {
                if ($item->menu_item_parent==0) {
                    if ($item->type=='taxonomy' && $item->object=='category') {
                        $cur_tint = soccerclub_taxonomy_get_inherited_property('category', $item->object_id, 'bg_tint');
                        if (!empty($cur_tint) && !soccerclub_is_inherit_option($cur_tint))
                            $items[$k]->classes[] = 'bg_tint_'.esc_attr($cur_tint);
                    }
                }
            }
        }
        return $items;
    }
}


// Save post data from frontend editor
if ( !function_exists( 'soccerclub_callback_frontend_editor_save' ) ) {
    function soccerclub_callback_frontend_editor_save() {

        if ( !wp_verify_nonce( soccerclub_get_value_gp('nonce'), admin_url('admin-ajax.php') ) )
            wp_die();
        $response = array('error'=>'');

        parse_str( soccerclub_get_value_gpc('data'), $output );
        $post_id = $output['frontend_editor_post_id'];

        if ( soccerclub_get_theme_option("allow_editor")=='yes' && (current_user_can('edit_posts', $post_id) || current_user_can('edit_pages', $post_id)) ) {
            if ($post_id > 0) {
                $title   = stripslashes($output['frontend_editor_post_title']);
                $content = stripslashes($output['frontend_editor_post_content']);
                $excerpt = stripslashes($output['frontend_editor_post_excerpt']);
                $rez = wp_update_post(array(
                    'ID'           => $post_id,
                    'post_content' => $content,
                    'post_excerpt' => $excerpt,
                    'post_title'   => $title
                ));
                if ($rez == 0)
                    $response['error'] = esc_html__('Post update error!', 'soccerclub');
            } else {
                $response['error'] = esc_html__('Post update error!', 'soccerclub');
            }
        } else
            $response['error'] = esc_html__('Post update denied!', 'soccerclub');

        echo json_encode($response);
        wp_die();
    }
}

// Delete post from frontend editor
if ( !function_exists( 'soccerclub_callback_frontend_editor_delete' ) ) {
    function soccerclub_callback_frontend_editor_delete() {

        if ( !wp_verify_nonce( soccerclub_get_value_gp('nonce'), admin_url('admin-ajax.php') ) )
            wp_die();

        $response = array('error'=>'');

        $post_id = soccerclub_get_value_gp('post_id');

        if ( soccerclub_get_theme_option("allow_editor")=='yes' && (current_user_can('delete_posts', $post_id) || current_user_can('delete_pages', $post_id)) ) {
            if ($post_id > 0) {
                $rez = wp_delete_post($post_id);
                if ($rez === false)
                    $response['error'] = esc_html__('Post delete error!', 'soccerclub');
            } else {
                $response['error'] = esc_html__('Post delete error!', 'soccerclub');
            }
        } else
            $response['error'] = esc_html__('Post delete denied!', 'soccerclub');

        echo json_encode($response);
        wp_die();
    }
}

// Show content with the html layout (if not empty)
if ( !function_exists('soccerclub_show_layout') ) {
    function soccerclub_show_layout($str, $before='', $after='') {
        if ($str != '') {
            printf("%s%s%s", $before, $str, $after);
        }
    }
}

//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( !function_exists( 'soccerclub_importer_set_options' ) ) {
    add_filter( 'trx_utils_filter_importer_options', 'soccerclub_importer_set_options', 9 );
    function soccerclub_importer_set_options($options=array()) {
        if (is_array($options)) {
            // Save or not installer's messages to the log-file
            $options['debug'] = false;
            // Prepare demo data
            $options['demo_url'] = esc_url(soccerclub_get_protocol().'://demofiles.axiomthemes.com/soccerclub/'); // Demo-site domain
            // Required plugins
            $options['required_plugins'] = array(
                'woocommerce',
                'the-events-calendar',
                'js_composer',
                'essential-grid',
                'revslider',
                'wp-booking-calendar',
                'contact-form-7'
            );

            $options['theme_slug'] = 'soccerclub';

            // Set number of thumbnails to regenerate when its imported (if demo data was zipped without cropped images)
            // Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
            $options['regenerate_thumbnails'] = 3;
            // Default demo
            $options['files']['default']['title'] = esc_html__('SoccerClub Demo', 'soccerclub');
            $options['files']['default']['domain_dev'] = esc_url(soccerclub_get_protocol().'://soccerclub.dv.axiomthemes.com');	// Developers domain
            $options['files']['default']['domain_demo']= esc_url(soccerclub_get_protocol().'://soccerclub.axiomthemes.com');	// Demo-site domain

        }
        return $options;
    }
}




// Prepare logo text
if ( !function_exists( 'soccerclub_prepare_logo_text' ) ) {
    function soccerclub_prepare_logo_text($text) {
    	if (!empty($text)){
        $text = str_replace(array('[', ']'), array('<span class="theme_accent">', '</span>'), $text);
        $text = str_replace(array('{', '}'), array('<strong>', '</strong>'), $text);
        return $text;
    }
    }
}
?>