<?php
/**
 * SoccerClub Framework
 *
 * @package soccerclub
 * @since soccerclub 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Framework directory path from theme root
if ( ! defined( 'SOCCERCLUB_FW_DIR' ) )			define( 'SOCCERCLUB_FW_DIR', 'fw' );
if ( ! defined( 'SOCCERCLUB_THEME_PATH' ) ) define( 'SOCCERCLUB_THEME_PATH', 	trailingslashit( get_template_directory() ) );


// Theme timing
if ( ! defined( 'SOCCERCLUB_START_TIME' ) )		define( 'SOCCERCLUB_START_TIME', microtime(true));		// Framework start time
if ( ! defined( 'SOCCERCLUB_START_MEMORY' ) )		define( 'SOCCERCLUB_START_MEMORY', memory_get_usage());	// Memory usage before core loading
if ( ! defined( 'SOCCERCLUB_START_QUERIES' ) )	define( 'SOCCERCLUB_START_QUERIES', get_num_queries());	// DB queries used

// Include theme variables storage
require_once trailingslashit( get_template_directory() ) . SOCCERCLUB_FW_DIR .'/core/core.storage.php';

// Theme variables storage
soccerclub_storage_set('options_prefix', 'soccerclub');	// Used as prefix to store theme's options in the post meta and wp options
soccerclub_storage_set('page_template', '');			// Storage for current page template name (used in the inheritance system)
soccerclub_storage_set('widgets_args', array(			// Arguments to register widgets
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h5 class="widget_title">',
		'after_title'   => '</h5>',
	)
);

/* Theme setup section
-------------------------------------------------------------------- */
if ( !function_exists( 'soccerclub_loader_theme_setup' ) ) {
	add_action( 'after_setup_theme', 'soccerclub_loader_theme_setup', 20 );
	function soccerclub_loader_theme_setup() {

		soccerclub_profiler_add_point(esc_html__('After load theme required files', 'soccerclub'));

		// Before init theme
		do_action('soccerclub_action_before_init_theme');

		// Load current values for main theme options
		soccerclub_load_main_options();

		// Theme core init - only for admin side. In frontend it called from header.php
		if ( is_admin() ) {
			soccerclub_core_init_theme();
		}
	}
}




/* Include core parts
------------------------------------------------------------------------ */
// Manual load important libraries before load all rest files
// core.strings must be first - we use soccerclub_str...() in the soccerclub_get_file_dir()
require_once trailingslashit( get_template_directory() ) . SOCCERCLUB_FW_DIR .'/core/core.strings.php';
// core.files must be first - we use soccerclub_get_file_dir() to include all rest parts
require_once trailingslashit( get_template_directory() ) . SOCCERCLUB_FW_DIR . '/core/core.files.php';

// Include debug and profiler
require_once trailingslashit( get_template_directory() ) . SOCCERCLUB_FW_DIR . '/core/core.debug.php';

require_once trailingslashit( get_template_directory() ) . '/plugins/plugin.gutenberg.php';
require_once trailingslashit( get_template_directory() ) . '/plugins/plugin.gdpr-framework.php';
require_once trailingslashit( get_template_directory() ) . '/plugins/plugin.contact-form-7.php';


// Include custom theme files
soccerclub_autoload_folder( 'includes' );

// Include core files
soccerclub_autoload_folder( 'core' );

// Include theme-specific plugins and post types
soccerclub_autoload_folder( 'plugins' );

// Include theme templates
soccerclub_autoload_folder( 'templates' );


?>