<?php

/* Theme setup section
-------------------------------------------------------------------- */

// ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
// Framework settings

soccerclub_storage_set('settings', array(
	
	'less_compiler'		=> 'lessc',								// no|lessc|less - Compiler for the .less
																// lessc - fast & low memory required, but .less-map, shadows & gradients not supprted
																// less  - slow, but support all features
	'less_nested'		=> false,								// Use nested selectors when compiling less - increase .css size, but allow using nested color schemes
	'less_prefix'		=> '',									// any string - Use prefix before each selector when compile less. For example: 'html '
	'less_separator'	=> '/*---LESS_SEPARATOR---*/',			// string - separator inside .less file to split it when compiling to reduce memory usage
																// (compilation speed gets a bit slow)
	'less_map'			=> 'no',								// no|internal|external - Generate map for .less files. 
																// Warning! You need more then 128Mb for PHP scripts on your server! Supported only if less_compiler=less (see above)
	
	'customizer_demo'	=> true,								// Show color customizer demo (if many color settings) or not (if only accent colors used)

	'allow_fullscreen'	=> false,								// Allow fullscreen and fullwide body styles

	'socials_type'		=> 'icons',								// images|icons - Use this kind of pictograms for all socials: share, social profiles, team members socials, etc.
	'slides_type'		=> 'bg',								// images|bg - Use image as slide's content or as slide's background

	'add_image_size'	=> false,								// Add theme's thumb sizes into WP list sizes. 
																// If false - new image thumb will be generated on demand,
																// otherwise - all thumb sizes will be generated when image is loaded

	'use_list_cache'	=> true,								// Use cache for any lists (increase theme speed, but get 15-20K memory)
	'use_post_cache'	=> true,								// Use cache for post_data (increase theme speed, decrease queries number, but get more memory - up to 300K)

	'allow_profiler'	=> false,								// Allow to show theme profiler when 'debug mode' is on

	'admin_dummy_style' => 2									// 1 | 2 - Progress bar style when import dummy data
	)
);



// Default Theme Options
if ( !function_exists( 'soccerclub_options_settings_theme_setup' ) ) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_options_settings_theme_setup', 2 );	// Priority 1 for add soccerclub_filter handlers
	function soccerclub_options_settings_theme_setup() {
		
		// Clear all saved Theme Options on first theme run
		add_action('after_switch_theme', 'soccerclub_options_reset');

		// Settings 
		$socials_type = soccerclub_get_theme_setting('socials_type');
				
		// Prepare arrays 
		soccerclub_storage_set('options_params', apply_filters('soccerclub_filter_theme_options_params', array(
			'list_fonts'				=> array('$soccerclub_get_list_fonts' => ''),
			'list_fonts_styles'			=> array('$soccerclub_get_list_fonts_styles' => ''),
			'list_socials' 				=> array('$soccerclub_get_list_socials' => ''),
			'list_icons' 				=> array('$soccerclub_get_list_icons' => ''),
			'list_posts_types' 			=> array('$soccerclub_get_list_posts_types' => ''),
			'list_categories' 			=> array('$soccerclub_get_list_categories' => ''),
			'list_menus'				=> array('$soccerclub_get_list_menus' => ''),
			'list_sidebars'				=> array('$soccerclub_get_list_sidebars' => ''),
			'list_positions' 			=> array('$soccerclub_get_list_sidebars_positions' => ''),
			'list_skins'				=> array('$soccerclub_get_list_skins' => ''),
			'list_color_schemes'		=> array('$soccerclub_get_list_color_schemes' => ''),
			'list_bg_tints'				=> array('$soccerclub_get_list_bg_tints' => ''),
			'list_body_styles'			=> array('$soccerclub_get_list_body_styles' => ''),
			'list_header_styles'		=> array('$soccerclub_get_list_templates_header' => ''),
			'list_blog_styles'			=> array('$soccerclub_get_list_templates_blog' => ''),
			'list_single_styles'		=> array('$soccerclub_get_list_templates_single' => ''),
			'list_article_styles'		=> array('$soccerclub_get_list_article_styles' => ''),
			'list_blog_counters' 		=> array('$soccerclub_get_list_blog_counters' => ''),
			'list_animations_in' 		=> array('$soccerclub_get_list_animations_in' => ''),
			'list_animations_out'		=> array('$soccerclub_get_list_animations_out' => ''),
			'list_filters'				=> array('$soccerclub_get_list_portfolio_filters' => ''),
			'list_hovers'				=> array('$soccerclub_get_list_hovers' => ''),
			'list_hovers_dir'			=> array('$soccerclub_get_list_hovers_directions' => ''),
			'list_alter_sizes'			=> array('$soccerclub_get_list_alter_sizes' => ''),
			'list_sliders' 				=> array('$soccerclub_get_list_sliders' => ''),
			'list_bg_image_positions'	=> array('$soccerclub_get_list_bg_image_positions' => ''),
			'list_popups' 				=> array('$soccerclub_get_list_popup_engines' => ''),
			'list_gmap_styles'		 	=> array('$soccerclub_get_list_googlemap_styles' => ''),
			'list_yes_no' 				=> array('$soccerclub_get_list_yesno' => ''),
			'list_on_off' 				=> array('$soccerclub_get_list_onoff' => ''),
			'list_show_hide' 			=> array('$soccerclub_get_list_showhide' => ''),
			'list_sorting' 				=> array('$soccerclub_get_list_sortings' => ''),
			'list_ordering' 			=> array('$soccerclub_get_list_orderings' => ''),
			'list_locations' 			=> array('$soccerclub_get_list_dedicated_locations' => '')
			)
		));


		// Theme options array
		soccerclub_storage_set('options', apply_filters('soccerclub_filter_options', array(

		
		//###############################
		//#### Customization         #### 
		//###############################
		'partition_customization' => array(
					"title" => esc_html__('Customization', 'soccerclub'),
					"start" => "partitions",
					"override" => "category,services_group,post,page,custom",
					"icon" => "iconadmin-cog-alt",
					"type" => "partition"
					),
		
		
		// Customization -> Body Style
		//-------------------------------------------------
		
		'customization_body' => array(
					"title" => esc_html__('Body style', 'soccerclub'),
					"override" => "category,services_group,post,page,custom",
					"icon" => 'iconadmin-picture',
					"start" => "customization_tabs",
					"type" => "tab"
					),
		
		'info_body_1' => array(
					"title" => esc_html__('Body parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select body style, skin and color scheme for entire site. You can override this parameters on any page, post or category', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"
					),

		'body_style' => array(
					"title" => esc_html__('Body style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select body style:', 'soccerclub') )
								. ' <br>' 
								. wp_kses_data( __('<b>boxed</b> - if you want use background color and/or image', 'soccerclub') )
								. ',<br>'
								. wp_kses_data( __('<b>wide</b> - page fill whole window with centered content', 'soccerclub') )
								. (soccerclub_get_theme_setting('allow_fullscreen') 
									? ',<br>' . wp_kses_data( __('<b>fullwide</b> - page content stretched on the full width of the window (with few left and right paddings)', 'soccerclub') )
									: '')
								. (soccerclub_get_theme_setting('allow_fullscreen') 
									? ',<br>' . wp_kses_data( __('<b>fullscreen</b> - page content fill whole window without any paddings', 'soccerclub') )
									: ''),
					"info" => true,
					"override" => "category,services_group,post,page,custom",
					"std" => "wide",
					"options" => soccerclub_get_options_param('list_body_styles'),
					"dir" => "horizontal",
					"type" => "radio"
					),
		
		'body_paddings' => array(
					"title" => esc_html__('Page paddings', 'soccerclub'),
					"desc" => wp_kses_data( __('Add paddings above and below the page content', 'soccerclub') ),
					"override" => "post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),

		'theme_skin' => array(
					"title" => esc_html__('Select theme skin', 'soccerclub'),
					"desc" => wp_kses_data( __('Select skin for the theme decoration', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "default",
					"options" => soccerclub_get_options_param('list_skins'),
					"type" => "select"
					),

		"body_scheme" => array(
					"title" => esc_html__('Color scheme', 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the entire page', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		'body_filled' => array(
					"title" => esc_html__('Fill body', 'soccerclub'),
					"desc" => wp_kses_data( __('Fill the page background with the solid color or leave it transparend to show background image (or video background)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),

		'info_body_2' => array(
					"title" => esc_html__('Background color and image', 'soccerclub'),
					"desc" => wp_kses_data( __('Color and image for the site background', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"
					),

		'bg_custom' => array(
					"title" => esc_html__('Use custom background',  'soccerclub'),
					"desc" => wp_kses_data( __("Use custom color and/or image as the site background", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),
		
		'bg_color' => array(
					"title" => esc_html__('Background color',  'soccerclub'),
					"desc" => wp_kses_data( __('Body background color',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"std" => "#ffffff",
					"type" => "color"
					),

		'bg_pattern' => array(
					"title" => esc_html__('Background predefined pattern',  'soccerclub'),
					"desc" => wp_kses_data( __('Select theme background pattern (first case - without pattern)',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"std" => "",
					"options" => array(
						0 => soccerclub_get_file_url('images/spacer.png'),
						1 => soccerclub_get_file_url('images/bg/pattern_1.jpg'),
						2 => soccerclub_get_file_url('images/bg/pattern_2.jpg'),
						3 => soccerclub_get_file_url('images/bg/pattern_3.jpg'),
						4 => soccerclub_get_file_url('images/bg/pattern_4.jpg'),
						5 => soccerclub_get_file_url('images/bg/pattern_5.jpg')
					),
					"style" => "list",
					"type" => "images"
					),
		
		'bg_pattern_custom' => array(
					"title" => esc_html__('Background custom pattern',  'soccerclub'),
					"desc" => wp_kses_data( __('Select or upload background custom pattern. If selected - use it instead the theme predefined pattern (selected in the field above)',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"std" => "",
					"type" => "media"
					),
		
		'bg_image' => array(
					"title" => esc_html__('Background predefined image',  'soccerclub'),
					"desc" => wp_kses_data( __('Select theme background image (first case - without image)',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"options" => array(
						0 => soccerclub_get_file_url('images/spacer.png'),
						1 => soccerclub_get_file_url('images/bg/image_1_thumb.jpg'),
						2 => soccerclub_get_file_url('images/bg/image_2_thumb.jpg'),
						3 => soccerclub_get_file_url('images/bg/image_3_thumb.jpg')
					),
					"style" => "list",
					"type" => "images"
					),
		
		'bg_image_custom' => array(
					"title" => esc_html__('Background custom image',  'soccerclub'),
					"desc" => wp_kses_data( __('Select or upload background custom image. If selected - use it instead the theme predefined image (selected in the field above)',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"std" => "",
					"type" => "media"
					),
		
		'bg_image_custom_position' => array( 
					"title" => esc_html__('Background custom image position',  'soccerclub'),
					"desc" => wp_kses_data( __('Select custom image position',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "left_top",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"options" => array(
						'left_top' => "Left Top",
						'center_top' => "Center Top",
						'right_top' => "Right Top",
						'left_center' => "Left Center",
						'center_center' => "Center Center",
						'right_center' => "Right Center",
						'left_bottom' => "Left Bottom",
						'center_bottom' => "Center Bottom",
						'right_bottom' => "Right Bottom",
					),
					"type" => "select"
					),
		
		'bg_image_load' => array(
					"title" => esc_html__('Load background image', 'soccerclub'),
					"desc" => wp_kses_data( __('Always load background images or only for boxed body style', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "boxed",
					"size" => "medium",
					"dependency" => array(
						'bg_custom' => array('yes')
					),
					"options" => array(
						'boxed' => esc_html__('Boxed', 'soccerclub'),
						'always' => esc_html__('Always', 'soccerclub')
					),
					"type" => "switch"
					),

		
		'info_body_3' => array(
					"title" => esc_html__('Video background', 'soccerclub'),
					"desc" => wp_kses_data( __('Parameters of the video, used as site background', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"
					),

		'show_video_bg' => array(
					"title" => esc_html__('Show video background',  'soccerclub'),
					"desc" => wp_kses_data( __("Show video as the site background", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),

		'video_bg_youtube_code' => array(
					"title" => esc_html__('Youtube code for video bg',  'soccerclub'),
					"desc" => wp_kses_data( __("Youtube code of video", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_video_bg' => array('yes')
					),
					"std" => "",
					"type" => "text"
					),

		'video_bg_url' => array(
					"title" => esc_html__('Local video for video bg',  'soccerclub'),
					"desc" => wp_kses_data( __("URL to video-file (uploaded on your site)", 'soccerclub') ),
					"readonly" =>false,
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_video_bg' => array('yes')
					),
					"before" => array(	'title' => esc_html__('Choose video', 'soccerclub'),
										'action' => 'media_upload',
										'multiple' => false,
										'linked_field' => '',
										'type' => 'video',
										'captions' => array('choose' => esc_html__( 'Choose Video', 'soccerclub'),
															'update' => esc_html__( 'Select Video', 'soccerclub')
														)
								),
					"std" => "",
					"type" => "media"
					),

		'video_bg_overlay' => array(
					"title" => esc_html__('Use overlay for video bg', 'soccerclub'),
					"desc" => wp_kses_data( __('Use overlay texture for the video background', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_video_bg' => array('yes')
					),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),
		
		
		
		
		
		// Customization -> Header
		//-------------------------------------------------
		
		'customization_header' => array(
					"title" => esc_html__("Header", 'soccerclub'),
					"override" => "category,services_group,post,page,custom",
					"icon" => 'iconadmin-window',
					"type" => "tab"),
		
		"info_header_1" => array(
					"title" => esc_html__('Top panel', 'soccerclub'),
					"desc" => wp_kses_data( __('Top panel settings. It include user menu area (with contact info, cart button, language selector, login/logout menu and user menu) and main menu area (with logo and main menu).', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"top_panel_style" => array(
					"title" => esc_html__('Top panel style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired style of the page header', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "header_4",
					"options" => soccerclub_get_options_param('list_header_styles'),
					"style" => "list",
					"type" => "images"),

		"top_panel_image" => array(
					"title" => esc_html__('Top panel image', 'soccerclub'),
					"desc" => wp_kses_data( __('Select default background image of the page header (if not single post or featured image for current post is not specified)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'top_panel_style' => array('header_7')
					),
					"std" => "",
					"type" => "media"),
		
		"top_panel_position" => array( 
					"title" => esc_html__('Top panel position', 'soccerclub'),
					"desc" => wp_kses_data( __('Select position for the top panel with logo and main menu', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "above",
					"options" => array(
						'hide'  => esc_html__('Hide', 'soccerclub'),
						'above' => esc_html__('Above slider', 'soccerclub'),
						'below' => esc_html__('Below slider', 'soccerclub'),
						'over'  => esc_html__('Over slider', 'soccerclub')
					),
					"type" => "checklist"),

		"top_panel_scheme" => array(
					"title" => esc_html__('Top panel color scheme', 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the top panel', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),

		"pushy_panel_scheme" => array(
					"title" => esc_html__('Push panel color scheme', 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the push panel (with logo, menu and socials)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'top_panel_style' => array('header_8')
					),
					"std" => "dark",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		"show_page_title" => array(
					"title" => esc_html__('Show Page title', 'soccerclub'),
					"desc" => wp_kses_data( __('Show post/page/category title', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_breadcrumbs" => array(
					"title" => esc_html__('Show Breadcrumbs', 'soccerclub'),
					"desc" => wp_kses_data( __('Show path to current category (post, page)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"breadcrumbs_max_level" => array(
					"title" => esc_html__('Breadcrumbs max nesting', 'soccerclub'),
					"desc" => wp_kses_data( __("Max number of the nested categories in the breadcrumbs (0 - unlimited)", 'soccerclub') ),
					"dependency" => array(
						'show_breadcrumbs' => array('yes')
					),
					"std" => "0",
					"min" => 0,
					"max" => 100,
					"step" => 1,
					"type" => "spinner"),

		
		
		
		"info_header_2" => array( 
					"title" => esc_html__('Main menu style and position', 'soccerclub'),
					"desc" => wp_kses_data( __('Select the Main menu style and position', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"menu_main" => array( 
					"title" => esc_html__('Select main menu',  'soccerclub'),
					"desc" => wp_kses_data( __('Select main menu for the current page',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "default",
					"options" => soccerclub_get_options_param('list_menus'),
					"type" => "select"),
		
		"menu_attachment" => array( 
					"title" => esc_html__('Main menu attachment', 'soccerclub'),
					"desc" => wp_kses_data( __('Attach main menu to top of window then page scroll down', 'soccerclub') ),
					"std" => "fixed",
					"options" => array(
						"fixed"=>esc_html__("Fix menu position", 'soccerclub'), 
						"none"=>esc_html__("Don't fix menu position", 'soccerclub')
					),
					"dir" => "vertical",
					"type" => "radio"),

		"menu_slider" => array( 
					"title" => esc_html__('Main menu slider', 'soccerclub'),
					"desc" => wp_kses_data( __('Use slider background for main menu items', 'soccerclub') ),
					"std" => "yes",
					"type" => "switch",
					"options" => soccerclub_get_options_param('list_yes_no')),

		"menu_animation_in" => array( 
					"title" => esc_html__('Submenu show animation', 'soccerclub'),
					"desc" => wp_kses_data( __('Select animation to show submenu ', 'soccerclub') ),
					"std" => "fadeInUp",
					"type" => "select",
					"options" => soccerclub_get_options_param('list_animations_in')),

		"menu_animation_out" => array( 
					"title" => esc_html__('Submenu hide animation', 'soccerclub'),
					"desc" => wp_kses_data( __('Select animation to hide submenu ', 'soccerclub') ),
					"std" => "fadeOut",
					"type" => "select",
					"options" => soccerclub_get_options_param('list_animations_out')),
		
		"menu_mobile" => array( 
					"title" => esc_html__('Main menu responsive', 'soccerclub'),
					"desc" => wp_kses_data( __('Allow responsive version for the main menu if window width less then this value', 'soccerclub') ),
					"std" => 1024,
					"min" => 320,
					"max" => 1024,
					"type" => "spinner"),
		
		"menu_width" => array( 
					"title" => esc_html__('Submenu width', 'soccerclub'),
					"desc" => wp_kses_data( __('Width for dropdown menus in main menu', 'soccerclub') ),
					"step" => 5,
					"std" => "",
					"min" => 180,
					"max" => 300,
					"mask" => "?999",
					"type" => "spinner"),
		
		
		
		"info_header_3" => array(
					"title" => esc_html__("User's menu area components", 'soccerclub'),
					"desc" => wp_kses_data( __("Select parts for the user's menu area", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"show_top_panel_top" => array(
					"title" => esc_html__('Show user menu area', 'soccerclub'),
					"desc" => wp_kses_data( __('Show user menu area on top of page', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"menu_user" => array(
					"title" => esc_html__('Select user menu',  'soccerclub'),
					"desc" => wp_kses_data( __('Select user menu for the current page',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_top_panel_top' => array('yes')
					),
					"std" => "default",
					"options" => soccerclub_get_options_param('list_menus'),
					"type" => "select"),
		
		"show_languages" => array(
					"title" => esc_html__('Show language selector', 'soccerclub'),
					"desc" => wp_kses_data( __('Show language selector in the user menu (if WPML plugin installed and current page/post has multilanguage version)', 'soccerclub') ),
					"dependency" => array(
						'show_top_panel_top' => array('yes')
					),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_login" => array( 
					"title" => esc_html__('Show Login/Logout buttons', 'soccerclub'),
					"desc" => wp_kses_data( __('Show Login and Logout buttons in the user menu area', 'soccerclub') ),
					"dependency" => array(
						'show_top_panel_top' => array('yes')
					),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_bookmarks" => array(
					"title" => esc_html__('Show bookmarks', 'soccerclub'),
					"desc" => wp_kses_data( __('Show bookmarks selector in the user menu', 'soccerclub') ),
					"dependency" => array(
						'show_top_panel_top' => array('yes')
					),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_socials" => array( 
					"title" => esc_html__('Show Social icons', 'soccerclub'),
					"desc" => wp_kses_data( __('Show Social icons in the user menu area', 'soccerclub') ),
					"dependency" => array(
						'show_top_panel_top' => array('yes')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		

		
		"info_header_4" => array( 
					"title" => esc_html__("Table of Contents (TOC)", 'soccerclub'),
					"desc" => wp_kses_data( __("Table of Contents for the current page. Automatically created if the page contains objects with id starting with 'toc_'", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"menu_toc" => array( 
					"title" => esc_html__('TOC position', 'soccerclub'),
					"desc" => wp_kses_data( __('Show TOC for the current page', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "float",
					"options" => array(
						'hide'  => esc_html__('Hide', 'soccerclub'),
						'fixed' => esc_html__('Fixed', 'soccerclub'),
						'float' => esc_html__('Float', 'soccerclub')
					),
					"type" => "checklist"),
		
		"menu_toc_home" => array(
					"title" => esc_html__('Add "Home" into TOC', 'soccerclub'),
					"desc" => wp_kses_data( __('Automatically add "Home" item into table of contents - return to home page of the site', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'menu_toc' => array('fixed','float')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"menu_toc_top" => array( 
					"title" => esc_html__('Add "To Top" into TOC', 'soccerclub'),
					"desc" => wp_kses_data( __('Automatically add "To Top" item into table of contents - scroll to top of the page', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'menu_toc' => array('fixed','float')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		
		
		
		'info_header_5' => array(
					"title" => esc_html__('Main logo', 'soccerclub'),
					"desc" => wp_kses_data( __("Select or upload logos for the site's header and select it position", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"
					),

		'logo' => array(
					"title" => esc_html__('Logo image', 'soccerclub'),
					"desc" => wp_kses_data( __('Main logo image', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "",
					"type" => "media"
					),

		'logo_retina' => array(
					"title" => esc_html__('Logo image for Retina', 'soccerclub'),
					"desc" => wp_kses_data( __('Main logo image used on Retina display', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "",
					"type" => "media"
					),

		'logo_fixed' => array(
					"title" => esc_html__('Logo image (fixed header)', 'soccerclub'),
					"desc" => wp_kses_data( __('Logo image for the header (if menu is fixed after the page is scrolled)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"divider" => false,
					"std" => "",
					"type" => "media"
					),

		'logo_text' => array(
					"title" => esc_html__('Logo text', 'soccerclub'),
					"desc" => wp_kses_data( __('Logo text - display it after logo image', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => '',
					"type" => "text"
					),

		'logo_height' => array(
					"title" => esc_html__('Logo height', 'soccerclub'),
					"desc" => wp_kses_data( __('Height for the logo in the header area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"step" => 1,
					"std" => '',
					"min" => 10,
					"max" => 300,
					"mask" => "?999",
					"type" => "spinner"
					),

		'logo_offset' => array(
					"title" => esc_html__('Logo top offset', 'soccerclub'),
					"desc" => wp_kses_data( __('Top offset for the logo in the header area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"step" => 1,
					"std" => '',
					"min" => 0,
					"max" => 99,
					"mask" => "?99",
					"type" => "spinner"
					),
		
		
		
		
		
		
		
		// Customization -> Slider
		//-------------------------------------------------
		
		"customization_slider" => array( 
					"title" => esc_html__('Slider', 'soccerclub'),
					"icon" => "iconadmin-picture",
					"override" => "category,services_group,page,custom",
					"type" => "tab"),
		
		"info_slider_1" => array(
					"title" => esc_html__('Main slider parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select parameters for main slider (you can override it in each category and page)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"type" => "info"),
					
		"show_slider" => array(
					"title" => esc_html__('Show Slider', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want to show slider on each page (post)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
					
		"slider_display" => array(
					"title" => esc_html__('Slider display', 'soccerclub'),
					"desc" => wp_kses_data( __('How display slider: boxed (fixed width and height), fullwide (fixed height) or fullscreen', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes')
					),
					"std" => "fullwide",
					"options" => array(
						"boxed"=>esc_html__("Boxed", 'soccerclub'),
						"fullwide"=>esc_html__("Fullwide", 'soccerclub'),
						"fullscreen"=>esc_html__("Fullscreen", 'soccerclub')
					),
					"type" => "checklist"),
		
		"slider_height" => array(
					"title" => esc_html__("Height (in pixels)", 'soccerclub'),
					"desc" => wp_kses_data( __("Slider height (in pixels) - only if slider display with fixed height.", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes')
					),
					"std" => '',
					"min" => 100,
					"step" => 10,
					"type" => "spinner"),
		
		"slider_engine" => array(
					"title" => esc_html__('Slider engine', 'soccerclub'),
					"desc" => wp_kses_data( __('What engine use to show slider?', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes')
					),
					"std" => "swiper",
					"options" => soccerclub_get_options_param('list_sliders'),
					"type" => "radio"),

		"slider_over_content" => array(
					"title" => esc_html__('Put content over slider',  'soccerclub'),
					"desc" => wp_kses_data( __('Put content below on fixed layer over this slider',  'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes')
					),
					"cols" => 80,
					"rows" => 20,
					"std" => "",
					"allow_html" => true,
					"allow_js" => true,
					"type" => "editor"),

		"slider_over_scheme" => array(
					"title" => esc_html__('Color scheme for content above', 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the content over the slider', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "dark",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		"slider_category" => array(
					"title" => esc_html__('Posts Slider: Category to show', 'soccerclub'),
					"desc" => wp_kses_data( __('Select category to show in Flexslider (ignored for Revolution and Royal sliders)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "",
					"options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'soccerclub')), soccerclub_get_options_param('list_categories')),
					"type" => "select",
					"multiple" => true,
					"style" => "list"),
		
		"slider_posts" => array(
					"title" => esc_html__('Posts Slider: Number posts or comma separated posts list',  'soccerclub'),
					"desc" => wp_kses_data( __("How many recent posts display in slider or comma separated list of posts ID (in this case selected category ignored)", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "5",
					"type" => "text"),
		
		"slider_orderby" => array(
					"title" => esc_html__("Posts Slider: Posts order by",  'soccerclub'),
					"desc" => wp_kses_data( __("Posts in slider ordered by date (default), comments, views, author rating, users rating, random or alphabetically", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "date",
					"options" => soccerclub_get_options_param('list_sorting'),
					"type" => "select"),
		
		"slider_order" => array(
					"title" => esc_html__("Posts Slider: Posts order", 'soccerclub'),
					"desc" => wp_kses_data( __('Select the desired ordering method for posts', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "desc",
					"options" => soccerclub_get_options_param('list_ordering'),
					"size" => "big",
					"type" => "switch"),
					
		"slider_interval" => array(
					"title" => esc_html__("Posts Slider: Slide change interval", 'soccerclub'),
					"desc" => wp_kses_data( __("Interval (in ms) for slides change in slider", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => 7000,
					"min" => 100,
					"step" => 100,
					"type" => "spinner"),
		
		"slider_pagination" => array(
					"title" => esc_html__("Posts Slider: Pagination", 'soccerclub'),
					"desc" => wp_kses_data( __("Choose pagination style for the slider", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "no",
					"options" => array(
						'no'   => esc_html__('None', 'soccerclub'),
						'yes'  => esc_html__('Dots', 'soccerclub'), 
						'over' => esc_html__('Titles', 'soccerclub')
					),
					"type" => "checklist"),
		
		"slider_infobox" => array(
					"title" => esc_html__("Posts Slider: Show infobox", 'soccerclub'),
					"desc" => wp_kses_data( __("Do you want to show post's title, reviews rating and description on slides in slider", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "slide",
					"options" => array(
						'no'    => esc_html__('None',  'soccerclub'),
						'slide' => esc_html__('Slide', 'soccerclub'), 
						'fixed' => esc_html__('Fixed', 'soccerclub')
					),
					"type" => "checklist"),
					
		"slider_info_category" => array(
					"title" => esc_html__("Posts Slider: Show post's category", 'soccerclub'),
					"desc" => wp_kses_data( __("Do you want to show post's category on slides in slider", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
					
		"slider_info_reviews" => array(
					"title" => esc_html__("Posts Slider: Show post's reviews rating", 'soccerclub'),
					"desc" => wp_kses_data( __("Do you want to show post's reviews rating on slides in slider", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
					
		"slider_info_descriptions" => array(
					"title" => esc_html__("Posts Slider: Show post's descriptions", 'soccerclub'),
					"desc" => wp_kses_data( __("How many characters show in the post's description in slider. 0 - no descriptions", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_slider' => array('yes'),
						'slider_engine' => array('swiper')
					),
					"std" => 0,
					"min" => 0,
					"step" => 10,
					"type" => "spinner"),
		
		
		
		
		
		// Customization -> Sidebars
		//-------------------------------------------------
		
		"customization_sidebars" => array( 
					"title" => esc_html__('Sidebars', 'soccerclub'),
					"icon" => "iconadmin-indent-right",
					"override" => "category,services_group,post,page,custom",
					"type" => "tab"),
		
		"info_sidebars_1" => array( 
					"title" => esc_html__('Custom sidebars', 'soccerclub'),
					"desc" => wp_kses_data( __('In this section you can create unlimited sidebars. You can fill them with widgets in the menu Appearance - Widgets', 'soccerclub') ),
					"type" => "info"),
		
		"custom_sidebars" => array(
					"title" => esc_html__('Custom sidebars',  'soccerclub'),
					"desc" => wp_kses_data( __('Manage custom sidebars. You can use it with each category (page, post) independently',  'soccerclub') ),
					"std" => "",
					"cloneable" => true,
					"type" => "text"),
		
		"info_sidebars_2" => array(
					"title" => esc_html__('Main sidebar', 'soccerclub'),
					"desc" => wp_kses_data( __('Show / Hide and select main sidebar', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		'show_sidebar_main' => array( 
					"title" => esc_html__('Show main sidebar',  'soccerclub'),
					"desc" => wp_kses_data( __('Select position for the main sidebar or hide it',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "right",
					"options" => soccerclub_get_options_param('list_positions'),
					"dir" => "horizontal",
					"type" => "checklist"),

		"sidebar_main_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the main sidebar', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_sidebar_main' => array('left', 'right')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		"sidebar_main" => array( 
					"title" => esc_html__('Select main sidebar',  'soccerclub'),
					"desc" => wp_kses_data( __('Select main sidebar content',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_sidebar_main' => array('left', 'right')
					),
					"std" => "sidebar_main",
					"options" => soccerclub_get_options_param('list_sidebars'),
					"type" => "select"),
		

		
		
		
		// Customization -> Footer
		//-------------------------------------------------
		
		'customization_footer' => array(
					"title" => esc_html__("Footer", 'soccerclub'),
					"override" => "category,services_group,post,page,custom",
					"icon" => 'iconadmin-window',
					"type" => "tab"),
		
		
		"info_footer_1" => array(
					"title" => esc_html__("Footer components", 'soccerclub'),
					"desc" => wp_kses_data( __("Select components of the footer, set style and put the content for the user's footer area", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"show_sidebar_footer" => array(
					"title" => esc_html__('Show footer sidebar', 'soccerclub'),
					"desc" => wp_kses_data( __('Select style for the footer sidebar or hide it', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"sidebar_footer_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the footer', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_sidebar_footer' => array('yes')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		"sidebar_footer" => array( 
					"title" => esc_html__('Select footer sidebar',  'soccerclub'),
					"desc" => wp_kses_data( __('Select footer sidebar for the blog page',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_sidebar_footer' => array('yes')
					),
					"std" => "sidebar_footer",
					"options" => soccerclub_get_options_param('list_sidebars'),
					"type" => "select"),
		
		"sidebar_footer_columns" => array( 
					"title" => esc_html__('Footer sidebar columns',  'soccerclub'),
					"desc" => wp_kses_data( __('Select columns number for the footer sidebar',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_sidebar_footer' => array('yes')
					),
					"std" => 4,
					"min" => 1,
					"max" => 6,
					"type" => "spinner"),
		
		
		"info_footer_2" => array(
					"title" => esc_html__('Testimonials in Footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Select parameters for Testimonials in the Footer', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),

		"show_testimonials_in_footer" => array(
					"title" => esc_html__('Show Testimonials in footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Show Testimonials slider in footer. For correct operation of the slider (and shortcode testimonials) you must fill out Testimonials posts on the menu "Testimonials"', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"testimonials_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the testimonials area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_testimonials_in_footer' => array('yes')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),

		"testimonials_count" => array( 
					"title" => esc_html__('Testimonials count', 'soccerclub'),
					"desc" => wp_kses_data( __('Number testimonials to show', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_testimonials_in_footer' => array('yes')
					),
					"std" => 3,
					"step" => 1,
					"min" => 1,
					"max" => 10,
					"type" => "spinner"),
		
		
		"info_footer_3" => array(
					"title" => esc_html__('Twitter in Footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Select parameters for Twitter stream in the Footer (you can override it in each category and page)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),

		"show_twitter_in_footer" => array(
					"title" => esc_html__('Show Twitter in footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Show Twitter slider in footer. For correct operation of the slider (and shortcode twitter) you must fill out the Twitter API keys on the menu "Appearance - Theme Options - Socials"', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"twitter_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the twitter area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_twitter_in_footer' => array('yes')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),

		"twitter_count" => array( 
					"title" => esc_html__('Twitter count', 'soccerclub'),
					"desc" => wp_kses_data( __('Number twitter to show', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_twitter_in_footer' => array('yes')
					),
					"std" => 3,
					"step" => 1,
					"min" => 1,
					"max" => 10,
					"type" => "spinner"),


		"info_footer_4" => array(
					"title" => esc_html__('Google map parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select parameters for Google map (you can override it in each category and page)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
					
		"show_googlemap" => array(
					"title" => esc_html__('Show Google Map', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want to show Google map on each page (post)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"googlemap_height" => array(
					"title" => esc_html__("Map height", 'soccerclub'),
					"desc" => wp_kses_data( __("Map height (default - in pixels, allows any CSS units of measure)", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => 400,
					"min" => 100,
					"step" => 10,
					"type" => "spinner"),
		
		"googlemap_address" => array(
					"title" => esc_html__('Address to show on map',  'soccerclub'),
					"desc" => wp_kses_data( __("Enter address to show on map center", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => "",
					"type" => "text"),
		
		"googlemap_latlng" => array(
					"title" => esc_html__('Latitude and Longitude to show on map',  'soccerclub'),
					"desc" => wp_kses_data( __("Enter coordinates (separated by comma) to show on map center (instead of address)", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => "",
					"type" => "text"),
		
		"googlemap_title" => array(
					"title" => esc_html__('Title to show on map',  'soccerclub'),
					"desc" => wp_kses_data( __("Enter title to show on map center", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => "",
					"type" => "text"),
		
		"googlemap_description" => array(
					"title" => esc_html__('Description to show on map',  'soccerclub'),
					"desc" => wp_kses_data( __("Enter description to show on map center", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => "",
					"type" => "text"),
		
		"googlemap_zoom" => array(
					"title" => esc_html__('Google map initial zoom',  'soccerclub'),
					"desc" => wp_kses_data( __("Enter desired initial zoom for Google map", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => 16,
					"min" => 1,
					"max" => 20,
					"step" => 1,
					"type" => "spinner"),
		
		"googlemap_style" => array(
					"title" => esc_html__('Google map style',  'soccerclub'),
					"desc" => wp_kses_data( __("Select style to show Google map", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => 'style1',
					"options" => soccerclub_get_options_param('list_gmap_styles'),
					"type" => "select"),
		
		"googlemap_marker" => array(
					"title" => esc_html__('Google map marker',  'soccerclub'),
					"desc" => wp_kses_data( __("Select or upload png-image with Google map marker", 'soccerclub') ),
					"dependency" => array(
						'show_googlemap' => array('yes')
					),
					"std" => '',
					"type" => "media"),
		
		
		
		"info_footer_5" => array(
					"title" => esc_html__("Contacts area", 'soccerclub'),
					"desc" => wp_kses_data( __("Show/Hide contacts area in the footer", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"show_contacts_in_footer" => array(
					"title" => esc_html__('Show Contacts in footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Show contact information area in footer: contact info and large social icons', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"contacts_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the contacts area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_contacts_in_footer' => array('yes')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),


            "info_footer_99" => array(
                "title" => esc_html__("Logo footer area", 'soccerclub'),
                "desc" => wp_kses_data( __("Show/Hide logo area in the footer", 'soccerclub') ),
                "override" => "category,services_group,post,page,custom",
                "type" => "info"),

            "show_just_logo_in_footer" => array(
                "title" => esc_html__('Show logo in footer', 'soccerclub'),
                "desc" => wp_kses_data( __('Show site logo', 'soccerclub') ),
                "override" => "category,services_group,post,page,custom",
                "std" => "yes",
                "options" => soccerclub_get_options_param('list_yes_no'),
                "type" => "switch"),


            'logo_footer' => array(
                "title" => esc_html__('Logo image for footer', 'soccerclub'),
                "desc" => wp_kses_data( __('Logo image in the footer (in the contacts area)', 'soccerclub') ),
                "override" => "category,services_group,post,page,custom",
                "dependency" => array(
                    'show_just_logo_in_footer' => array('yes')
                ),
                "std" => "",
                "type" => "media"
            ),

            'logo_footer_retina' => array(
                "title" => esc_html__('Logo image for footer for Retina', 'soccerclub'),
                "desc" => wp_kses_data( __('Logo image in the footer (in the contacts area) used on Retina display', 'soccerclub') ),
                "override" => "category,services_group,post,page,custom",
                "dependency" => array(
                    'show_just_logo_in_footer' => array('yes')
                ),
                "std" => "",
                "type" => "media"
            ),

            'logo_footer_height' => array(
                "title" => esc_html__('Logo height', 'soccerclub'),
                "desc" => wp_kses_data( __('Height for the logo in the footer area (in the contacts area)', 'soccerclub') ),
                "override" => "category,services_group,post,page,custom",
                "dependency" => array(
                    'show_just_logo_in_footer' => array('yes')
                ),
                "step" => 1,
                "std" => 30,
                "min" => 10,
                "max" => 300,
                "mask" => "?999",
                "type" => "spinner"
            ),




            "info_footer_6" => array(
					"title" => esc_html__("Copyright and footer menu", 'soccerclub'),
					"desc" => wp_kses_data( __("Show/Hide copyright area in the footer", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),

		"show_copyright_in_footer" => array(
					"title" => esc_html__('Show Copyright area in footer', 'soccerclub'),
					"desc" => wp_kses_data( __('Show area with copyright information, footer menu and small social icons in footer', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "socials",
					"options" => array(
						'none' => esc_html__('Hide', 'soccerclub'),
						'text' => esc_html__('Text', 'soccerclub'),
						'menu' => esc_html__('Text and menu', 'soccerclub'),
						'socials' => esc_html__('Text and Social icons', 'soccerclub')
					),
					"type" => "checklist"),

		"copyright_scheme" => array(
					"title" => esc_html__("Color scheme", 'soccerclub'),
					"desc" => wp_kses_data( __('Select predefined color scheme for the copyright area', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_copyright_in_footer' => array('text', 'menu', 'socials')
					),
					"std" => "original",
					"dir" => "horizontal",
					"options" => soccerclub_get_options_param('list_color_schemes'),
					"type" => "checklist"),
		
		"menu_footer" => array( 
					"title" => esc_html__('Select footer menu',  'soccerclub'),
					"desc" => wp_kses_data( __('Select footer menu for the current page',  'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "default",
					"dependency" => array(
						'show_copyright_in_footer' => array('menu')
					),
					"options" => soccerclub_get_options_param('list_menus'),
					"type" => "select"),

		"footer_copyright" => array(
					"title" => esc_html__('Footer copyright text',  'soccerclub'),
					"desc" => wp_kses_data( __("Copyright text to show in footer area (bottom of site)", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_copyright_in_footer' => array('text', 'menu', 'socials')
					),
					"allow_html" => true,
                    "allow_js" => true,
					"std" => "AxiomThemes {Y} All Rights Reserved Terms of Use Privacy Policy",
					"rows" => "10",
					"type" => "editor"),




		// Customization -> Other
		//-------------------------------------------------
		
		'customization_other' => array(
					"title" => esc_html__('Other', 'soccerclub'),
					"override" => "category,services_group,post,page,custom",
					"icon" => 'iconadmin-cog',
					"type" => "tab"
					),

		'info_other_1' => array(
					"title" => esc_html__('Theme customization other parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Animation parameters and responsive layouts for the small screens', 'soccerclub') ),
					"type" => "info"
					),

		'show_theme_customizer' => array(
					"title" => esc_html__('Show Theme customizer', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want to show theme customizer in the right panel? Your website visitors will be able to customise it yourself.', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),

		"customizer_demo" => array(
					"title" => esc_html__('Theme customizer panel demo time', 'soccerclub'),
					"desc" => wp_kses_data( __('Timer for demo mode for the customizer panel (in milliseconds: 1000ms = 1s). If 0 - no demo.', 'soccerclub') ),
					"dependency" => array(
						'show_theme_customizer' => array('yes')
					),
					"std" => "0",
					"min" => 0,
					"max" => 10000,
					"step" => 500,
					"type" => "spinner"),
		
		'css_animation' => array(
					"title" => esc_html__('Extended CSS animations', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want use extended animations effects on your site?', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),
		
		'animation_on_mobile' => array(
					"title" => esc_html__('Allow CSS animations on mobile', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you allow extended animations effects on mobile devices?', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),

		'remember_visitors_settings' => array(
					"title" => esc_html__("Remember visitor's settings", 'soccerclub'),
					"desc" => wp_kses_data( __('To remember the settings that were made by the visitor, when navigating to other pages or to limit their effect only within the current page', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),
					
		'responsive_layouts' => array(
					"title" => esc_html__('Responsive Layouts', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want use responsive layouts on small screen or still use main layout?', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"
					),
		
		'page_preloader' => array(
					"title" => esc_html__('Show page preloader',  'soccerclub'),
					"desc" => wp_kses_data( __('Do you want show animated page preloader?',  'soccerclub') ),
					"std" => "",
					"type" => "media"
					),

        'privacy_text' => array(
            "title" => esc_html__("Text with Privacy Policy link", 'soccerclub'),
            "desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'soccerclub') ),
            "std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'soccerclub'), 'soccerclub_kses_allowed_html' ),
            "type"  => "text"
                    ),


		'info_other_2' => array(
					"title" => esc_html__('Google fonts parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Specify additional parameters, used to load Google fonts', 'soccerclub') ),
					"type" => "info"
					),
		
		"fonts_subset" => array(
					"title" => esc_html__('Characters subset', 'soccerclub'),
					"desc" => wp_kses_data( __('Select subset, included into used Google fonts', 'soccerclub') ),
					"std" => "latin,latin-ext",
					"options" => array(
						'latin' => esc_html__('Latin', 'soccerclub'),
						'latin-ext' => esc_html__('Latin Extended', 'soccerclub'),
						'greek' => esc_html__('Greek', 'soccerclub'),
						'greek-ext' => esc_html__('Greek Extended', 'soccerclub'),
						'cyrillic' => esc_html__('Cyrillic', 'soccerclub'),
						'cyrillic-ext' => esc_html__('Cyrillic Extended', 'soccerclub'),
						'vietnamese' => esc_html__('Vietnamese', 'soccerclub')
					),
					"size" => "medium",
					"dir" => "vertical",
					"multiple" => true,
					"type" => "checklist"),
		
		
		
		
		
		
		
		//###############################
		//#### Blog and Single pages #### 
		//###############################
		"partition_blog" => array(
					"title" => esc_html__('Blog &amp; Single', 'soccerclub'),
					"icon" => "iconadmin-docs",
					"override" => "category,services_group,post,page,custom",
					"type" => "partition"),
		
		
		
		// Blog -> Stream page
		//-------------------------------------------------
		
		'blog_tab_stream' => array(
					"title" => esc_html__('Stream page', 'soccerclub'),
					"start" => 'blog_tabs',
					"icon" => "iconadmin-docs",
					"override" => "category,services_group,post,page,custom",
					"type" => "tab"),
		
		"info_blog_1" => array(
					"title" => esc_html__('Blog streampage parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired blog streampage parameters (you can override it in each category)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"blog_style" => array(
					"title" => esc_html__('Blog style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired blog style', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "excerpt",
					"options" => soccerclub_get_options_param('list_blog_styles'),
					"type" => "select"),
		
		"hover_style" => array(
					"title" => esc_html__('Hover style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired hover style (only for Blog style = Portfolio)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'blog_style' => array('portfolio','grid','square','colored')
					),
					"std" => "square effect_shift",
					"options" => soccerclub_get_options_param('list_hovers'),
					"type" => "select"),
		
		"hover_dir" => array(
					"title" => esc_html__('Hover dir', 'soccerclub'),
					"desc" => wp_kses_data( __('Select hover direction (only for Blog style = Portfolio and Hover style = Circle or Square)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'blog_style' => array('portfolio','grid','square','colored'),
						'hover_style' => array('square','circle')
					),
					"std" => "left_to_right",
					"options" => soccerclub_get_options_param('list_hovers_dir'),
					"type" => "select"),
		
		"article_style" => array(
					"title" => esc_html__('Article style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select article display method: boxed or stretch', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "stretch",
					"options" => soccerclub_get_options_param('list_article_styles'),
					"size" => "medium",
					"type" => "switch"),
		
		"dedicated_location" => array(
					"title" => esc_html__('Dedicated location', 'soccerclub'),
					"desc" => wp_kses_data( __('Select location for the dedicated content or featured image in the "excerpt" blog style', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'blog_style' => array('excerpt')
					),
					"std" => "default",
					"options" => soccerclub_get_options_param('list_locations'),
					"type" => "select"),
		
		"show_filters" => array(
					"title" => esc_html__('Show filters', 'soccerclub'),
					"desc" => wp_kses_data( __('What taxonomy use for filter buttons', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'blog_style' => array('portfolio','grid','square','colored')
					),
					"std" => "hide",
					"options" => soccerclub_get_options_param('list_filters'),
					"type" => "checklist"),
		
		"blog_sort" => array(
					"title" => esc_html__('Blog posts sorted by', 'soccerclub'),
					"desc" => wp_kses_data( __('Select the desired sorting method for posts', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "date",
					"options" => soccerclub_get_options_param('list_sorting'),
					"dir" => "vertical",
					"type" => "radio"),
		
		"blog_order" => array(
					"title" => esc_html__('Blog posts order', 'soccerclub'),
					"desc" => wp_kses_data( __('Select the desired ordering method for posts', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "desc",
					"options" => soccerclub_get_options_param('list_ordering'),
					"size" => "big",
					"type" => "switch"),
		
		"posts_per_page" => array(
					"title" => esc_html__('Blog posts per page',  'soccerclub'),
					"desc" => wp_kses_data( __('How many posts display on blog pages for selected style. If empty or 0 - inherit system wordpress settings',  'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "12",
					"mask" => "?99",
					"type" => "text"),
		
		"post_excerpt_maxlength" => array(
					"title" => esc_html__('Excerpt maxlength for streampage',  'soccerclub'),
					"desc" => wp_kses_data( __('How many characters from post excerpt are display in blog streampage (only for Blog style = Excerpt). 0 - do not trim excerpt.',  'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'blog_style' => array('excerpt', 'portfolio', 'grid', 'square', 'related')
					),
					"std" => "250",
					"mask" => "?9999",
					"type" => "text"),
		
		"post_excerpt_maxlength_masonry" => array(
					"title" => esc_html__('Excerpt maxlength for classic and masonry',  'soccerclub'),
					"desc" => wp_kses_data( __('How many characters from post excerpt are display in blog streampage (only for Blog style = Classic or Masonry). 0 - do not trim excerpt.',  'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'blog_style' => array('masonry', 'classic')
					),
					"std" => "150",
					"mask" => "?9999",
					"type" => "text"),
		
		
		
		
		// Blog -> Single page
		//-------------------------------------------------
		
		'blog_tab_single' => array(
					"title" => esc_html__('Single page', 'soccerclub'),
					"icon" => "iconadmin-doc",
					"override" => "category,services_group,post,page,custom",
					"type" => "tab"),
		
		
		"info_single_1" => array(
					"title" => esc_html__('Single (detail) pages parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired parameters for single (detail) pages (you can override it in each category and single post (page))', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"type" => "info"),
		
		"single_style" => array(
					"title" => esc_html__('Single page style', 'soccerclub'),
					"desc" => wp_kses_data( __('Select desired style for single page', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "single-standard",
					"options" => soccerclub_get_options_param('list_single_styles'),
					"dir" => "horizontal",
					"type" => "radio"),

		"icon" => array(
					"title" => esc_html__('Select post icon', 'soccerclub'),
					"desc" => wp_kses_data( __('Select icon for output before post/category name in some layouts', 'soccerclub') ),
					"override" => "services_group,post,page,custom",
					"std" => "",
					"options" => soccerclub_get_options_param('list_icons'),
					"style" => "select",
					"type" => "icons"
					),

		"alter_thumb_size" => array(
					"title" => esc_html__('Alter thumb size (WxH)',  'soccerclub'),
					"override" => "page,post",
					"desc" => wp_kses_data( __("Select thumb size for the alternative portfolio layout (number items horizontally x number items vertically)", 'soccerclub') ),
					"class" => "",
					"std" => "1_1",
					"type" => "radio",
					"options" => soccerclub_get_options_param('list_alter_sizes')
					),
		
		"show_featured_image" => array(
					"title" => esc_html__('Show featured image before post',  'soccerclub'),
					"desc" => wp_kses_data( __("Show featured image (if selected) before post content on single pages", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_post_title" => array(
					"title" => esc_html__('Show post title', 'soccerclub'),
					"desc" => wp_kses_data( __('Show area with post title on single pages', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_post_title_on_quotes" => array(
					"title" => esc_html__('Show post title on links, chat, quote, status', 'soccerclub'),
					"desc" => wp_kses_data( __('Show area with post title on single and blog pages in specific post formats: links, chat, quote, status', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_post_info" => array(
					"title" => esc_html__('Show post info', 'soccerclub'),
					"desc" => wp_kses_data( __('Show area with post info on single pages', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_text_before_readmore" => array(
					"title" => esc_html__('Show text before "Read more" tag', 'soccerclub'),
					"desc" => wp_kses_data( __('Show text before "Read more" tag on single pages', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
					
		"show_post_author" => array(
					"title" => esc_html__('Show post author details',  'soccerclub'),
					"desc" => wp_kses_data( __("Show post author information block on single post page", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_post_tags" => array(
					"title" => esc_html__('Show post tags',  'soccerclub'),
					"desc" => wp_kses_data( __("Show tags block on single post page", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"show_post_related" => array(
					"title" => esc_html__('Show related posts',  'soccerclub'),
					"desc" => wp_kses_data( __("Show related posts block on single post page", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"post_related_count" => array(
					"title" => esc_html__('Related posts number',  'soccerclub'),
					"desc" => wp_kses_data( __("How many related posts showed on single post page", 'soccerclub') ),
					"dependency" => array(
						'show_post_related' => array('yes')
					),
					"override" => "category,services_group,post,page,custom",
					"std" => "2",
					"step" => 1,
					"min" => 2,
					"max" => 8,
					"type" => "spinner"),

		"post_related_columns" => array(
					"title" => esc_html__('Related posts columns',  'soccerclub'),
					"desc" => wp_kses_data( __("How many columns used to show related posts on single post page. 1 - use scrolling to show all related posts", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'show_post_related' => array('yes')
					),
					"std" => "2",
					"step" => 1,
					"min" => 1,
					"max" => 4,
					"type" => "spinner"),
		
		"post_related_sort" => array(
					"title" => esc_html__('Related posts sorted by', 'soccerclub'),
					"desc" => wp_kses_data( __('Select the desired sorting method for related posts', 'soccerclub') ),
					"dependency" => array(
						'show_post_related' => array('yes')
					),
					"std" => "date",
					"options" => soccerclub_get_options_param('list_sorting'),
					"type" => "select"),
		
		"post_related_order" => array(
					"title" => esc_html__('Related posts order', 'soccerclub'),
					"desc" => wp_kses_data( __('Select the desired ordering method for related posts', 'soccerclub') ),
					"dependency" => array(
						'show_post_related' => array('yes')
					),
					"std" => "desc",
					"options" => soccerclub_get_options_param('list_ordering'),
					"size" => "big",
					"type" => "switch"),
		
		"show_post_comments" => array(
					"title" => esc_html__('Show comments',  'soccerclub'),
					"desc" => wp_kses_data( __("Show comments block on single post page", 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		
		
		// Blog -> Other parameters
		//-------------------------------------------------
		
		'blog_tab_other' => array(
					"title" => esc_html__('Other parameters', 'soccerclub'),
					"icon" => "iconadmin-newspaper",
					"override" => "category,services_group,page,custom",
					"type" => "tab"),
		
		"info_blog_other_1" => array(
					"title" => esc_html__('Other Blog parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select excluded categories, substitute parameters, etc.', 'soccerclub') ),
					"type" => "info"),
		
		"exclude_cats" => array(
					"title" => esc_html__('Exclude categories', 'soccerclub'),
					"desc" => wp_kses_data( __('Select categories, which posts are exclude from blog page', 'soccerclub') ),
					"std" => "",
					"options" => soccerclub_get_options_param('list_categories'),
					"multiple" => true,
					"style" => "list",
					"type" => "select"),
		
		"blog_pagination" => array(
					"title" => esc_html__('Blog pagination', 'soccerclub'),
					"desc" => wp_kses_data( __('Select type of the pagination on blog streampages', 'soccerclub') ),
					"std" => "pages",
					"override" => "category,services_group,page,custom",
					"options" => array(
						'pages'    => esc_html__('Standard page numbers', 'soccerclub'),
						'slider'   => esc_html__('Slider with page numbers', 'soccerclub'),
						'viewmore' => esc_html__('"View more" button', 'soccerclub'),
						'infinite' => esc_html__('Infinite scroll', 'soccerclub')
					),
					"dir" => "vertical",
					"type" => "radio"),
		
		"blog_counters" => array(
					"title" => esc_html__('Blog counters', 'soccerclub'),
					"desc" => wp_kses_data( __('Select counters, displayed near the post title', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "comments",
					"options" => soccerclub_get_options_param('list_blog_counters'),
					"dir" => "vertical",
					"multiple" => true,
					"type" => "checklist"),
		
		"close_category" => array(
					"title" => esc_html__("Post's category announce", 'soccerclub'),
					"desc" => wp_kses_data( __('What category display in announce block (over posts thumb) - original or nearest parental', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "parental",
					"options" => array(
						'parental' => esc_html__('Nearest parental category', 'soccerclub'),
						'original' => esc_html__("Original post's category", 'soccerclub')
					),
					"dir" => "vertical",
					"type" => "radio"),
		
		"show_date_after" => array(
					"title" => esc_html__('Show post date after', 'soccerclub'),
					"desc" => wp_kses_data( __('Show post date after N days (before - show post age)', 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "30",
					"mask" => "?99",
					"type" => "text"),
		
		
		
		
		
		//###############################
		//#### Reviews               #### 
		//###############################
		"partition_reviews" => array(
					"title" => esc_html__('Reviews', 'soccerclub'),
					"icon" => "iconadmin-newspaper",
					"override" => "category,services_group,services_group",
					"type" => "partition"),
		
		"info_reviews_1" => array(
					"title" => esc_html__('Reviews criterias', 'soccerclub'),
					"desc" => wp_kses_data( __('Set up list of reviews criterias. You can override it in any category.', 'soccerclub') ),
					"override" => "category,services_group,services_group",
					"type" => "info"),
		
		"show_reviews" => array(
					"title" => esc_html__('Show reviews block',  'soccerclub'),
					"desc" => wp_kses_data( __("Show reviews block on single post page and average reviews rating after post's title in stream pages", 'soccerclub') ),
					"override" => "category,services_group,services_group",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"reviews_max_level" => array(
					"title" => esc_html__('Max reviews level',  'soccerclub'),
					"desc" => wp_kses_data( __("Maximum level for reviews marks", 'soccerclub') ),
					"std" => "5",
					"options" => array(
						'5'=>esc_html__('5 stars', 'soccerclub'), 
						'10'=>esc_html__('10 stars', 'soccerclub'), 
						'100'=>esc_html__('100%', 'soccerclub')
					),
					"type" => "radio",
					),
		
		"reviews_style" => array(
					"title" => esc_html__('Show rating as',  'soccerclub'),
					"desc" => wp_kses_data( __("Show rating marks as text or as stars/progress bars.", 'soccerclub') ),
					"std" => "stars",
					"options" => array(
						'text' => esc_html__('As text (for example: 7.5 / 10)', 'soccerclub'), 
						'stars' => esc_html__('As stars or bars', 'soccerclub')
					),
					"dir" => "vertical",
					"type" => "radio"),
		
		"reviews_criterias_levels" => array(
					"title" => esc_html__('Reviews Criterias Levels', 'soccerclub'),
					"desc" => wp_kses_data( __('Words to mark criterials levels. Just write the word and press "Enter". Also you can arrange words.', 'soccerclub') ),
					"std" => esc_html__("bad,poor,normal,good,great", 'soccerclub'),
					"type" => "tags"),
		
		"reviews_first" => array(
					"title" => esc_html__('Show first reviews',  'soccerclub'),
					"desc" => wp_kses_data( __("What reviews will be displayed first: by author or by visitors. Also this type of reviews will display under post's title.", 'soccerclub') ),
					"std" => "author",
					"options" => array(
						'author' => esc_html__('By author', 'soccerclub'),
						'users' => esc_html__('By visitors', 'soccerclub')
						),
					"dir" => "horizontal",
					"type" => "radio"),
		
		"reviews_second" => array(
					"title" => esc_html__('Hide second reviews',  'soccerclub'),
					"desc" => wp_kses_data( __("Do you want hide second reviews tab in widgets and single posts?", 'soccerclub') ),
					"std" => "show",
					"options" => soccerclub_get_options_param('list_show_hide'),
					"size" => "medium",
					"type" => "switch"),
		
		"reviews_can_vote" => array(
					"title" => esc_html__('What visitors can vote',  'soccerclub'),
					"desc" => wp_kses_data( __("What visitors can vote: all or only registered", 'soccerclub') ),
					"std" => "all",
					"options" => array(
						'all'=>esc_html__('All visitors', 'soccerclub'), 
						'registered'=>esc_html__('Only registered', 'soccerclub')
					),
					"dir" => "horizontal",
					"type" => "radio"),
		
		"reviews_criterias" => array(
					"title" => esc_html__('Reviews criterias',  'soccerclub'),
					"desc" => wp_kses_data( __('Add default reviews criterias.',  'soccerclub') ),
					"override" => "category,services_group,services_group",
					"std" => "",
					"cloneable" => true,
					"type" => "text"),

		// Don't remove this parameter - it used in admin for store marks
		"reviews_marks" => array(
					"std" => "",
					"type" => "hidden"),
		





		//###############################
		//#### Media                #### 
		//###############################
		"partition_media" => array(
					"title" => esc_html__('Media', 'soccerclub'),
					"icon" => "iconadmin-picture",
					"override" => "category,services_group,post,page,custom",
					"type" => "partition"),
		
		"info_media_1" => array(
					"title" => esc_html__('Media settings', 'soccerclub'),
					"desc" => wp_kses_data( __('Set up parameters to show images, galleries, audio and video posts', 'soccerclub') ),
					"override" => "category,services_group,services_group",
					"type" => "info"),
					
		"retina_ready" => array(
					"title" => esc_html__('Image dimensions', 'soccerclub'),
					"desc" => wp_kses_data( __('What dimensions use for uploaded image: Original or "Retina ready" (twice enlarged)', 'soccerclub') ),
					"std" => "1",
					"size" => "medium",
					"options" => array(
						"1" => esc_html__("Original", 'soccerclub'), 
						"2" => esc_html__("Retina", 'soccerclub')
					),
					"type" => "switch"),
		
		"images_quality" => array(
					"title" => esc_html__('Quality for cropped images', 'soccerclub'),
					"desc" => wp_kses_data( __('Quality (1-100) to save cropped images', 'soccerclub') ),
					"std" => "70",
					"min" => 1,
					"max" => 100,
					"type" => "spinner"),
		
		"substitute_gallery" => array(
					"title" => esc_html__('Substitute standard Wordpress gallery', 'soccerclub'),
					"desc" => wp_kses_data( __('Substitute standard Wordpress gallery with our slider on the single pages', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"gallery_instead_image" => array(
					"title" => esc_html__('Show gallery instead featured image', 'soccerclub'),
					"desc" => wp_kses_data( __('Show slider with gallery instead featured image on blog streampage and in the related posts section for the gallery posts', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"gallery_max_slides" => array(
					"title" => esc_html__('Max images number in the slider', 'soccerclub'),
					"desc" => wp_kses_data( __('Maximum images number from gallery into slider', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"dependency" => array(
						'gallery_instead_image' => array('yes')
					),
					"std" => "5",
					"min" => 2,
					"max" => 10,
					"type" => "spinner"),
		
		"popup_engine" => array(
					"title" => esc_html__('Popup engine to zoom images', 'soccerclub'),
					"desc" => wp_kses_data( __('Select engine to show popup windows with images and galleries', 'soccerclub') ),
					"std" => "magnific",
					"options" => soccerclub_get_options_param('list_popups'),
					"type" => "select"),
		
		"substitute_audio" => array(
					"title" => esc_html__('Substitute audio tags', 'soccerclub'),
					"desc" => wp_kses_data( __('Substitute audio tag with source from soundcloud to embed player', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"substitute_video" => array(
					"title" => esc_html__('Substitute video tags', 'soccerclub'),
					"desc" => wp_kses_data( __('Substitute video tags with embed players or leave video tags unchanged (if you use third party plugins for the video tags)', 'soccerclub') ),
					"override" => "category,services_group,post,page,custom",
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"use_mediaelement" => array(
					"title" => esc_html__('Use Media Element script for audio and video tags', 'soccerclub'),
					"desc" => wp_kses_data( __('Do you want use the Media Element script for all audio and video tags on your site or leave standard HTML5 behaviour?', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		
		
		
		//###############################
		//#### Socials               #### 
		//###############################
		"partition_socials" => array(
					"title" => esc_html__('Socials', 'soccerclub'),
					"icon" => "iconadmin-users",
					"override" => "category,services_group,page,custom",
					"type" => "partition"),
		
		"info_socials_1" => array(
					"title" => esc_html__('Social networks', 'soccerclub'),
					"desc" => wp_kses_data( __("Social networks list for site footer and Social widget", 'soccerclub') ),
					"type" => "info"),
		
		"social_icons" => array(
					"title" => esc_html__('Social networks',  'soccerclub'),
					"desc" => wp_kses_data( __('Select icon and write URL to your profile in desired social networks.',  'soccerclub') ),
					"std" => array(array('url'=>'', 'icon'=>'')),
					"cloneable" => true,
					"size" => "small",
					"style" => $socials_type,
					"options" => $socials_type=='images' ? soccerclub_get_options_param('list_socials') : soccerclub_get_options_param('list_icons'),
					"type" => "socials"),
		
		"info_socials_2" => array(
					"title" => esc_html__('Share buttons', 'soccerclub'),
					"desc" => wp_kses_data(  esc_html__("Add button's code for each social share network.",'soccerclub')).'<br>'
					.wp_kses_data(  esc_html__("In share url you can use next macro:",'soccerclub')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s - share post (page) URL,",'soccerclub'), '<b>{url}</b>')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s - post title,",'soccerclub'), '<b>{title}</b>')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s - post image,",'soccerclub'), '<b>{image}</b>')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s - post description (if supported)",'soccerclub'), '<b>{descr}</b>')).'<br>'
					.wp_kses_data(  esc_html__("For example:",'soccerclub')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s share string: %s",'soccerclub'), '<b>Facebook</b>','<em>http://www.facebook.com/sharer.php?u={link}&amp;t={title}</em>' )).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%s share string: %s",'soccerclub'), '<b>Delicious</b>','<em>http://delicious.com/save?url={link}&amp;title={title}&amp;note={descr}</em>' )),
					"override" => "category,services_group,page,custom",
					"type" => "info"),
		
		"show_share" => array(
					"title" => esc_html__('Show social share buttons',  'soccerclub'),
					"desc" => wp_kses_data( __("Show social share buttons block", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"std" => "horizontal",
					"options" => array(
						'hide'		=> esc_html__('Hide', 'soccerclub'),
						'vertical'	=> esc_html__('Vertical', 'soccerclub'),
						'horizontal'=> esc_html__('Horizontal', 'soccerclub')
					),
					"type" => "checklist"),

		"show_share_counters" => array(
					"title" => esc_html__('Show share counters',  'soccerclub'),
					"desc" => wp_kses_data( __("Show share counters after social buttons", 'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_share' => array('vertical', 'horizontal')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"share_caption" => array(
					"title" => esc_html__('Share block caption',  'soccerclub'),
					"desc" => wp_kses_data( __('Caption for the block with social share buttons',  'soccerclub') ),
					"override" => "category,services_group,page,custom",
					"dependency" => array(
						'show_share' => array('vertical', 'horizontal')
					),
					"std" => esc_html__('Share:', 'soccerclub'),
					"type" => "text"),
		
		"share_buttons" => array(
					"title" => esc_html__('Share buttons',  'soccerclub'),
					"desc" => wp_kses_data( __('Select icon and write share URL for desired social networks.', 'soccerclub')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("%sImportant!%s If you leave text field empty - internal theme link will be used (if present).", 'soccerclub'), '<b>','</b>')),					
					"dependency" => array(
						'show_share' => array('vertical', 'horizontal')
					),
					"std" => array(array('url'=>'', 'icon'=>'')),
					"cloneable" => true,
					"size" => "small",
					"style" => $socials_type,
					"options" => $socials_type=='images' ? soccerclub_get_options_param('list_socials') : soccerclub_get_options_param('list_icons'),
					"type" => "socials"),
		
		
		"info_socials_3" => array(
					"title" => esc_html__('Twitter API keys', 'soccerclub'),
					"desc" => wp_kses_data( __("Put to this section Twitter API 1.1 keys.", 'soccerclub')).'<br>'
					.wp_kses_data(  sprintf(esc_html__("You can take them after registration your application in %s", 'soccerclub'), '<strong>https://apps.twitter.com/</strong>')),
					"type" => "info"),
		
		"twitter_username" => array(
					"title" => esc_html__('Twitter username',  'soccerclub'),
					"desc" => wp_kses_data( __('Your login (username) in Twitter',  'soccerclub') ),
					"divider" => false,
					"std" => "",
					"type" => "text"),
		
		"twitter_consumer_key" => array(
					"title" => esc_html__('Consumer Key',  'soccerclub'),
					"desc" => wp_kses_data( __('Twitter API Consumer key',  'soccerclub') ),
					"divider" => false,
					"std" => "",
					"type" => "text"),
		
		"twitter_consumer_secret" => array(
					"title" => esc_html__('Consumer Secret',  'soccerclub'),
					"desc" => wp_kses_data( __('Twitter API Consumer secret',  'soccerclub') ),
					"divider" => false,
					"std" => "",
					"type" => "text"),
		
		"twitter_token_key" => array(
					"title" => esc_html__('Token Key',  'soccerclub'),
					"desc" => wp_kses_data( __('Twitter API Token key',  'soccerclub') ),
					"divider" => false,
					"std" => "",
					"type" => "text"),
		
		"twitter_token_secret" => array(
					"title" => esc_html__('Token Secret',  'soccerclub'),
					"desc" => wp_kses_data( __('Twitter API Token secret',  'soccerclub') ),
					"divider" => false,
					"std" => "",
					"type" => "text"),

            "info_socials_4" => array(
                "title" => esc_html__('Login via Social network', 'soccerclub'),
                "desc" => esc_html__("Settings for the Login via Social networks", 'soccerclub'),
                "type" => "info"),

            "social_login" => array(
                "title" => esc_html__('Social plugin shortcode',  'soccerclub'),
                "desc" => esc_html__('Social plugin shortcode like [plugin_shortcode]',  'soccerclub'),
                "divider" => false,
                "std" => "",
                "type" => "text"),
		
		
		
		//###############################
		//#### Contact info          #### 
		//###############################
		"partition_contacts" => array(
					"title" => esc_html__('Contact info', 'soccerclub'),
					"icon" => "iconadmin-mail",
					"type" => "partition"),
		
		"info_contact_1" => array(
					"title" => esc_html__('Contact information', 'soccerclub'),
					"desc" => wp_kses_data( __('Company address, phones and e-mail', 'soccerclub') ),
					"type" => "info"),
		
		"contact_info" => array(
					"title" => esc_html__('Contacts in the header', 'soccerclub'),
					"desc" => wp_kses_data( __('String with contact info in the left side of the site header', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-home'),
					"allow_html" => true,
					"type" => "text"),
		
		"contact_open_hours" => array(
					"title" => esc_html__('Open hours in the header', 'soccerclub'),
					"desc" => wp_kses_data( __('String with open hours in the site header', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-clock'),
					"allow_html" => true,
					"type" => "text"),
		
		"contact_email" => array(
					"title" => esc_html__('Contact form email', 'soccerclub'),
					"desc" => wp_kses_data( __('E-mail for send contact form and user registration data', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-mail'),
					"type" => "text"),
		
		"contact_address_1" => array(
					"title" => esc_html__('Company address (part 1)', 'soccerclub'),
					"desc" => wp_kses_data( __('Company country, post code and city', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-home'),
					"type" => "text"),
		
		"contact_address_2" => array(
					"title" => esc_html__('Company address (part 2)', 'soccerclub'),
					"desc" => wp_kses_data( __('Street and house number', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-home'),
					"type" => "text"),
		
		"contact_phone" => array(
					"title" => esc_html__('Phone', 'soccerclub'),
					"desc" => wp_kses_data( __('Phone number', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-phone'),
					"allow_html" => true,
					"type" => "text"),
		
		"contact_fax" => array(
					"title" => esc_html__('Fax', 'soccerclub'),
					"desc" => wp_kses_data( __('Fax number', 'soccerclub') ),
					"std" => "",
					"before" => array('icon'=>'iconadmin-phone'),
					"allow_html" => true,
					"type" => "text"),
		
		"info_contact_2" => array(
					"title" => esc_html__('Contact and Comments form', 'soccerclub'),
					"desc" => wp_kses_data( __('Maximum length of the messages in the contact form shortcode and in the comments form', 'soccerclub') ),
					"type" => "info"),
		
		"message_maxlength_contacts" => array(
					"title" => esc_html__('Contact form message', 'soccerclub'),
					"desc" => wp_kses_data( __("Message's maxlength in the contact form shortcode", 'soccerclub') ),
					"std" => "1000",
					"min" => 0,
					"max" => 10000,
					"step" => 100,
					"type" => "spinner"),
		
		"message_maxlength_comments" => array(
					"title" => esc_html__('Comments form message', 'soccerclub'),
					"desc" => wp_kses_data( __("Message's maxlength in the comments form", 'soccerclub') ),
					"std" => "1000",
					"min" => 0,
					"max" => 10000,
					"step" => 100,
					"type" => "spinner"),
		
		"info_contact_3" => array(
					"title" => esc_html__('Default mail function', 'soccerclub'),
					"desc" => wp_kses_data( __('What function use to send mail: the built-in Wordpress or standard PHP function? Attention! Some plugins may not work with one of them and you always have the ability to switch to alternative.', 'soccerclub') ),
					"type" => "info"),
		
		"mail_function" => array(
					"title" => esc_html__("Mail function", 'soccerclub'),
					"desc" => wp_kses_data( __("What function use to send mail? Attention! Only wp_mail support attachment in the mail!", 'soccerclub') ),
					"std" => "wp_mail",
					"size" => "medium",
					"options" => array(
						'wp_mail' => esc_html__('WP mail', 'soccerclub'),
						'mail' => esc_html__('PHP mail', 'soccerclub')
					),
					"type" => "switch"),
		
		
		
		
		
		
		
		//###############################
		//#### Search parameters     #### 
		//###############################
		"partition_search" => array(
					"title" => esc_html__('Search', 'soccerclub'),
					"icon" => "iconadmin-search",
					"type" => "partition"),
		
		"info_search_1" => array(
					"title" => esc_html__('Search parameters', 'soccerclub'),
					"desc" => wp_kses_data( __('Enable/disable AJAX search and output settings for it', 'soccerclub') ),
					"type" => "info"),
		
		"show_search" => array(
					"title" => esc_html__('Show search field', 'soccerclub'),
					"desc" => wp_kses_data( __('Show search field in the top area and side menus', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"use_ajax_search" => array(
					"title" => esc_html__('Enable AJAX search', 'soccerclub'),
					"desc" => wp_kses_data( __('Use incremental AJAX search for the search field in top of page', 'soccerclub') ),
					"dependency" => array(
						'show_search' => array('yes')
					),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"ajax_search_min_length" => array(
					"title" => esc_html__('Min search string length',  'soccerclub'),
					"desc" => wp_kses_data( __('The minimum length of the search string',  'soccerclub') ),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"std" => 4,
					"min" => 3,
					"type" => "spinner"),
		
		"ajax_search_delay" => array(
					"title" => esc_html__('Delay before search (in ms)',  'soccerclub'),
					"desc" => wp_kses_data( __('How much time (in milliseconds, 1000 ms = 1 second) must pass after the last character before the start search',  'soccerclub') ),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"std" => 500,
					"min" => 300,
					"max" => 1000,
					"step" => 100,
					"type" => "spinner"),
		
		"ajax_search_types" => array(
					"title" => esc_html__('Search area', 'soccerclub'),
					"desc" => wp_kses_data( __('Select post types, what will be include in search results. If not selected - use all types.', 'soccerclub') ),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"std" => "",
					"options" => soccerclub_get_options_param('list_posts_types'),
					"multiple" => true,
					"style" => "list",
					"type" => "select"),
		
		"ajax_search_posts_count" => array(
					"title" => esc_html__('Posts number in output',  'soccerclub'),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"desc" => wp_kses_data( __('Number of the posts to show in search results',  'soccerclub') ),
					"std" => 5,
					"min" => 1,
					"max" => 10,
					"type" => "spinner"),
		
		"ajax_search_posts_image" => array(
					"title" => esc_html__("Show post's image", 'soccerclub'),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"desc" => wp_kses_data( __("Show post's thumbnail in the search results", 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"ajax_search_posts_date" => array(
					"title" => esc_html__("Show post's date", 'soccerclub'),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"desc" => wp_kses_data( __("Show post's publish date in the search results", 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"ajax_search_posts_author" => array(
					"title" => esc_html__("Show post's author", 'soccerclub'),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"desc" => wp_kses_data( __("Show post's author in the search results", 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"ajax_search_posts_counters" => array(
					"title" => esc_html__("Show post's counters", 'soccerclub'),
					"dependency" => array(
						'show_search' => array('yes'),
						'use_ajax_search' => array('yes')
					),
					"desc" => wp_kses_data( __("Show post's counters (views, comments, likes) in the search results", 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		
		
		
		
		//###############################
		//#### Service               #### 
		//###############################
		
		"partition_service" => array(
					"title" => esc_html__('Service', 'soccerclub'),
					"icon" => "iconadmin-wrench",
					"type" => "partition"),
		
		"info_service_1" => array(
					"title" => esc_html__('Theme functionality', 'soccerclub'),
					"desc" => wp_kses_data( __('Basic theme functionality settings', 'soccerclub') ),
					"type" => "info"),

		"use_ajax_views_counter" => array(
					"title" => esc_html__('Use AJAX post views counter', 'soccerclub'),
					"desc" => wp_kses_data( __('Use javascript for post views count (if site work under the caching plugin) or increment views count in single page template', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"allow_editor" => array(
					"title" => esc_html__('Frontend editor',  'soccerclub'),
					"desc" => wp_kses_data( __("Allow authors to edit their posts in frontend area", 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"admin_add_filters" => array(
					"title" => esc_html__('Additional filters in the admin panel', 'soccerclub'),
					"desc" => wp_kses_data( __('Show additional filters (on post formats, tags and categories) in admin panel page "Posts".', 'soccerclub')). '<br>'
					.wp_kses_data( __('Attention! If you have more than 2.000-3.000 posts, enabling this option may cause slow load of the "Posts" page! If you encounter such slow down, simply open Appearance - Theme Options - Service and set "No" for this option.', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"show_overriden_taxonomies" => array(
					"title" => esc_html__('Show overriden options for taxonomies', 'soccerclub'),
					"desc" => wp_kses_data( __('Show extra column in categories list, where changed (overriden) theme options are displayed.', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"show_overriden_posts" => array(
					"title" => esc_html__('Show overriden options for posts and pages', 'soccerclub'),
					"desc" => wp_kses_data( __('Show extra column in posts and pages list, where changed (overriden) theme options are displayed.', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),
		
		"admin_dummy_data" => array(
					"title" => esc_html__('Enable Dummy Data Installer', 'soccerclub'),
					"desc" => wp_kses_data( __('Show "Install Dummy Data" in the menu "Appearance". <b>Attention!</b> When you install dummy data all content of your site will be replaced!', 'soccerclub') ),
					"std" => "yes",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

		"admin_dummy_timeout" => array(
					"title" => esc_html__('Dummy Data Installer Timeout',  'soccerclub'),
					"desc" => wp_kses_data( __('Web-servers set the time limit for the execution of php-scripts. By default, this is 30 sec. Therefore, the import process will be split into parts. Upon completion of each part - the import will resume automatically! The import process will try to increase this limit to the time, specified in this field.',  'soccerclub') ),
					"std" => 120,
					"min" => 30,
					"max" => 1800,
					"type" => "spinner"),
		
		"admin_emailer" => array(
					"title" => esc_html__('Enable Emailer in the admin panel', 'soccerclub'),
					"desc" => wp_kses_data( __('Allow to use ThemeREX Emailer for mass-volume e-mail distribution and management of mailing lists in "Appearance - Emailer"', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

                "disable_widgets_block_editor" => array(
                    "title" => esc_html__('Disable new Widgets Block Editor', 'soccerclub'),
                    "desc" => wp_kses_data( __('Attention! If after the update to WordPress 5.8+ you are having trouble editing widgets or working in Customizer - disable new Widgets Block Editor (used in WordPress 5.8+ instead of a classic widgets panel)', 'soccerclub') ),
                    "std" => "no",
                    "options" => soccerclub_get_options_param('list_yes_no'),
                    "type" => "switch"),

		"debug_mode" => array(
					"title" => esc_html__('Debug mode', 'soccerclub'),
					"desc" => wp_kses_data( __('In debug mode we are using unpacked scripts and styles, else - using minified scripts and styles (if present). <b>Attention!</b> If you have modified the source code in the js or css files, regardless of this option will be used latest (modified) version stylesheets and scripts. You can re-create minified versions of files using on-line services or utilities', 'soccerclub') ),
					"std" => "no",
					"options" => soccerclub_get_options_param('list_yes_no'),
					"type" => "switch"),

            "info_service_2" => array(
                "title" => esc_html__('API Keys', 'soccerclub'),
                "desc" => wp_kses_data( __('API Keys for some Web services', 'soccerclub') ),
                "type" => "info"),
            'api_google' => array(
                "title" => esc_html__('Google API Key', 'soccerclub'),
                "desc" => wp_kses_data( __("Insert Google API Key for browsers into the field above to generate Google Maps", 'soccerclub') ),
                "std" => "",
                "type" => "text"),
            )
		));
	}
}


// Update all temporary vars (start with $soccerclub_) in the Theme Options with actual lists
if ( !function_exists( 'soccerclub_options_settings_theme_setup2' ) ) {
	add_action( 'soccerclub_action_after_init_theme', 'soccerclub_options_settings_theme_setup2', 1 );
	function soccerclub_options_settings_theme_setup2() {
		if (soccerclub_options_is_used()) {
			// Replace arrays with actual parameters
			$lists = array();
			$tmp = soccerclub_storage_get('options');
			if (is_array($tmp) && count($tmp) > 0) {
				$prefix = '$soccerclub_';
				$prefix_len = soccerclub_strlen($prefix);
				foreach ($tmp as $k=>$v) {
					if (isset($v['options']) && is_array($v['options']) && count($v['options']) > 0) {
						foreach ($v['options'] as $k1=>$v1) {
							if (soccerclub_substr($k1, 0, $prefix_len) == $prefix || soccerclub_substr($v1, 0, $prefix_len) == $prefix) {
								$list_func = soccerclub_substr(soccerclub_substr($k1, 0, $prefix_len) == $prefix ? $k1 : $v1, 1);
								unset($tmp[$k]['options'][$k1]);
								if (isset($lists[$list_func]))
									$tmp[$k]['options'] = soccerclub_array_merge($tmp[$k]['options'], $lists[$list_func]);
								else {
									if (function_exists($list_func)) {
										$tmp[$k]['options'] = $lists[$list_func] = soccerclub_array_merge($tmp[$k]['options'], $list_func == 'soccerclub_get_list_menus' ? $list_func(true) : $list_func());
								   	} else
								   		dfl(sprintf(esc_html__('Wrong function name %s in the theme options array', 'soccerclub'), $list_func));
								}
							}
						}
					}
				}
				soccerclub_storage_set('options', $tmp);
			}
		}
	}
}

// Reset old Theme Options while theme first run
if ( !function_exists( 'soccerclub_options_reset' ) ) {
	//Handler of add_action('after_switch_theme', 'soccerclub_options_reset');
	function soccerclub_options_reset($clear=true) {
		$theme_slug = str_replace(' ', '_', trim(soccerclub_strtolower(get_stylesheet())));
		$option_name = soccerclub_storage_get('options_prefix') . '_' . trim($theme_slug) . '_options_reset';
		if ( get_option($option_name, false) === false ) {
			if ($clear) {
				// Remove Theme Options from WP Options
				global $wpdb;
				$wpdb->query( $wpdb->prepare("delete from {$wpdb->options} where option_name like %s",
				    soccerclub_storage_get('options_prefix').'_%'
                        )
                    );
				// Add Templates Options
				if (file_exists(soccerclub_get_file_dir('demo/templates_options.txt'))) {
					$txt = soccerclub_fgc(soccerclub_get_file_dir('demo/templates_options.txt'));
					$data = soccerclub_unserialize($txt);
					// Replace upload url in options
					if (is_array($data) && count($data) > 0) {
						foreach ($data as $k=>$v) {
							if (is_array($v) && count($v) > 0) {
								foreach ($v as $k1=>$v1) {
									$v[$k1] = soccerclub_replace_uploads_url(soccerclub_replace_uploads_url($v1, 'uploads'), 'imports');
								}
							}
							add_option( $k, $v, '', 'yes' );
						}
					}
				}
			}
			add_option($option_name, 1, '', 'yes');
		}
	}
}
?>