<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('soccerclub_revslider_theme_setup')) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_revslider_theme_setup', 1 );
	function soccerclub_revslider_theme_setup() {
		if (soccerclub_exists_revslider()) {
			add_filter( 'soccerclub_filter_list_sliders',					'soccerclub_revslider_list_sliders' );
			add_filter( 'soccerclub_filter_theme_options_params',			'soccerclub_revslider_theme_options_params' );
		}
		if (is_admin()) {
			add_filter( 'soccerclub_filter_required_plugins',				'soccerclub_revslider_required_plugins' );
		}
	}
}

if ( !function_exists( 'soccerclub_revslider_settings_theme_setup2' ) ) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_revslider_settings_theme_setup2', 3 );
	function soccerclub_revslider_settings_theme_setup2() {
		if (soccerclub_exists_revslider()) {

			// Add Revslider specific options in the Theme Options
			soccerclub_storage_set_array_after('options', 'slider_engine', "slider_alias", array(
				"title" => esc_html__('Revolution Slider: Select slider',  'soccerclub'),
				"desc" => wp_kses_data( __("Select slider to show (if engine=revo in the field above)", 'soccerclub') ),
				"override" => "category,services_group,page",
				"dependency" => array(
					'show_slider' => array('yes'),
					'slider_engine' => array('revo')
				),
				"std" => "",
				"options" => soccerclub_get_options_param('list_revo_sliders'),
				"type" => "select"
				)
			);

		}
	}
}

// Check if RevSlider installed and activated
if ( !function_exists( 'soccerclub_exists_revslider' ) ) {
	function soccerclub_exists_revslider() {
		return function_exists('rev_slider_shortcode');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'soccerclub_revslider_required_plugins' ) ) {
	//Handler of add_filter('soccerclub_filter_required_plugins',	'soccerclub_revslider_required_plugins');
	function soccerclub_revslider_required_plugins($list=array()) {
		if (in_array('revslider', soccerclub_storage_get('required_plugins'))) {
			$path = soccerclub_get_file_dir('plugins/install/revslider.zip');
			if (file_exists($path)) {
				$list[] = array(
					'name' 		=> 'Revolution Slider',
					'slug' 		=> 'revslider',
					'version' 	=> '6.7.10',
					'source'	=> $path,
					'required' 	=> false
					);
			}
		}
		return $list;
	}
}


// Lists
//------------------------------------------------------------------------

// Add RevSlider in the sliders list, prepended inherit (if need)
if ( !function_exists( 'soccerclub_revslider_list_sliders' ) ) {
	//Handler of add_filter( 'soccerclub_filter_list_sliders',					'soccerclub_revslider_list_sliders' );
	function soccerclub_revslider_list_sliders($list=array()) {
		$list["revo"] = esc_html__("Layer slider (Revolution)", 'soccerclub');
		return $list;
	}
}

// Return Revo Sliders list, prepended inherit (if need)
if ( !function_exists( 'soccerclub_get_list_revo_sliders' ) ) {
	function soccerclub_get_list_revo_sliders($prepend_inherit=false) {
		if (($list = soccerclub_storage_get('list_revo_sliders'))=='') {
			$list = array();
			if (soccerclub_exists_revslider()) {
				global $wpdb;
                // Attention! The use of wpdb->prepare() is not required
                // because the query does not use external data substitution
				$rows = $wpdb->get_results( "SELECT alias, title FROM " . esc_sql($wpdb->prefix) . "revslider_sliders" );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->alias] = $row->title;
					}
				}
			}
			$list = apply_filters('soccerclub_filter_list_revo_sliders', $list);
			if (soccerclub_get_theme_setting('use_list_cache')) soccerclub_storage_set('list_revo_sliders', $list);
		}
		return $prepend_inherit ? soccerclub_array_merge(array('inherit' => esc_html__("Inherit", 'soccerclub')), $list) : $list;
	}
}

// Add RevSlider in the Theme Options params
if ( !function_exists( 'soccerclub_revslider_theme_options_params' ) ) {
	//Handler of add_filter( 'soccerclub_filter_theme_options_params',			'soccerclub_revslider_theme_options_params' );
	function soccerclub_revslider_theme_options_params($list=array()) {
		$list["list_revo_sliders"] = array('$soccerclub_get_list_revo_sliders' => '');
		return $list;
	}
}
?>