<?php
/**
 * SoccerClub Framework: Matches support
 *
 * @package	soccerclub
 * @since	soccerclub 3.5
 */

// Theme init
if (!function_exists('soccerclub_matches_theme_setup')) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_matches_theme_setup', 1 );
	function soccerclub_matches_theme_setup() {
		
		// Detect current page type, taxonomy and title (for custom post_types use priority < 10 to fire it handles early, than for standard post types)
		add_filter('soccerclub_filter_get_blog_type',			'soccerclub_matches_get_blog_type', 9, 2);
		add_filter('soccerclub_filter_get_blog_title',		'soccerclub_matches_get_blog_title', 9, 2);
		add_filter('soccerclub_filter_get_current_taxonomy',	'soccerclub_matches_get_current_taxonomy', 9, 2);
		add_filter('soccerclub_filter_is_taxonomy',			'soccerclub_matches_is_taxonomy', 9, 2);
		add_filter('soccerclub_filter_get_period_links',		'soccerclub_matches_get_period_links', 9, 3);
		add_filter('soccerclub_filter_get_stream_page_title',	'soccerclub_matches_get_stream_page_title', 9, 2);
		add_filter('soccerclub_filter_get_stream_page_link',	'soccerclub_matches_get_stream_page_link', 9, 2);
		add_filter('soccerclub_filter_get_stream_page_id',	'soccerclub_matches_get_stream_page_id', 9, 2);
		add_filter('soccerclub_filter_query_add_filters',		'soccerclub_matches_query_add_filters', 9, 2);
		add_filter('soccerclub_filter_detect_inheritance_key','soccerclub_matches_detect_inheritance_key', 9, 1);
		add_filter('soccerclub_filter_list_post_types', 		'soccerclub_matches_list_post_types', 10, 1);
		add_filter('soccerclub_filter_post_date',		 		'soccerclub_matches_post_date', 9, 3);

		// Advanced Calendar filters
		add_filter('soccerclub_filter_calendar_get_prev_month',			'soccerclub_matches_calendar_get_prev_month', 9, 2);
		add_filter('soccerclub_filter_calendar_get_next_month',			'soccerclub_matches_calendar_get_next_month', 9, 2);
		add_filter('soccerclub_filter_calendar_get_curr_month_posts',		'soccerclub_matches_calendar_get_curr_month_posts', 9, 2);

		// Add Main Query parameters
		if (soccerclub_is_matches_page()) {
			add_filter( 'posts_join',										'soccerclub_matches_posts_join', 10, 2 );
			add_filter( 'getarchives_join',									'soccerclub_matches_getarchives_join', 10, 2 );
			add_filter( 'posts_where',										'soccerclub_matches_posts_where', 10, 2 );
			add_filter( 'getarchives_where',								'soccerclub_matches_getarchives_where', 10, 2 );
		}

		// Extra column for matches lists
		if (soccerclub_get_theme_option('show_overriden_posts')=='yes') {
			add_filter('manage_edit-matches_columns',			'soccerclub_post_add_options_column', 9);
			add_filter('manage_matches_posts_custom_column',	'soccerclub_post_fill_options_column', 9, 2);
		}

		// Registar shortcodes [trx_matches] and [trx_latest_matches] in the shortcodes list
		add_action('soccerclub_action_shortcodes_list',		'soccerclub_matches_reg_shortcodes');
		add_action('soccerclub_action_shortcodes_list',		'soccerclub_latest_matches_reg_shortcodes');
		if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer()){
			add_action('soccerclub_action_shortcodes_list_vc','soccerclub_matches_reg_shortcodes_vc');
			add_action('soccerclub_action_shortcodes_list_vc','soccerclub_latest_matches_reg_shortcodes_vc');
		}

		// Add supported data types
		soccerclub_theme_support_pt('matches');
		soccerclub_theme_support_tx('matches_group');
	}
}

if ( !function_exists( 'soccerclub_matches_settings_theme_setup2' ) ) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_matches_settings_theme_setup2', 3 );
	function soccerclub_matches_settings_theme_setup2() {
		// Add post type 'matches' and taxonomy 'matches_group' into theme inheritance list
		soccerclub_add_theme_inheritance( array('matches' => array(
			'stream_template' => 'blog-matches',
			'single_template' => 'single-match',
			'taxonomy' => array('matches_group'),
			'taxonomy_tags' => array(),
			'post_type' => array('matches'),
			'override' => 'custom'
			) )
		);
	}
}


if (!function_exists('soccerclub_matches_after_theme_setup')) {
	add_action( 'soccerclub_action_after_init_theme', 'soccerclub_matches_after_theme_setup' );
	function soccerclub_matches_after_theme_setup() {
		// Update fields in the override options
		if (soccerclub_storage_get_array('post_override_options', 'page')=='matches') {
			
			add_filter('soccerclub_filter_post_save_custom_options',		'soccerclub_matches_save_custom_options', 10, 3);

			$players = soccerclub_get_list_posts(false, array(
				'post_type'=>'players',
				'orderby'=>'title',
				'order'=>'asc',
				'return'=>'title'
				)
			);
			
			// override options fields
			soccerclub_storage_set_array('post_override_options', 'title', esc_html__('Match Options', 'soccerclub'));
			soccerclub_storage_set_array('post_override_options', 'fields', array(
				"mb_partition_matches" => array(
					"title" => esc_html__('Matches', 'soccerclub'),
					"override" => "page,post,custom",
					"divider" => false,
					"icon" => "iconadmin-users",
					"type" => "partition"),
				"mb_info_matches_1" => array(
					"title" => esc_html__('Match details', 'soccerclub'),
					"override" => "page,post,custom",
					"divider" => false,
					"desc" => wp_kses_data( __('In this section you can put details for this match', 'soccerclub') ),
					"class" => "match_meta",
					"type" => "info"),
				"match_date" => array(
					"title" => esc_html__('Start date',  'soccerclub'),
					"desc" => esc_html__("Match start date", 'soccerclub'),
					"override" => "page,post,custom",
					"class" => "match_date",
					"std" => date('Y-m-d'),
					"format" => 'yy-mm-dd',
					"type" => "date"),
				"match_time" => array(
					"title" => esc_html__('Time',  'soccerclub'),
					"desc" => wp_kses_data( __("Match start time", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_time",
					"std" => '',
					"type" => "text"),
				"match_link" => array(
					"title" => esc_html__('Preview link',  'soccerclub'),
					"desc" => wp_kses_data( __("The announcement of the match", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_link",
					"std" => '',
					"type" => "text"),
				"match_score" => array(
					"title" => esc_html__('Score',  'soccerclub'),
					"desc" => wp_kses_data( __("The final score", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_score",
					"std" => '',
					"type" => "text"),
				"match_player_1" => array(
					"title" => esc_html__('First Player',  'soccerclub'),
					"desc" => wp_kses_data( __("Select first player", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_player_1",
					"std" => '',
					"type" => "select",
					"options" => $players),
				"match_points_1" => array(
					"title" => esc_html__('Points for player 1',  'soccerclub'),
					"desc" => wp_kses_data( __("Points per game for the first player", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_points_1",
					"std" => '',
					"type" => "text"),
				"match_player_2" => array(
					"title" => esc_html__('Second Player',  'soccerclub'),
					"desc" => wp_kses_data( __("Select second player", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_player_1",
					"std" => '',
					"type" => "select",
					"options" => $players),
				"match_points_2" => array(
					"title" => esc_html__('Points for player 2',  'soccerclub'),
					"desc" => wp_kses_data( __("Points per game for the second player", 'soccerclub') ),
					"override" => "page,post,custom",
					"class" => "match_points_1",
					"std" => '',
					"type" => "text")
				)
			);
		}
	}
}


// Before save custom options
if (!function_exists('soccerclub_matches_save_custom_options')) {
	//Handler of add_filter('soccerclub_filter_post_save_custom_options',	'soccerclub_matches_save_custom_options', 10, 3);
	function soccerclub_matches_save_custom_options($custom_options, $post_type, $post_id) {
		if (isset($custom_options['match_date'])) {
			// Save match date in the post meta to sort and filter posts
			update_post_meta($post_id, soccerclub_storage_get('options_prefix').'_date_start', $custom_options['match_date'] . (soccerclub_param_is_inherit($custom_options['match_time']) ? '' : ' '.$custom_options['match_time']));
			// Update players points
			$post_meta = get_post_meta($post_id, soccerclub_storage_get('options_prefix') . '_post_options', true);
			$points_1_old = empty($post_meta['match_points_1']) || soccerclub_param_is_inherit($post_meta['match_points_1']) ? 0 : $post_meta['match_points_1'];
			$points_2_old = empty($post_meta['match_points_2']) || soccerclub_param_is_inherit($post_meta['match_points_2']) ? 0 : $post_meta['match_points_2'];
			soccerclub_update_players_points($custom_options['match_player_1'], $custom_options['match_points_1'], $points_1_old);
			soccerclub_update_players_points($custom_options['match_player_2'], $custom_options['match_points_2'], $points_2_old);
		}
		return $custom_options;
	}
}

// Update players meta
if ( !function_exists('soccerclub_update_players_points') ) {
	function soccerclub_update_players_points($player, $points_new, $points_old) {
		$player_obj = (intval($player) > 0 ? get_post($player, OBJECT) : soccerclub_get_page_by_title($player, OBJECT, 'players'));
		if(isset($player_obj->ID)){
		$player_id = $player_obj->ID;
		$points = empty($points_new) || soccerclub_param_is_inherit($points_new) ? 0 : $points_new;
		$sum_points = get_post_meta($player_id, soccerclub_storage_get('options_prefix').'_points', true);
		$sum_points = empty($sum_points) || soccerclub_param_is_inherit($sum_points) ? 0 : $sum_points;
		$points = max(0, $points - $points_old + $sum_points);
		update_post_meta($player_id, soccerclub_storage_get('options_prefix').'_points', $points);
	}
	}
}


// Return true, if current page is matches page
if ( !function_exists( 'soccerclub_is_matches_page' ) ) {
	function soccerclub_is_matches_page() {
		$is = in_array(soccerclub_storage_get('page_template'), array('blog-matches', 'single-match'));
		if (!$is) {
			if (!soccerclub_storage_empty('pre_query'))
				$is = soccerclub_storage_call_obj_method('pre_query', 'get', 'post_type')=='matches'
						|| soccerclub_storage_call_obj_method('pre_query', 'is_tax', 'matches_group') 
						|| (soccerclub_storage_call_obj_method('pre_query', 'is_page') 
							&& ($id=soccerclub_get_template_page_id('blog-matches')) > 0 
							&& $id==soccerclub_storage_get_obj_property('pre_query', 'queried_object_id', 0)
							);
			else
				$is = get_query_var('post_type')=='matches' 
						|| is_tax('matches_group') 
						|| (is_page() && ($id=soccerclub_get_template_page_id('blog-matches')) > 0 && $id==get_the_ID());
		}
		return $is;
	}
}

// Filter to detect current page inheritance key
if ( !function_exists( 'soccerclub_matches_detect_inheritance_key' ) ) {
	//Handler of add_filter('soccerclub_filter_detect_inheritance_key',	'soccerclub_matches_detect_inheritance_key', 9, 1);
	function soccerclub_matches_detect_inheritance_key($key) {
		if (!empty($key)) return $key;
		return soccerclub_is_matches_page() ? 'matches' : '';
	}
}

// Filter to detect current page slug
if ( !function_exists( 'soccerclub_matches_get_blog_type' ) ) {
	//Handler of add_filter('soccerclub_filter_get_blog_type',	'soccerclub_matches_get_blog_type', 9, 2);
	function soccerclub_matches_get_blog_type($page, $query=null) {
		if (!empty($page)) return $page;
		if ($query && $query->is_tax('matches_group') || is_tax('matches_group'))
			$page = 'matches_category';
		else if ($query && $query->get('post_type')=='matches' || get_query_var('post_type')=='matches')
			$page = $query && $query->is_single() || is_single() ? 'match' : 'matches';
		return $page;
	}
}

// Filter to detect current page title
if ( !function_exists( 'soccerclub_matches_get_blog_title' ) ) {
	//Handler of add_filter('soccerclub_filter_get_blog_title',	'soccerclub_matches_get_blog_title', 9, 2);
	function soccerclub_matches_get_blog_title($title, $page) {
		if (!empty($title)) return $title;
		if ( $page == 'archives_day' && get_post_type()=='matches' ) {
			$dt = strtotime(get_post_meta(get_the_ID(), 'date_start', true));
			$title = sprintf( esc_html__( 'Daily Archives: %s', 'soccerclub' ), soccerclub_get_date_translations(date( get_option('date_format'), $dt )) );
		} else if ( $page == 'archives_month' && get_post_type()=='matches' ) {
			$dt = strtotime(get_post_meta(get_the_ID(), 'date_start', true));
			$title = sprintf( esc_html__( 'Monthly Archives: %s', 'soccerclub' ), soccerclub_get_date_translations(date( 'F Y', $dt )) );
		} else if ( $page == 'archives_year' && get_post_type()=='matches' ) {
			$dt = strtotime(get_post_meta(get_the_ID(), 'date_start', true));
			$title = sprintf( esc_html__( 'Yearly Archives: %s', 'soccerclub' ), date( 'Y', $dt ) );
		} else if ( soccerclub_strpos($page, 'matches')!==false ) {
			if ( $page == 'matches_category' ) {
				$term = get_term_by( 'slug', get_query_var( 'matches_group' ), 'matches_group', OBJECT);
				$title = $term->name;
			} else if ( $page == 'match' ) {
				$title = soccerclub_get_post_title();
			} else {
				$title = esc_html__('All matches', 'soccerclub');
			}
		}
		return $title;
	}
}

// Filter to detect stream page title
if ( !function_exists( 'soccerclub_matches_get_stream_page_title' ) ) {
	//Handler of add_filter('soccerclub_filter_get_stream_page_title',	'soccerclub_matches_get_stream_page_title', 9, 2);
	function soccerclub_matches_get_stream_page_title($title, $page) {
		if (!empty($title)) return $title;
		if (soccerclub_strpos($page, 'matches')!==false) {
			if (($page_id = soccerclub_matches_get_stream_page_id(0, $page=='matches' ? 'blog-matches' : $page)) > 0)
				$title = soccerclub_get_post_title($page_id);
			else
				$title = esc_html__('All matches', 'soccerclub');				
		}
		return $title;
	}
}

// Filter to detect stream page ID
if ( !function_exists( 'soccerclub_matches_get_stream_page_id' ) ) {
	//Handler of add_filter('soccerclub_filter_get_stream_page_id',	'soccerclub_matches_get_stream_page_id', 9, 2);
	function soccerclub_matches_get_stream_page_id($id, $page) {
		if (!empty($id)) return $id;
		if (soccerclub_strpos($page, 'matches')!==false) $id = soccerclub_get_template_page_id('blog-matches');
		return $id;
	}
}

// Filter to detect stream page URL
if ( !function_exists( 'soccerclub_matches_get_stream_page_link' ) ) {
	//Handler of add_filter('soccerclub_filter_get_stream_page_link',	'soccerclub_matches_get_stream_page_link', 9, 2);
	function soccerclub_matches_get_stream_page_link($url, $page) {
		if (!empty($url)) return $url;
		if (soccerclub_strpos($page, 'matches')!==false) {
			$id = soccerclub_get_template_page_id('blog-matches');
			if ($id) $url = get_permalink($id);
		}
		return $url;
	}
}

// Filter to detect current taxonomy
if ( !function_exists( 'soccerclub_matches_get_current_taxonomy' ) ) {
	//Handler of add_filter('soccerclub_filter_get_current_taxonomy',	'soccerclub_matches_get_current_taxonomy', 9, 2);
	function soccerclub_matches_get_current_taxonomy($tax, $page) {
		if (!empty($tax)) return $tax;
		if ( soccerclub_strpos($page, 'matches')!==false ) {
			$tax = 'matches_group';
		}
		return $tax;
	}
}

// Return taxonomy name (slug) if current page is this taxonomy page
if ( !function_exists( 'soccerclub_matches_is_taxonomy' ) ) {
	//Handler of add_filter('soccerclub_filter_is_taxonomy',	'soccerclub_matches_is_taxonomy', 9, 2);
	function soccerclub_matches_is_taxonomy($tax, $query=null) {
		if (!empty($tax))
			return $tax;
		else 
			return $query && $query->get('matches_group')!='' || is_tax('matches_group') ? 'matches_group' : '';
	}
}

// Filter to return breadcrumbs links to the parent period
if ( !function_exists( 'soccerclub_matches_get_period_links' ) ) {
	//Handler of add_filter('soccerclub_filter_get_period_links',	'soccerclub_matches_get_period_links', 9, 3);
	function soccerclub_matches_get_period_links($links, $page, $delimiter='') {
		if (!empty($links)) return $links;
		global $post;
		if (in_array($page, array('archives_day', 'archives_month')) && is_object($post) && get_post_type()=='matches') {
			$dt = strtotime(get_post_meta(get_the_ID(), soccerclub_storage_get('options_prefix').'_date_start', true));
			$year  = date('Y', $dt); 
			$month = date('m', $dt); 
			$links = '<a class="breadcrumbs_item cat_parent" href="' . esc_url(get_year_link( $year )) . '">' . ($year) . '</a>';
			if ($page == 'archives_day')
				$links .= (!empty($links) ? $delimiter : '') . '<a class="breadcrumbs_item cat_parent" href="' . esc_url(get_month_link( $year, $month )) . '">' . trim(soccerclub_get_date_translations(date('F', $dt))) . '</a>';
		}
		return $links;
	}
}

// Add custom post type and/or taxonomies arguments to the query
if ( !function_exists( 'soccerclub_matches_query_add_filters' ) ) {
	//Handler of add_filter('soccerclub_filter_query_add_filters',	'soccerclub_matches_query_add_filters', 9, 2);
	function soccerclub_matches_query_add_filters($args, $filter) {
		if ($filter == 'matches') {
			$args['post_type'] = 'matches';
		}
		return $args;
	}
}

// Add custom post type into list
if ( !function_exists( 'soccerclub_matches_list_post_types' ) ) {
	//Handler of add_filter('soccerclub_filter_list_post_types', 	'soccerclub_matches_list_post_types', 10, 1);
	function soccerclub_matches_list_post_types($list) {
			$list['matches'] = esc_html__('Matches', 'soccerclub');
		return $list;
	}
}


// Return previous month and year with published posts
if ( !function_exists( 'soccerclub_matches_calendar_get_prev_month' ) ) {
	//Handler of add_filter('soccerclub_filter_calendar_get_prev_month',	'soccerclub_matches_calendar_get_prev_month', 9, 2);
	function soccerclub_matches_calendar_get_prev_month($prev, $opt) {
		if (!empty($opt['posts_types']) && !in_array('matches', $opt['posts_types'])) return $prev;
		if (!empty($prev['done']) && in_array('matches', $prev['done'])) return $prev;
		$args = array(
			'post_type' => 'matches',
			'post_status' => current_user_can('read_private_pages') && current_user_can('read_private_posts') ? array('publish', 'private') : 'publish',
			'posts_per_page' => 1,
			'ignore_sticky_posts' => true,
			'orderby' => 'meta_value',
			'meta_key' => soccerclub_storage_get('options_prefix').'_date_start',
			'order' => 'desc',
			'meta_query' => array(
				array(
					'key' => soccerclub_storage_get('options_prefix').'_date_start',
					'value' => ($opt['year']).'-'.($opt['month']).'-01',
					'compare' => '<',
					'type' => 'DATE'
				)
			)
		);
		$q = new WP_Query($args);
		$month = $year = 0;
		if ($q->have_posts()) {
			while ($q->have_posts()) { $q->the_post();
				$dt = strtotime(get_post_meta(get_the_ID(), soccerclub_storage_get('options_prefix').'_date_start', true));
				$year  = date('Y', $dt);
				$month = date('m', $dt);
			}
			wp_reset_postdata();
		}
		if (empty($prev) || ($year+$month>0 && ($prev['year']+$prev['month']==0 || ($prev['year']).($prev['month']) < ($year).($month)))) {
			$prev['year'] = $year;
			$prev['month'] = $month;
		}
		if (empty($prev['done'])) $prev['done'] = array();
		$prev['done'][] = 'matches';
		return $prev;
	}
}

// Return next month and year with published posts
if ( !function_exists( 'soccerclub_matches_calendar_get_next_month' ) ) {
	//Handler of add_filter('soccerclub_filter_calendar_get_next_month',	'soccerclub_matches_calendar_get_next_month', 9, 2);
	function soccerclub_matches_calendar_get_next_month($next, $opt) {
		if (!empty($opt['posts_types']) && !in_array('matches', $opt['posts_types'])) return $next;
		if (!empty($next['done']) && in_array('matches', $next['done'])) return $next;
		$args = array(
			'post_type' => 'matches',
			'post_status' => current_user_can('read_private_pages') && current_user_can('read_private_posts') ? array('publish', 'private') : 'publish',
			'posts_per_page' => 1,
			'ignore_sticky_posts' => true,
			'orderby' => 'meta_value',
			'meta_key' => soccerclub_storage_get('options_prefix').'_date_start',
			'order' => 'asc',
			'meta_query' => array(
				array(
					'key' => soccerclub_storage_get('options_prefix').'_date_start',
					'value' => ($opt['year']).'-'.($opt['month']).'-'.($opt['last_day']).' 23:59:59',
					'compare' => '>',
					'type' => 'DATE'
				)
			)
		);
		$q = new WP_Query($args);
		$month = $year = 0;
		if ($q->have_posts()) {
			while ($q->have_posts()) { $q->the_post();
				$dt = strtotime(get_post_meta(get_the_ID(), soccerclub_storage_get('options_prefix').'_date_start', true));
				$year  = date('Y', $dt);
				$month = date('m', $dt);
			}
			wp_reset_postdata();
		}
		if (empty($next) || ($year+$month>0 && ($next['year']+$next['month']==0 || ($next['year']).($next['month']) > ($year).($month)))) {
			$next['year'] = $year;
			$next['month'] = $month;
		}
		if (empty($next['done'])) $next['done'] = array();
		$next['done'][] = 'matches';
		return $next;
	}
}

// Return current month published posts
if ( !function_exists( 'soccerclub_matches_calendar_get_curr_month_posts' ) ) {
	//Handler of add_filter('soccerclub_filter_calendar_get_curr_month_posts',	'soccerclub_matches_calendar_get_curr_month_posts', 9, 2);
	function soccerclub_matches_calendar_get_curr_month_posts($posts, $opt) {
		if (!empty($opt['posts_types']) && !in_array('matches', $opt['posts_types'])) return $posts;
		if (!empty($posts['done']) && in_array('matches', $posts['done'])) return $posts;
		$args = array(
			'post_type' => 'matches',
			'post_status' => current_user_can('read_private_pages') && current_user_can('read_private_posts') ? array('publish', 'private') : 'publish',
			'posts_per_page' => -1,
			'ignore_sticky_posts' => true,
			'orderby' => 'meta_value',
			'order' => 'asc',
			'meta_query' => array(
				array(
					'key' => soccerclub_storage_get('options_prefix').'_date_start',
					'value' => array(($opt['year']).'-'.($opt['month']).'-01', ($opt['year']).'-'.($opt['month']).'-'.($opt['last_day']).' 23:59:59'),
					'compare' => 'BETWEEN',
					'type' => 'DATE'
				)
			)
		);
		$q = new WP_Query($args);
		if ($q->have_posts()) {
			if (empty($posts)) $posts = array();
			while ($q->have_posts()) { $q->the_post();
				$dt = strtotime(get_post_meta(get_the_ID(), soccerclub_storage_get('options_prefix').'_date_start', true));
				$day = (int) date('d', $dt);
				$title = apply_filters('the_title', get_the_title());
				if (empty($posts[$day])) 
					$posts[$day] = array();
				if (empty($posts[$day]['link']) && count($opt['posts_types'])==1)
					$posts[$day]['link'] = get_day_link($opt['year'], $opt['month'], $day);
				if (empty($posts[$day]['titles']))
					$posts[$day]['titles'] = $title;
				else
					$posts[$day]['titles'] = is_int($posts[$day]['titles']) ? $posts[$day]['titles']+1 : 2;
				if (empty($posts[$day]['posts'])) $posts[$day]['posts'] = array();
				$posts[$day]['posts'][] = array(
					'post_id' => get_the_ID(),
					'post_type' => get_post_type(),
					'post_date' => date(get_option('date_format'), $dt),
					'post_title' => $title,
					'post_link' => get_permalink()
				);
			}
			wp_reset_postdata();
		}
		if (empty($posts['done'])) $posts['done'] = array();
		$posts['done'][] = 'matches';
		return $posts;
	}
}

// Pre query: Join tables into main query
if ( !function_exists( 'soccerclub_matches_posts_join' ) ) {
	//Handler of add_action( 'posts_join', 'soccerclub_matches_posts_join', 10, 2 );
	function soccerclub_matches_posts_join($join_sql, $query) {
		if (!is_admin() && $query->is_main_query()) {
			if ($query->is_day || $query->is_month || $query->is_year) {
				global $wpdb;
				$join_sql .= $wpdb->prepare(" LEFT JOIN {$wpdb->postmeta} AS _matches_meta ON {$wpdb->posts}.ID = _matches_meta.post_id AND  _matches_meta.meta_key = %s", soccerclub_storage_get('options_prefix')."date_start");
			}
		}
		return $join_sql;
	}
}

// Pre query: Join tables into archives widget query
if ( !function_exists( 'soccerclub_matches_getarchives_join' ) ) {
	//Handler of add_action( 'getarchives_join', 'soccerclub_matches_getarchives_join', 10, 2 );
	function soccerclub_matches_getarchives_join($join_sql, $r) {
		global $wpdb;
		$join_sql .= $wpdb->prepare(" LEFT JOIN {$wpdb->postmeta} AS _matches_meta ON {$wpdb->posts}.ID = _matches_meta.post_id AND  _matches_meta.meta_key = %s", soccerclub_storage_get('options_prefix')."date_start");
		return $join_sql;
	}
}

// Pre query: Where section into main query
if ( !function_exists( 'soccerclub_matches_posts_where' ) ) {
	//Handler of add_action( 'posts_where', 'soccerclub_matches_posts_where', 10, 2 );
	function soccerclub_matches_posts_where($where_sql, $query) {
		if (!is_admin() && $query->is_main_query()) {
			if ($query->is_day || $query->is_month || $query->is_year) {
				global $wpdb;
				$add_sql = "";
				// Posts status
				if ((!isset($_REQUEST['preview']) || $_REQUEST['preview']!='true') && (!isset($_REQUEST['vc_editable']) || $_REQUEST['vc_editable']!='true')) {
					if (current_user_can('read_private_pages') && current_user_can('read_private_posts'))
						$add_sql .= " AND ({$wpdb->posts}.post_status='publish' OR {$wpdb->posts}.post_status='private')";
					else
						$add_sql .= " AND {$wpdb->posts}.post_status='publish'";
				}
				// Posts type and date
				$dt = $query->get('m');
				$y = $query->get('year');
				if (empty($y)) $y = (int) soccerclub_substr($dt, 0, 4);
				$add_sql .= $wpdb->prepare(" AND {$wpdb->posts}.post_type='matches' AND YEAR(_matches_meta.meta_value)=%d", $y);
				if ($query->is_month || $query->is_day) {
					$m = $query->get('monthnum');
					if (empty($m)) $m = (int) soccerclub_substr($dt, 4, 2);
					$add_sql .= $wpdb->prepare(" AND MONTH(_matches_meta.meta_value)=%d", $m);
				}
				if ($query->is_day) {
					$d = $query->get('day');
					if (empty($d)) $d = (int) soccerclub_substr($dt, 6, 2);
					$add_sql .= $wpdb->prepare(" AND DAYOFMONTH(_matches_meta.meta_value)=%d", $d);
				}
				if ( !empty($add_sql)) $where_sql .= " OR ({$add_sql})";
			}
		}
		return $where_sql;
	}
}

// Pre query: Where section into archives widget query
if ( !function_exists( 'soccerclub_matches_getarchives_where' ) ) {
	//Handler of add_action( 'getarchives_where', 'soccerclub_matches_getarchives_where', 10, 2 );
	function soccerclub_matches_getarchives_where($where_sql, $r) {
		global $wpdb;
		// Posts type and date
		$where_sql .= " OR {$wpdb->posts}.post_type='matches'";
		return $where_sql;
	}
}

// Return courses start date instead post publish date
if ( !function_exists( 'soccerclub_matches_post_date' ) ) {
	//Handler of add_filter('soccerclub_filter_post_date', 'soccerclub_matches_post_date', 9, 3);
	function soccerclub_matches_post_date($post_date, $post_id, $post_type) {
		if ($post_type == 'matches') {
			$match_date = get_post_meta($post_id, soccerclub_storage_get('options_prefix').'_date_start', true);
			if (!empty($match_date) && !soccerclub_param_is_inherit($match_date))
				$post_date = $match_date;
		}
		return $post_date;
	}
}


// Get nearest match
if ( !function_exists('soccerclub_nearest_match') ) {
	//Handler of add_action( 'soccerclub_nearest_match', 'soccerclub_nearest_match' );
	function soccerclub_nearest_match($ids, $count, $numb){
		$new_array = array();
		$current = array_search ('0', $ids); 
		$key = $current; 
		$i = 0;
		$interval = $count / 2;
		if($count % 2 != 0) $interval = ($count + 1) / 2;
		$interval_prev = $interval_next = $interval;
		
		if($key - $interval < 0){
			$interval_prev = $interval + ($key - $interval);
			$interval_next = $interval - ($key - $interval);
		}
		if($numb < $key + $interval){
			if($numb == $key){
				$interval_next = 0;
				$interval_prev = $count;
			}
			else{
				$interval_next = $interval;
				$interval_prev = $interval;

				if ($interval > $numb - $key ) {
					$interval_next = $numb - $key;
					$interval_prev = $interval + ($interval - $interval_next);
				}
			}
		}
		
		$index = 0;
		for($i = $key - $interval_prev; $i < $key; $i++){
			if( array_key_exists( $i , $ids ) ){
				$new_array[$index] = $ids[$i];
				$index++;
			}			
		}
		for($i = $key + 1; $i <= $key + $interval_next; $i++){
			if( array_key_exists( $i , $ids ) ){
				$new_array[$index] = $ids[$i];
				$index++;
			}			
		}
		
		return	$new_array;
	}
}

// Return list with countries
if ( !function_exists( 'soccerclub_get_list_countries' ) ) {
	function soccerclub_get_list_countries($prepend_inherit=false, $index=-1) {
		$list = array(
			"Afghanistan" => esc_html__("Afghanistan", 'soccerclub'),
			"Albania" => esc_html__("Albania", 'soccerclub'),
			"Algeria" => esc_html__("Algeria", 'soccerclub'),
			"American Samoa" => esc_html__("American Samoa", 'soccerclub'),
			"Andorra" => esc_html__("Andorra", 'soccerclub'),
			"Angola" => esc_html__("Angola", 'soccerclub'),
			"Anguilla" => esc_html__("Anguilla", 'soccerclub'),
			"Antarctica" => esc_html__("Antarctica", 'soccerclub'),
			"Antigua and Barbuda" => esc_html__("Antigua and Barbuda", 'soccerclub'),
			"Argentina" => esc_html__("Argentina", 'soccerclub'),
			"Armenia" => esc_html__("Armenia", 'soccerclub'),
			"Aruba" => esc_html__("Aruba", 'soccerclub'),
			"Australia" => esc_html__("Australia", 'soccerclub'),
			"Austria" => esc_html__("Austria", 'soccerclub'),
			"Azerbaijan" => esc_html__("Azerbaijan", 'soccerclub'),
			"Bahamas" => esc_html__("Bahamas", 'soccerclub'),
			"Bahrain" => esc_html__("Bahrain", 'soccerclub'),
			"Bangladesh" => esc_html__("Bangladesh", 'soccerclub'),
			"Barbados" => esc_html__("Barbados", 'soccerclub'),
			"Belarus" => esc_html__("Belarus", 'soccerclub'),
			"Belgium" => esc_html__("Belgium", 'soccerclub'),
			"Belize" => esc_html__("Belize", 'soccerclub'),
			"Benin" => esc_html__("Benin", 'soccerclub'),
			"Bermuda" => esc_html__("Bermuda", 'soccerclub'),
			"Bhutan" => esc_html__("Bhutan", 'soccerclub'),
			"Bolivia" => esc_html__("Bolivia", 'soccerclub'),
			"Bosnia and Herzegovina" => esc_html__("Bosnia and Herzegovina", 'soccerclub'),
			"Botswana" => esc_html__("Botswana", 'soccerclub'),
			"Bouvet Island" => esc_html__("Bouvet Island", 'soccerclub'),
			"Brazil" => esc_html__("Brazil", 'soccerclub'),
			"British Antarctic Territory" => esc_html__("British Antarctic Territory", 'soccerclub'),
			"British Indian Ocean Territory" => esc_html__("British Indian Ocean Territory", 'soccerclub'),
			"British Virgin Islands" => esc_html__("British Virgin Islands", 'soccerclub'),
			"Brunei" => esc_html__("Brunei", 'soccerclub'),
			"Bulgaria" => esc_html__("Bulgaria", 'soccerclub'),
			"Burkina Faso" => esc_html__("Burkina Faso", 'soccerclub'),
			"Burundi" => esc_html__("Burundi", 'soccerclub'),
			"Cambodia" => esc_html__("Cambodia", 'soccerclub'),
			"Cameroon" => esc_html__("Cameroon", 'soccerclub'),
			"Canada" => esc_html__("Canada", 'soccerclub'),
			"Canton and Enderbury Islands" => esc_html__("Canton and Enderbury Islands", 'soccerclub'),
			"Cape Verde" => esc_html__("Cape Verde", 'soccerclub'),
			"Cayman Islands" => esc_html__("Cayman Islands", 'soccerclub'),
			"Central African Republic" => esc_html__("Central African Republic", 'soccerclub'),
			"Chad" => esc_html__("Chad", 'soccerclub'),
			"Chile" => esc_html__("Chile", 'soccerclub'),
			"China" => esc_html__("China", 'soccerclub'),
			"Christmas Island" => esc_html__("Christmas Island", 'soccerclub'),
			"Cocos [Keeling] Islands" => esc_html__("Cocos [Keeling] Islands", 'soccerclub'),
			"Colombia" => esc_html__("Colombia", 'soccerclub'),
			"Comoros" => esc_html__("Comoros", 'soccerclub'),
			"Congo - Brazzaville" => esc_html__("Congo - Brazzaville", 'soccerclub'),
			"Congo - Kinshasa" => esc_html__("Congo - Kinshasa", 'soccerclub'),
			"Cook Islands" => esc_html__("Cook Islands", 'soccerclub'),
			"Costa Rica" => esc_html__("Costa Rica", 'soccerclub'),
			"Croatia" => esc_html__("Croatia", 'soccerclub'),
			"Cuba" => esc_html__("Cuba", 'soccerclub'),
			"Cyprus" => esc_html__("Cyprus", 'soccerclub'),
			"Czech Republic" => esc_html__("Czech Republic", 'soccerclub'),
			"Cote d'Ivoire" => esc_html__("Cote d'Ivoire", 'soccerclub'),
			"Denmark" => esc_html__("Denmark", 'soccerclub'),
			"Djibouti" => esc_html__("Djibouti", 'soccerclub'),
			"Dominica" => esc_html__("Dominica", 'soccerclub'),
			"Dominican Republic" => esc_html__("Dominican Republic", 'soccerclub'),
			"Dronning Maud Land" => esc_html__("Dronning Maud Land", 'soccerclub'),
			"East Germany" => esc_html__("East Germany", 'soccerclub'),
			"Ecuador" => esc_html__("Ecuador", 'soccerclub'),
			"Egypt" => esc_html__("Egypt", 'soccerclub'),
			"El Salvador" => esc_html__("El Salvador", 'soccerclub'),
			"Equatorial Guinea" => esc_html__("Equatorial Guinea", 'soccerclub'),
			"Eritrea" => esc_html__("Eritrea", 'soccerclub'),
			"Estonia" => esc_html__("Estonia", 'soccerclub'),
			"Ethiopia" => esc_html__("Ethiopia", 'soccerclub'),
			"Falkland Islands" => esc_html__("Falkland Islands", 'soccerclub'),
			"Faroe Islands" => esc_html__("Faroe Islands", 'soccerclub'),
			"Fiji" => esc_html__("Fiji", 'soccerclub'),
			"Finland" => esc_html__("Finland", 'soccerclub'),
			"France" => esc_html__("France", 'soccerclub'),
			"French Guiana" => esc_html__("French Guiana", 'soccerclub'),
			"French Polynesia" => esc_html__("French Polynesia", 'soccerclub'),
			"French Southern Territories" => esc_html__("French Southern Territories", 'soccerclub'),
			"French Southern and Antarctic Territories" => esc_html__("French Southern and Antarctic Territories", 'soccerclub'),
			"Gabon" => esc_html__("Gabon", 'soccerclub'),
			"Gambia" => esc_html__("Gambia", 'soccerclub'),
			"Georgia" => esc_html__("Georgia", 'soccerclub'),
			"Germany" => esc_html__("Germany", 'soccerclub'),
			"Ghana" => esc_html__("Ghana", 'soccerclub'),
			"Gibraltar" => esc_html__("Gibraltar", 'soccerclub'),
			"Greece" => esc_html__("Greece", 'soccerclub'),
			"Greenland" => esc_html__("Greenland", 'soccerclub'),
			"Grenada" => esc_html__("Grenada", 'soccerclub'),
			"Guadeloupe" => esc_html__("Guadeloupe", 'soccerclub'),
			"Guam" => esc_html__("Guam", 'soccerclub'),
			"Guatemala" => esc_html__("Guatemala", 'soccerclub'),
			"Guernsey" => esc_html__("Guernsey", 'soccerclub'),
			"Guinea" => esc_html__("Guinea", 'soccerclub'),
			"Guinea-Bissau" => esc_html__("Guinea-Bissau", 'soccerclub'),
			"Guyana" => esc_html__("Guyana", 'soccerclub'),
			"Haiti" => esc_html__("Haiti", 'soccerclub'),
			"Heard Island and McDonald Islands" => esc_html__("Heard Island and McDonald Islands", 'soccerclub'),
			"Honduras" => esc_html__("Honduras", 'soccerclub'),
			"Hong Kong SAR China" => esc_html__("Hong Kong SAR China", 'soccerclub'),
			"Hungary" => esc_html__("Hungary", 'soccerclub'),
			"Iceland" => esc_html__("Iceland", 'soccerclub'),
			"India" => esc_html__("India", 'soccerclub'),
			"Indonesia" => esc_html__("Indonesia", 'soccerclub'),
			"Iran" => esc_html__("Iran", 'soccerclub'),
			"Iraq" => esc_html__("Iraq", 'soccerclub'),
			"Ireland" => esc_html__("Ireland", 'soccerclub'),
			"Isle of Man" => esc_html__("Isle of Man", 'soccerclub'),
			"Israel" => esc_html__("Israel", 'soccerclub'),
			"Italy" => esc_html__("Italy", 'soccerclub'),
			"Jamaica" => esc_html__("Jamaica", 'soccerclub'),
			"Japan" => esc_html__("Japan", 'soccerclub'),
			"Jersey" => esc_html__("Jersey", 'soccerclub'),
			"Johnston Island" => esc_html__("Johnston Island", 'soccerclub'),
			"Jordan" => esc_html__("Jordan", 'soccerclub'),
			"Kazakhstan" => esc_html__("Kazakhstan", 'soccerclub'),
			"Kenya" => esc_html__("Kenya", 'soccerclub'),
			"Kiribati" => esc_html__("Kiribati", 'soccerclub'),
			"Kuwait" => esc_html__("Kuwait", 'soccerclub'),
			"Kyrgyzstan" => esc_html__("Kyrgyzstan", 'soccerclub'),
			"Laos" => esc_html__("Laos", 'soccerclub'),
			"Latvia" => esc_html__("Latvia", 'soccerclub'),
			"Lebanon" => esc_html__("Lebanon", 'soccerclub'),
			"Lesotho" => esc_html__("Lesotho", 'soccerclub'),
			"Liberia" => esc_html__("Liberia", 'soccerclub'),
			"Libya" => esc_html__("Libya", 'soccerclub'),
			"Liechtenstein" => esc_html__("Liechtenstein", 'soccerclub'),
			"Lithuania" => esc_html__("Lithuania", 'soccerclub'),
			"Luxembourg" => esc_html__("Luxembourg", 'soccerclub'),
			"Macau SAR China" => esc_html__("Macau SAR China", 'soccerclub'),
			"Macedonia" => esc_html__("Macedonia", 'soccerclub'),
			"Madagascar" => esc_html__("Madagascar", 'soccerclub'),
			"Malawi" => esc_html__("Malawi", 'soccerclub'),
			"Malaysia" => esc_html__("Malaysia", 'soccerclub'),
			"Maldives" => esc_html__("Maldives", 'soccerclub'),
			"Mali" => esc_html__("Mali", 'soccerclub'),
			"Malta" => esc_html__("Malta", 'soccerclub'),
			"Marshall Islands" => esc_html__("Marshall Islands", 'soccerclub'),
			"Martinique" => esc_html__("Martinique", 'soccerclub'),
			"Mauritania" => esc_html__("Mauritania", 'soccerclub'),
			"Mauritius" => esc_html__("Mauritius", 'soccerclub'),
			"Mayotte" => esc_html__("Mayotte", 'soccerclub'),
			"Metropolitan France" => esc_html__("Metropolitan France", 'soccerclub'),
			"Mexico" => esc_html__("Mexico", 'soccerclub'),
			"Micronesia" => esc_html__("Micronesia", 'soccerclub'),
			"Midway Islands" => esc_html__("Midway Islands", 'soccerclub'),
			"Moldova" => esc_html__("Moldova", 'soccerclub'),
			"Monaco" => esc_html__("Monaco", 'soccerclub'),
			"Mongolia" => esc_html__("Mongolia", 'soccerclub'),
			"Montenegro" => esc_html__("Montenegro", 'soccerclub'),
			"Montserrat" => esc_html__("Montserrat", 'soccerclub'),
			"Morocco" => esc_html__("Morocco", 'soccerclub'),
			"Mozambique" => esc_html__("Mozambique", 'soccerclub'),
			"Myanmar [Burma]" => esc_html__("Myanmar [Burma]", 'soccerclub'),
			"Namibia" => esc_html__("Namibia", 'soccerclub'),
			"Nauru" => esc_html__("Nauru", 'soccerclub'),
			"Nepal" => esc_html__("Nepal", 'soccerclub'),
			"Netherlands" => esc_html__("Netherlands", 'soccerclub'),
			"Netherlands Antilles" => esc_html__("Netherlands Antilles", 'soccerclub'),
			"Neutral Zone" => esc_html__("Neutral Zone", 'soccerclub'),
			"New Caledonia" => esc_html__("New Caledonia", 'soccerclub'),
			"New Zealand" => esc_html__("New Zealand", 'soccerclub'),
			"Nicaragua" => esc_html__("Nicaragua", 'soccerclub'),
			"Niger" => esc_html__("Niger", 'soccerclub'),
			"Nigeria" => esc_html__("Nigeria", 'soccerclub'),
			"Niue" => esc_html__("Niue", 'soccerclub'),
			"Norfolk Island" => esc_html__("Norfolk Island", 'soccerclub'),
			"North Korea" => esc_html__("North Korea", 'soccerclub'),
			"North Vietnam" => esc_html__("North Vietnam", 'soccerclub'),
			"Northern Mariana Islands" => esc_html__("Northern Mariana Islands", 'soccerclub'),
			"Norway" => esc_html__("Norway", 'soccerclub'),
			"Oman" => esc_html__("Oman", 'soccerclub'),
			"Pacific Islands Trust Territory" => esc_html__("Pacific Islands Trust Territory", 'soccerclub'),
			"Pakistan" => esc_html__("Pakistan", 'soccerclub'),
			"Palau" => esc_html__("Palau", 'soccerclub'),
			"Palestinian Territories" => esc_html__("Palestinian Territories", 'soccerclub'),
			"Panama" => esc_html__("Panama", 'soccerclub'),
			"Panama Canal Zone" => esc_html__("Panama Canal Zone", 'soccerclub'),
			"Papua New Guinea" => esc_html__("Papua New Guinea", 'soccerclub'),
			"Paraguay" => esc_html__("Paraguay", 'soccerclub'),
			"People's Democratic Republic of Yemen" => esc_html__("People's Democratic Republic of Yemen", 'soccerclub'),
			"Peru" => esc_html__("Peru", 'soccerclub'),
			"Philippines" => esc_html__("Philippines", 'soccerclub'),
			"Pitcairn Islands" => esc_html__("Pitcairn Islands", 'soccerclub'),
			"Poland" => esc_html__("Poland", 'soccerclub'),
			"Portugal" => esc_html__("Portugal", 'soccerclub'),
			"Puerto Rico" => esc_html__("Puerto Rico", 'soccerclub'),
			"Qatar" => esc_html__("Qatar", 'soccerclub'),
			"Romania" => esc_html__("Romania", 'soccerclub'),
			"Russia" => esc_html__("Russia", 'soccerclub'),
			"Rwanda" => esc_html__("Rwanda", 'soccerclub'),
			"Reunion" => esc_html__("Reunion", 'soccerclub'),
			"Saint Barthelemy" => esc_html__("Saint Barthelemy", 'soccerclub'),
			"Saint Helena" => esc_html__("Saint Helena", 'soccerclub'),
			"Saint Kitts and Nevis" => esc_html__("Saint Kitts and Nevis", 'soccerclub'),
			"Saint Lucia" => esc_html__("Saint Lucia", 'soccerclub'),
			"Saint Martin" => esc_html__("Saint Martin", 'soccerclub'),
			"Saint Pierre and Miquelon" => esc_html__("Saint Pierre and Miquelon", 'soccerclub'),
			"Saint Vincent and the Grenadines" => esc_html__("Saint Vincent and the Grenadines", 'soccerclub'),
			"Samoa" => esc_html__("Samoa", 'soccerclub'),
			"San Marino" => esc_html__("San Marino", 'soccerclub'),
			"Saudi Arabia" => esc_html__("Saudi Arabia", 'soccerclub'),
			"Senegal" => esc_html__("Senegal", 'soccerclub'),
			"Serbia" => esc_html__("Serbia", 'soccerclub'),
			"Serbia and Montenegro" => esc_html__("Serbia and Montenegro", 'soccerclub'),
			"Seychelles" => esc_html__("Seychelles", 'soccerclub'),
			"Sierra Leone" => esc_html__("Sierra Leone", 'soccerclub'),
			"Singapore" => esc_html__("Singapore", 'soccerclub'),
			"Slovakia" => esc_html__("Slovakia", 'soccerclub'),
			"Slovenia" => esc_html__("Slovenia", 'soccerclub'),
			"Solomon Islands" => esc_html__("Solomon Islands", 'soccerclub'),
			"Somalia" => esc_html__("Somalia", 'soccerclub'),
			"South Africa" => esc_html__("South Africa", 'soccerclub'),
			"South Georgia and the South Sandwich Islands" => esc_html__("South Georgia and the South Sandwich Islands", 'soccerclub'),
			"South Korea" => esc_html__("South Korea", 'soccerclub'),
			"Spain" => esc_html__("Spain", 'soccerclub'),
			"Sri Lanka" => esc_html__("Sri Lanka", 'soccerclub'),
			"Sudan" => esc_html__("Sudan", 'soccerclub'),
			"Suriname" => esc_html__("Suriname", 'soccerclub'),
			"Svalbard and Jan Mayen" => esc_html__("Svalbard and Jan Mayen", 'soccerclub'),
			"Swaziland" => esc_html__("Swaziland", 'soccerclub'),
			"Sweden" => esc_html__("Sweden", 'soccerclub'),
			"Switzerland" => esc_html__("Switzerland", 'soccerclub'),
			"Syria" => esc_html__("Syria", 'soccerclub'),
			"Sao Tome and Principe" => esc_html__("Sao Tome and Principe", 'soccerclub'),
			"Taiwan" => esc_html__("Taiwan", 'soccerclub'),
			"Tajikistan" => esc_html__("Tajikistan", 'soccerclub'),
			"Tanzania" => esc_html__("Tanzania", 'soccerclub'),
			"Thailand" => esc_html__("Thailand", 'soccerclub'),
			"Timor-Leste" => esc_html__("Timor-Leste", 'soccerclub'),
			"Togo" => esc_html__("Togo", 'soccerclub'),
			"Tokelau" => esc_html__("Tokelau", 'soccerclub'),
			"Tonga" => esc_html__("Tonga", 'soccerclub'),
			"Trinidad and Tobago" => esc_html__("Trinidad and Tobago", 'soccerclub'),
			"Tunisia" => esc_html__("Tunisia", 'soccerclub'),
			"Turkey" => esc_html__("Turkey", 'soccerclub'),
			"Turkmenistan" => esc_html__("Turkmenistan", 'soccerclub'),
			"Turks and Caicos Islands" => esc_html__("Turks and Caicos Islands", 'soccerclub'),
			"Tuvalu" => esc_html__("Tuvalu", 'soccerclub'),
			"U.S. Minor Outlying Islands" => esc_html__("U.S. Minor Outlying Islands", 'soccerclub'),
			"U.S. Miscellaneous Pacific Islands" => esc_html__("U.S. Miscellaneous Pacific Islands", 'soccerclub'),
			"U.S. Virgin Islands" => esc_html__("U.S. Virgin Islands", 'soccerclub'),
			"Uganda" => esc_html__("Uganda", 'soccerclub'),
			"Ukraine" => esc_html__("Ukraine", 'soccerclub'),
			"Union of Soviet Socialist Republics" => esc_html__("Union of Soviet Socialist Republics", 'soccerclub'),
			"United Arab Emirates" => esc_html__("United Arab Emirates", 'soccerclub'),
			"United Kingdom" => esc_html__("United Kingdom", 'soccerclub'),
			"United States" => esc_html__("United States", 'soccerclub'),
			"Unknown or Invalid Region" => esc_html__("Unknown or Invalid Region", 'soccerclub'),
			"Uruguay" => esc_html__("Uruguay", 'soccerclub'),
			"Uzbekistan" => esc_html__("Uzbekistan", 'soccerclub'),
			"Vanuatu" => esc_html__("Vanuatu", 'soccerclub'),
			"Vatican City" => esc_html__("Vatican City", 'soccerclub'),
			"Venezuela" => esc_html__("Venezuela", 'soccerclub'),
			"Vietnam" => esc_html__("Vietnam", 'soccerclub'),
			"Wake Island" => esc_html__("Wake Island", 'soccerclub'),
			"Wallis and Futuna" => esc_html__("Wallis and Futuna", 'soccerclub'),
			"Western Sahara" => esc_html__("Western Sahara", 'soccerclub'),
			"Yemen" => esc_html__("Yemen", 'soccerclub'),
			"Zambia" => esc_html__("Zambia", 'soccerclub'),
			"Zimbabwe" => esc_html__("Zimbabwe", 'soccerclub'),
			"Aland Islands" => esc_html__("Aland Islands", 'soccerclub')
		);
		if (empty($index) || $index < 0){
			return $prepend_inherit ? soccerclub_array_merge(array('inherit' => esc_html__("Inherit", 'soccerclub')), $list) : $list;
		} else {
			return $list[$index];
		}
	}
}
?>
