<?php

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }


/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'soccerclub_template_single_team_theme_setup' ) ) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_template_single_team_theme_setup', 1 );
	function soccerclub_template_single_team_theme_setup() {
		soccerclub_add_template(array(
			'layout' => 'single-team',
			'mode'   => 'team',
			'need_content' => true,
			'need_terms' => true,
			'title'  => esc_html__('Single Team member', 'soccerclub'),
			'thumb_title'  => esc_html__('Large image (crop) single-team', 'soccerclub'),
			'w'		 => 437,
			'h'		 => 439
		));
	}
}

// Template output
if ( !function_exists( 'soccerclub_template_single_team_output' ) ) {
	function soccerclub_template_single_team_output($post_options, $post_data) {
		$post_data['post_views']++;
		$show_title = soccerclub_get_custom_option('show_post_title')=='yes';
		$title_tag = soccerclub_get_custom_option('show_page_title')=='yes' ? 'h3' : 'h1';
        $post_meta = get_post_meta($post_data['post_id'], 'soccerclub_team_data', true);



		soccerclub_open_wrapper('<article class="' 
				. join(' ', get_post_class('itemscope'
					. ' post_item post_item_single_team'
					. ' post_featured_' . esc_attr($post_options['post_class'])
					. ' post_format_' . esc_attr($post_data['post_format'])))
				. '"'
				. ' itemscope itemtype="//schema.org/Article'
				. '">');

		if ($show_title && $post_options['location'] == 'center' && soccerclub_get_custom_option('show_page_title')=='no') {
			?>
			<<?php echo esc_attr($title_tag); ?> itemprop="headline" class="post_title entry-title"><span class="post_icon <?php echo esc_attr($post_data['post_icon']); ?>"></span><?php soccerclub_show_layout($post_data['post_title']); ?></<?php echo esc_attr($title_tag); ?>>
			<?php 
		}

		if (!$post_data['post_protected'] && (
			!empty($post_options['dedicated']) ||
			(soccerclub_get_custom_option('show_featured_image')=='yes' && $post_data['post_thumb'])
		)) {
			?>
			<section class="single_team_post_featured">
			<?php
			if (!empty($post_options['dedicated'])) {
                soccerclub_show_layout($post_options['dedicated']);
			} else {
				soccerclub_enqueue_popup();
				?>
				<div class="post_thumb" data-image="<?php echo esc_url($post_data['post_attachment']); ?>" data-title="<?php echo esc_attr($post_data['post_title']); ?>">
					<a class="hover_icon hover_icon_view" href="<?php echo esc_url($post_data['post_attachment']); ?>" title="<?php echo esc_attr($post_data['post_title']); ?>"><?php soccerclub_show_layout($post_data['post_thumb']); ?></a>
				</div>
				<?php 
			}

			
			
            $soc_list = $post_meta['team_member_socials'];
            if (is_array($soc_list) && count($soc_list)>0) {
                $soc_str = '';
                foreach ($soc_list as $sn=>$sl) {
                    if (!empty($sl))
                        $soc_str .= (!empty($soc_str) ? '|' : '') . ($sn) . '=' . ($sl);
                }
                if (!empty($soc_str))
                    $args['socials'] = soccerclub_do_shortcode('[trx_socials size="small" shape="round" socials="'.esc_attr($soc_str).'"][/trx_socials]');
            }
			
			if ( isset($args['socials']) and !empty($args['socials']) ) {
			
            ?>
                <div class="socials_single_team">
                    <?php   soccerclub_show_layout($args['socials']);          ?>
                </div>

			<?php } ?>
				
				
			</section>





            <section class="single_team_post_description">
                <h2 class="title_team"><?php soccerclub_show_layout($post_data['post_title']); ?></h2><h2 class="team_numbers"><?php esc_html_e('#', 'soccerclub'); ?><?php soccerclub_show_layout($post_meta['team_member_number']); ?></h2>
                <h5 class="team_position"><?php soccerclub_show_layout($post_meta['team_member_position']); ?></h5>
                <div class="about_team">
                    <p><?php esc_html_e('Nationality : ', 'soccerclub'); ?><?php soccerclub_show_layout($post_meta['team_member_nationality']); ?></p>
                    <p><?php esc_html_e('Date Of Birth : ', 'soccerclub'); ?><?php soccerclub_show_layout($post_meta['team_member_date_of_birth']); ?></p>
                    <p><?php esc_html_e('Height : ', 'soccerclub'); ?><?php soccerclub_show_layout($post_meta['team_member_growth']); ?></p>
                    <p><?php esc_html_e('Weight : ', 'soccerclub'); ?><?php soccerclub_show_layout($post_meta['team_member_weight']); ?></p>
                </div>
                <div class="team_biography">
                    <h2><?php esc_html_e('Biography', 'soccerclub'); ?></h2>
                    <div class="sc_team_single_item_description"><?php soccerclub_show_layout($post_data['post_excerpt']); ?></div>
                </div>
            </section>
			<?php
		}
		

		soccerclub_open_wrapper('<section class="post_content'.(!$post_data['post_protected'] && $post_data['post_edit_enable'] ? ' '.esc_attr('post_content_editor_present') : '').'" itemprop="articleBody">');
		
		if ($show_title && $post_options['location'] != 'center' && soccerclub_get_custom_option('show_page_title')=='no') {
			?>
			<<?php echo esc_attr($title_tag); ?> itemprop="name" class="post_title entry-title"><span class="post_icon <?php echo esc_attr($post_data['post_icon']); ?>"></span><?php soccerclub_show_layout($post_data['post_title']); ?></<?php echo esc_attr($title_tag); ?>>
			<?php 
		}
			
		// Post content
		if ($post_data['post_protected']) {
            soccerclub_show_layout($post_data['post_excerpt']);
			echo get_the_password_form(); 
		} else {
            if(function_exists('soccerclub_reviews_wrapper')){
                soccerclub_show_layout(soccerclub_gap_wrapper(soccerclub_reviews_wrapper($post_data['post_content'])));
            } else {
                soccerclub_show_layout(soccerclub_gap_wrapper($post_data['post_content']));
            }
			wp_link_pages( array( 
				'before' => '<nav class="pagination_single"><span class="pager_pages">' . esc_html__( 'Pages:', 'soccerclub' ) . '</span>', 
				'after' => '</nav>',
				'link_before' => '<span class="pager_numbers">',
				'link_after' => '</span>'
				)
			); 
			if ( soccerclub_get_custom_option('show_post_tags') == 'yes' && !empty($post_data['post_terms'][$post_data['post_taxonomy_tags']]->terms_links)) {
				?>
				<div class="post_info post_info_bottom">
					<span class="post_info_item post_info_tags"><?php esc_html_e('Tags:', 'soccerclub'); ?> <?php echo join(', ', $post_data['post_terms'][$post_data['post_taxonomy_tags']]->terms_links); ?></span>
				</div>
				<?php 
			}
		} 

		// Prepare args for all rest template parts
		// This parts not pop args from storage!
		soccerclub_template_set_args('single-footer', array(
			'post_options' => $post_options,
			'post_data' => $post_data
		));
			
		if (!$post_data['post_protected'] && $post_data['post_edit_enable']) {
			get_template_part(soccerclub_get_file_slug('templates/_parts/editor-area.php'));
		}

		soccerclub_close_wrapper();
			
		if (!$post_data['post_protected']) {
			get_template_part(soccerclub_get_file_slug('templates/_parts/share.php'));
		}

		soccerclub_close_wrapper();

		if (!$post_data['post_protected']) {
			get_template_part(soccerclub_get_file_slug('templates/_parts/related-posts.php'));
			get_template_part(soccerclub_get_file_slug('templates/_parts/comments.php'));
		}

		// Manually pop args from storage
		// after all single footer templates
		soccerclub_template_get_args('single-footer');
	}
}
?>