function soccerclub_googlemap_init(dom_obj, coords) {
	"use strict";
	if (typeof SOCCERCLUB_STORAGE['googlemap_init_obj'] == 'undefined') soccerclub_googlemap_init_styles();
	SOCCERCLUB_STORAGE['googlemap_init_obj'].geocoder = '';
	try {
		var id = dom_obj.id;
		SOCCERCLUB_STORAGE['googlemap_init_obj'][id] = {
			dom: dom_obj,
			markers: coords.markers,
			geocoder_request: false,
			opt: {
				zoom: coords.zoom,
				center: null,
				scrollwheel: false,
				scaleControl: false,
				disableDefaultUI: false,
				panControl: true,
				zoomControl: true, //zoom
				mapTypeControl: false,
				streetViewControl: false,
				overviewMapControl: false,
				styles: SOCCERCLUB_STORAGE['googlemap_styles'][coords.style ? coords.style : 'default'],
				mapTypeId: google.maps.MapTypeId.ROADMAP
			}
		};
		
		soccerclub_googlemap_create(id);

	} catch (e) {
		
		dcl(SOCCERCLUB_STORAGE['strings']['googlemap_not_avail']);

	};
}

function soccerclub_googlemap_create(id) {
	"use strict";

	// Create map
	SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map = new google.maps.Map(SOCCERCLUB_STORAGE['googlemap_init_obj'][id].dom, SOCCERCLUB_STORAGE['googlemap_init_obj'][id].opt);

	// Add markers
	for (var i in SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers)
		SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].inited = false;
	soccerclub_googlemap_add_markers(id);
	
	// Add resize listener
	jQuery(window).resize(function() {
		if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map)
			SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map.setCenter(SOCCERCLUB_STORAGE['googlemap_init_obj'][id].opt.center);
	});
}

function soccerclub_googlemap_add_markers(id) {
	"use strict";
	for (var i in SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers) {
		
		if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].inited) continue;
		
		if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].latlng == '') {
			
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].geocoder_request!==false) continue;
			
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'].geocoder == '') SOCCERCLUB_STORAGE['googlemap_init_obj'].geocoder = new google.maps.Geocoder();
			SOCCERCLUB_STORAGE['googlemap_init_obj'][id].geocoder_request = i;
			SOCCERCLUB_STORAGE['googlemap_init_obj'].geocoder.geocode({address: SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].address}, function(results, status) {
				"use strict";
				if (status == google.maps.GeocoderStatus.OK) {
					var idx = SOCCERCLUB_STORAGE['googlemap_init_obj'][id].geocoder_request;
					if (results[0].geometry.location.lat && results[0].geometry.location.lng) {
						SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[idx].latlng = '' + results[0].geometry.location.lat() + ',' + results[0].geometry.location.lng();
					} else {
						SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[idx].latlng = results[0].geometry.location.toString().replace(/\(\)/g, '');
					}
					SOCCERCLUB_STORAGE['googlemap_init_obj'][id].geocoder_request = false;
					setTimeout(function() { 
						soccerclub_googlemap_add_markers(id); 
						}, 200);
				} else
					dcl(SOCCERCLUB_STORAGE['strings']['geocode_error'] + ' ' + status);
			});
		
		} else {
			
			// Prepare marker object
			var latlngStr = SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].latlng.split(',');
			var markerInit = {
				map: SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map,
				position: new google.maps.LatLng(latlngStr[0], latlngStr[1]),
				clickable: SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].description!=''
			};
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].point) markerInit.icon = SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].point;
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].title) markerInit.title = SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].title;
			SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].marker = new google.maps.Marker(markerInit);
			
			// Set Map center
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].opt.center == null) {
				SOCCERCLUB_STORAGE['googlemap_init_obj'][id].opt.center = markerInit.position;
				SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map.setCenter(SOCCERCLUB_STORAGE['googlemap_init_obj'][id].opt.center);				
			}
			
			// Add description window
			if (SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].description!='') {
				SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].infowindow = new google.maps.InfoWindow({
					content: SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].description
				});
				google.maps.event.addListener(SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].marker, "click", function(e) {
					var latlng = e.latLng.toString().replace("(", '').replace(")", "").replace(" ", "");
					for (var i in SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers) {
						if (latlng == SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].latlng) {
							SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].infowindow.open(
								SOCCERCLUB_STORAGE['googlemap_init_obj'][id].map,
								SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].marker
							);
							break;
						}
					}
				});
			}
			
			SOCCERCLUB_STORAGE['googlemap_init_obj'][id].markers[i].inited = true;
		}
	}
}

function soccerclub_googlemap_refresh(id) {
	"use strict";
	for (id in SOCCERCLUB_STORAGE['googlemap_init_obj']) {
		soccerclub_googlemap_create(id);
	}
}

function soccerclub_googlemap_init_styles() {
    "use strict";
	// Init Google map
	SOCCERCLUB_STORAGE['googlemap_init_obj'] = {};
	SOCCERCLUB_STORAGE['googlemap_styles'] = {
		'default': []
	};
	if (window.soccerclub_theme_googlemap_styles!==undefined)
		SOCCERCLUB_STORAGE['googlemap_styles'] = soccerclub_theme_googlemap_styles(SOCCERCLUB_STORAGE['googlemap_styles']);
}