<?php
/**
 * SoccerClub Framework: shortcodes manipulations
 *
 * @package	soccerclub
 * @since	soccerclub 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('soccerclub_sc_theme_setup')) {
	add_action( 'soccerclub_action_init_theme', 'soccerclub_sc_theme_setup', 1 );
	function soccerclub_sc_theme_setup() {
		// Add sc stylesheets
		add_action('soccerclub_action_add_styles', 'soccerclub_sc_add_styles', 1);
	}
}

if (!function_exists('soccerclub_sc_theme_setup2')) {
	add_action( 'soccerclub_action_before_init_theme', 'soccerclub_sc_theme_setup2' );
	function soccerclub_sc_theme_setup2() {

		if ( !is_admin() || isset($_POST['action']) ) {
			// Enable/disable shortcodes in excerpt
			add_filter('the_excerpt', 					'soccerclub_sc_excerpt_shortcodes');
	
			// Prepare shortcodes in the content
			if (function_exists('soccerclub_sc_prepare_content')) soccerclub_sc_prepare_content();
		}

		// Add init script into shortcodes output in VC frontend editor
		add_filter('soccerclub_shortcode_output', 'soccerclub_sc_add_scripts', 10, 4);

		// AJAX: Send contact form data
		add_action('wp_ajax_send_form',			'soccerclub_sc_form_send');
		add_action('wp_ajax_nopriv_send_form',	'soccerclub_sc_form_send');

        if (soccerclub_exists_revslider()) {
            add_filter( 'soccerclub_filter_shortcodes_params',			'soccerclub_revslider_shortcodes_params' );
        }

        if (soccerclub_exists_woocommerce()) {
            add_action('soccerclub_action_shortcodes_list', 			'soccerclub_woocommerce_reg_shortcodes', 20);
            if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer())
                add_action('soccerclub_action_shortcodes_list_vc',	'soccerclub_woocommerce_reg_shortcodes_vc', 20);
        }

        // Registar shortcodes [trx_clients] and [trx_clients_item] in the shortcodes list
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_clients_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer())
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_clients_reg_shortcodes_vc');

        // Registar shortcodes [trx_matches] and [trx_latest_matches] in the shortcodes list
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_matches_reg_shortcodes');
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_latest_matches_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer()){
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_matches_reg_shortcodes_vc');
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_latest_matches_reg_shortcodes_vc');
        }

        // Register shortcodes [trx_players] and [trx_players_table]
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_players_reg_shortcodes');
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_players_table_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer()){
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_players_reg_shortcodes_vc');
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_players_table_reg_shortcodes_vc');
        }

        // Register shortcodes [trx_services] and [trx_services_item]
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_services_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer())
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_services_reg_shortcodes_vc');

        // Register shortcodes [trx_team] and [trx_team_item]
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_team_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer())
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_team_reg_shortcodes_vc');

        // Register shortcodes [trx_testimonials] and [trx_testimonials_item]
        add_action('soccerclub_action_shortcodes_list',		'soccerclub_testimonials_reg_shortcodes');
        if (function_exists('soccerclub_exists_visual_composer') && soccerclub_exists_visual_composer())
            add_action('soccerclub_action_shortcodes_list_vc','soccerclub_testimonials_reg_shortcodes_vc');

		// Show shortcodes list in admin editor
		add_action('media_buttons',				'soccerclub_sc_selector_add_in_toolbar', 11);

	}
}


// Register shortcodes styles
if ( !function_exists( 'soccerclub_sc_add_styles' ) ) {
	//add_action('soccerclub_action_add_styles', 'soccerclub_sc_add_styles', 1);
	function soccerclub_sc_add_styles() {
		// Shortcodes
		wp_enqueue_style( 'soccerclub-shortcodes-style',	trx_utils_get_file_url('/shortcodes/theme.shortcodes.css'), array(), null );
	}
}


// Register shortcodes init scripts
if ( !function_exists( 'soccerclub_sc_add_scripts' ) ) {
	//add_filter('soccerclub_shortcode_output', 'soccerclub_sc_add_scripts', 10, 4);
	function soccerclub_sc_add_scripts($output, $tag='', $atts=array(), $content='') {

		if (soccerclub_storage_empty('shortcodes_scripts_added')) {
			soccerclub_storage_set('shortcodes_scripts_added', true);
			//wp_enqueue_style( 'soccerclub-shortcodes-style', soccerclub_get_file_url('shortcodes/theme.shortcodes.css'), array(), null );
            wp_enqueue_script( 'soccerclub-shortcodes-script', trx_utils_get_file_url('shortcodes/theme.shortcodes.js'), array('jquery'), null, true );
		}
		
		return $output;
	}
}


/* Prepare text for shortcodes
-------------------------------------------------------------------------------- */

// Prepare shortcodes in content
if (!function_exists('soccerclub_sc_prepare_content')) {
	function soccerclub_sc_prepare_content() {
		if (function_exists('soccerclub_sc_clear_around')) {
			$filters = array(
				array('trx_utils', 'sc', 'clear', 'around'),
				array('widget', 'text'),
				array('the', 'excerpt'),
				array('the', 'content')
			);
			if (function_exists('soccerclub_exists_woocommerce') && soccerclub_exists_woocommerce()) {
				$filters[] = array('woocommerce', 'template', 'single', 'excerpt');
				$filters[] = array('woocommerce', 'short', 'description');
			}
			if (is_array($filters) && count($filters) > 0) {
				foreach ($filters as $flt)
					add_filter(join('_', $flt), 'soccerclub_sc_clear_around', 1);	// Priority 1 to clear spaces before do_shortcodes()
			}
		}
	}
}

// Enable/Disable shortcodes in the excerpt
if (!function_exists('soccerclub_sc_excerpt_shortcodes')) {
	function soccerclub_sc_excerpt_shortcodes($content) {
		if (!empty($content)) {
			$content = do_shortcode($content);
			//$content = strip_shortcodes($content);
		}
		return $content;
	}
}



/*
// Remove spaces and line breaks between close and open shortcode brackets ][:
[trx_columns]
	[trx_column_item]Column text ...[/trx_column_item]
	[trx_column_item]Column text ...[/trx_column_item]
	[trx_column_item]Column text ...[/trx_column_item]
[/trx_columns]

convert to

[trx_columns][trx_column_item]Column text ...[/trx_column_item][trx_column_item]Column text ...[/trx_column_item][trx_column_item]Column text ...[/trx_column_item][/trx_columns]
*/
if (!function_exists('soccerclub_sc_clear_around')) {
	function soccerclub_sc_clear_around($content) {
		if (!empty($content)) $content = preg_replace("/\](\s|\n|\r)*\[/", "][", $content);
		return $content;
	}
}






/* Shortcodes support utils
---------------------------------------------------------------------- */

// SoccerClub shortcodes load scripts
if (!function_exists('soccerclub_sc_load_scripts')) {
	function soccerclub_sc_load_scripts() {
        wp_enqueue_script( 'soccerclub-shortcodes_admin-script', trx_utils_get_file_url('shortcodes/shortcodes_admin.js'), array('jquery'), null, true );
        wp_enqueue_script( 'soccerclub-selection-script',  soccerclub_get_file_url('js/jquery.selection.js'), array('jquery'), null, true );
		wp_localize_script( 'soccerclub-shortcodes-admin-script', 'SOCCERCLUB_SHORTCODES_DATA', soccerclub_storage_get('shortcodes') );
	}
}

// SoccerClub shortcodes prepare scripts
if (!function_exists('soccerclub_sc_prepare_scripts')) {
	function soccerclub_sc_prepare_scripts() {
		if (!soccerclub_storage_isset('shortcodes_prepared')) {
			soccerclub_storage_set('shortcodes_prepared', true);
			?>
			<script type="text/javascript">
				jQuery(document).ready(function(){
					SOCCERCLUB_STORAGE['shortcodes_cp'] = '<?php echo is_admin() ? (!soccerclub_storage_empty('to_colorpicker') ? soccerclub_storage_get('to_colorpicker') : 'wp') : 'custom'; ?>';	// wp | tiny | custom
				});
			</script>
			<?php
		}
	}
}

// Show shortcodes list in admin editor
if (!function_exists('soccerclub_sc_selector_add_in_toolbar')) {
	//add_action('media_buttons','soccerclub_sc_selector_add_in_toolbar', 11);
	function soccerclub_sc_selector_add_in_toolbar(){

		if ( !soccerclub_options_is_used() ) return;

		soccerclub_sc_load_scripts();
		soccerclub_sc_prepare_scripts();

		$shortcodes = soccerclub_storage_get('shortcodes');
		$shortcodes_list = '<select class="sc_selector"><option value="">&nbsp;'.esc_html__('- Select Shortcode -', 'trx_utils').'&nbsp;</option>';

		if (is_array($shortcodes) && count($shortcodes) > 0) {
			foreach ($shortcodes as $idx => $sc) {
				$shortcodes_list .= '<option value="'.esc_attr($idx).'" title="'.esc_attr($sc['desc']).'">'.esc_html($sc['title']).'</option>';
			}
		}

		$shortcodes_list .= '</select>';

        soccerclub_show_layout($shortcodes_list);
	}
}

// Add RevSlider in the shortcodes params
if ( !function_exists( 'soccerclub_revslider_shortcodes_params' ) ) {
    //Handler of add_filter( 'soccerclub_filter_shortcodes_params',			'soccerclub_revslider_shortcodes_params' );
    function soccerclub_revslider_shortcodes_params($list=array()) {
        $list["revo_sliders"] = soccerclub_get_list_revo_sliders();
        return $list;
    }
}

// Register shortcodes to the internal builder
//------------------------------------------------------------------------
if ( !function_exists( 'soccerclub_woocommerce_reg_shortcodes' ) ) {
    //Handler of add_action('soccerclub_action_shortcodes_list', 'soccerclub_woocommerce_reg_shortcodes', 20);
    function soccerclub_woocommerce_reg_shortcodes() {

        // WooCommerce - Cart
        soccerclub_sc_map("woocommerce_cart", array(
                "title" => esc_html__("Woocommerce: Cart", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show Cart page", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array()
            )
        );

        // WooCommerce - Checkout
        soccerclub_sc_map("woocommerce_checkout", array(
                "title" => esc_html__("Woocommerce: Checkout", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show Checkout page", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array()
            )
        );

        // WooCommerce - My Account
        soccerclub_sc_map("woocommerce_my_account", array(
                "title" => esc_html__("Woocommerce: My Account", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show My Account page", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array()
            )
        );

        // WooCommerce - Order Tracking
        soccerclub_sc_map("woocommerce_order_tracking", array(
                "title" => esc_html__("Woocommerce: Order Tracking", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show Order Tracking page", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array()
            )
        );

        // WooCommerce - Shop Messages
        soccerclub_sc_map("shop_messages", array(
                "title" => esc_html__("Woocommerce: Shop Messages", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show shop messages", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array()
            )
        );

        // WooCommerce - Product Page
        soccerclub_sc_map("product_page", array(
                "title" => esc_html__("Woocommerce: Product Page", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: display single product page", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "sku" => array(
                        "title" => esc_html__("SKU", 'trx_utils'),
                        "desc" => wp_kses_data( __("SKU code of displayed product", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "id" => array(
                        "title" => esc_html__("ID", 'trx_utils'),
                        "desc" => wp_kses_data( __("ID of displayed product", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "posts_per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => "1",
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "post_type" => array(
                        "title" => esc_html__("Post type", 'trx_utils'),
                        "desc" => wp_kses_data( __("Post type for the WP query (leave 'product')", 'trx_utils') ),
                        "value" => "product",
                        "type" => "text"
                    ),
                    "post_status" => array(
                        "title" => esc_html__("Post status", 'trx_utils'),
                        "desc" => wp_kses_data( __("Display posts only with this status", 'trx_utils') ),
                        "value" => "publish",
                        "type" => "select",
                        "options" => array(
                            "publish" => esc_html__('Publish', 'trx_utils'),
                            "protected" => esc_html__('Protected', 'trx_utils'),
                            "private" => esc_html__('Private', 'trx_utils'),
                            "pending" => esc_html__('Pending', 'trx_utils'),
                            "draft" => esc_html__('Draft', 'trx_utils')
                        )
                    )
                )
            )
        );

        // WooCommerce - Product
        soccerclub_sc_map("product", array(
                "title" => esc_html__("Woocommerce: Product", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: display one product", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "sku" => array(
                        "title" => esc_html__("SKU", 'trx_utils'),
                        "desc" => wp_kses_data( __("SKU code of displayed product", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "id" => array(
                        "title" => esc_html__("ID", 'trx_utils'),
                        "desc" => wp_kses_data( __("ID of displayed product", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    )
                )
            )
        );

        // WooCommerce - Best Selling Products
        soccerclub_sc_map("best_selling_products", array(
                "title" => esc_html__("Woocommerce: Best Selling Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show best selling products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    )
                )
            )
        );

        // WooCommerce - Recent Products
        soccerclub_sc_map("recent_products", array(
                "title" => esc_html__("Woocommerce: Recent Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show recent products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    )
                )
            )
        );

        // WooCommerce - Related Products
        soccerclub_sc_map("related_products", array(
                "title" => esc_html__("Woocommerce: Related Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show related products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "posts_per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    )
                )
            )
        );

        // WooCommerce - Featured Products
        soccerclub_sc_map("featured_products", array(
                "title" => esc_html__("Woocommerce: Featured Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show featured products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    )
                )
            )
        );

        // WooCommerce - Top Rated Products
        soccerclub_sc_map("featured_products", array(
                "title" => esc_html__("Woocommerce: Top Rated Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show top rated products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    )
                )
            )
        );

        // WooCommerce - Sale Products
        soccerclub_sc_map("featured_products", array(
                "title" => esc_html__("Woocommerce: Sale Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: list products on sale", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    )
                )
            )
        );

        // WooCommerce - Product Category
        soccerclub_sc_map("product_category", array(
                "title" => esc_html__("Woocommerce: Products from category", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: list products in specified category(-ies)", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    ),
                    "category" => array(
                        "title" => esc_html__("Categories", 'trx_utils'),
                        "desc" => wp_kses_data( __("Comma separated category slugs", 'trx_utils') ),
                        "value" => '',
                        "type" => "text"
                    ),
                    "operator" => array(
                        "title" => esc_html__("Operator", 'trx_utils'),
                        "desc" => wp_kses_data( __("Categories operator", 'trx_utils') ),
                        "value" => "IN",
                        "type" => "checklist",
                        "size" => "medium",
                        "options" => array(
                            "IN" => esc_html__('IN', 'trx_utils'),
                            "NOT IN" => esc_html__('NOT IN', 'trx_utils'),
                            "AND" => esc_html__('AND', 'trx_utils')
                        )
                    )
                )
            )
        );

        // WooCommerce - Products
        soccerclub_sc_map("products", array(
                "title" => esc_html__("Woocommerce: Products", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: list all products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "skus" => array(
                        "title" => esc_html__("SKUs", 'trx_utils'),
                        "desc" => wp_kses_data( __("Comma separated SKU codes of products", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "ids" => array(
                        "title" => esc_html__("IDs", 'trx_utils'),
                        "desc" => wp_kses_data( __("Comma separated ID of products", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    )
                )
            )
        );

        // WooCommerce - Product attribute
        soccerclub_sc_map("product_attribute", array(
                "title" => esc_html__("Woocommerce: Products by Attribute", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show products with specified attribute", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "per_page" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    ),
                    "attribute" => array(
                        "title" => esc_html__("Attribute", 'trx_utils'),
                        "desc" => wp_kses_data( __("Attribute name", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "filter" => array(
                        "title" => esc_html__("Filter", 'trx_utils'),
                        "desc" => wp_kses_data( __("Attribute value", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    )
                )
            )
        );

        // WooCommerce - Products Categories
        soccerclub_sc_map("product_categories", array(
                "title" => esc_html__("Woocommerce: Product Categories", 'trx_utils'),
                "desc" => wp_kses_data( __("WooCommerce shortcode: show categories with products", 'trx_utils') ),
                "decorate" => false,
                "container" => false,
                "params" => array(
                    "number" => array(
                        "title" => esc_html__("Number", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many categories showed", 'trx_utils') ),
                        "value" => 4,
                        "min" => 1,
                        "type" => "spinner"
                    ),
                    "columns" => array(
                        "title" => esc_html__("Columns", 'trx_utils'),
                        "desc" => wp_kses_data( __("How many columns per row use for categories output", 'trx_utils') ),
                        "value" => 4,
                        "min" => 2,
                        "max" => 4,
                        "type" => "spinner"
                    ),
                    "orderby" => array(
                        "title" => esc_html__("Order by", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "date",
                        "type" => "select",
                        "options" => array(
                            "date" => esc_html__('Date', 'trx_utils'),
                            "title" => esc_html__('Title', 'trx_utils')
                        )
                    ),
                    "order" => array(
                        "title" => esc_html__("Order", 'trx_utils'),
                        "desc" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "value" => "desc",
                        "type" => "switch",
                        "size" => "big",
                        "options" => soccerclub_get_sc_param('ordering')
                    ),
                    "parent" => array(
                        "title" => esc_html__("Parent", 'trx_utils'),
                        "desc" => wp_kses_data( __("Parent category slug", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "ids" => array(
                        "title" => esc_html__("IDs", 'trx_utils'),
                        "desc" => wp_kses_data( __("Comma separated ID of products", 'trx_utils') ),
                        "value" => "",
                        "type" => "text"
                    ),
                    "hide_empty" => array(
                        "title" => esc_html__("Hide empty", 'trx_utils'),
                        "desc" => wp_kses_data( __("Hide empty categories", 'trx_utils') ),
                        "value" => "yes",
                        "type" => "switch",
                        "options" => soccerclub_get_sc_param('yes_no')
                    )
                )
            )
        );
    }
}



// Register shortcodes to the VC builder
//------------------------------------------------------------------------
if ( !function_exists( 'soccerclub_woocommerce_reg_shortcodes_vc' ) ) {
    //Handler of add_action('soccerclub_action_shortcodes_list_vc', 'soccerclub_woocommerce_reg_shortcodes_vc');
    function soccerclub_woocommerce_reg_shortcodes_vc() {

        if (false && function_exists('soccerclub_exists_woocommerce') && soccerclub_exists_woocommerce()) {

            // WooCommerce - Cart
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "woocommerce_cart",
                "name" => esc_html__("Cart", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show cart page", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_wooc_cart',
                "class" => "trx_sc_alone trx_sc_woocommerce_cart",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => false,
                "params" => array(
                    array(
                        "param_name" => "dummy",
                        "heading" => esc_html__("Dummy data", 'trx_utils'),
                        "description" => wp_kses_data( __("Dummy data - not used in shortcodes", 'trx_utils') ),
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Woocommerce_Cart extends Soccerclub_Vc_ShortCodeAlone {}


            // WooCommerce - Checkout
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "woocommerce_checkout",
                "name" => esc_html__("Checkout", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show checkout page", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_wooc_checkout',
                "class" => "trx_sc_alone trx_sc_woocommerce_checkout",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => false,
                "params" => array(
                    array(
                        "param_name" => "dummy",
                        "heading" => esc_html__("Dummy data", 'trx_utils'),
                        "description" => wp_kses_data( __("Dummy data - not used in shortcodes", 'trx_utils') ),
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Woocommerce_Checkout extends Soccerclub_Vc_ShortCodeAlone {}


            // WooCommerce - My Account
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "woocommerce_my_account",
                "name" => esc_html__("My Account", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show my account page", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_wooc_my_account',
                "class" => "trx_sc_alone trx_sc_woocommerce_my_account",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => false,
                "params" => array(
                    array(
                        "param_name" => "dummy",
                        "heading" => esc_html__("Dummy data", 'trx_utils'),
                        "description" => wp_kses_data( __("Dummy data - not used in shortcodes", 'trx_utils') ),
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Woocommerce_My_Account extends Soccerclub_Vc_ShortCodeAlone {}


            // WooCommerce - Order Tracking
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "woocommerce_order_tracking",
                "name" => esc_html__("Order Tracking", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show order tracking page", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_wooc_order_tracking',
                "class" => "trx_sc_alone trx_sc_woocommerce_order_tracking",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => false,
                "params" => array(
                    array(
                        "param_name" => "dummy",
                        "heading" => esc_html__("Dummy data", 'trx_utils'),
                        "description" => wp_kses_data( __("Dummy data - not used in shortcodes", 'trx_utils') ),
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Woocommerce_Order_Tracking extends Soccerclub_Vc_ShortCodeAlone {}


            // WooCommerce - Shop Messages
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "shop_messages",
                "name" => esc_html__("Shop Messages", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show shop messages", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_wooc_shop_messages',
                "class" => "trx_sc_alone trx_sc_shop_messages",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => false,
                "params" => array(
                    array(
                        "param_name" => "dummy",
                        "heading" => esc_html__("Dummy data", 'trx_utils'),
                        "description" => wp_kses_data( __("Dummy data - not used in shortcodes", 'trx_utils') ),
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Shop_Messages extends Soccerclub_Vc_ShortCodeAlone {}


            // WooCommerce - Product Page
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "product_page",
                "name" => esc_html__("Product Page", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: display single product page", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_product_page',
                "class" => "trx_sc_single trx_sc_product_page",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "sku",
                        "heading" => esc_html__("SKU", 'trx_utils'),
                        "description" => wp_kses_data( __("SKU code of displayed product", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "id",
                        "heading" => esc_html__("ID", 'trx_utils'),
                        "description" => wp_kses_data( __("ID of displayed product", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "posts_per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "post_type",
                        "heading" => esc_html__("Post type", 'trx_utils'),
                        "description" => wp_kses_data( __("Post type for the WP query (leave 'product')", 'trx_utils') ),
                        "class" => "",
                        "value" => "product",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "post_status",
                        "heading" => esc_html__("Post status", 'trx_utils'),
                        "description" => wp_kses_data( __("Display posts only with this status", 'trx_utils') ),
                        "class" => "",
                        "value" => array(
                            esc_html__('Publish', 'trx_utils') => 'publish',
                            esc_html__('Protected', 'trx_utils') => 'protected',
                            esc_html__('Private', 'trx_utils') => 'private',
                            esc_html__('Pending', 'trx_utils') => 'pending',
                            esc_html__('Draft', 'trx_utils') => 'draft'
                        ),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Product_Page extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Product
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "product",
                "name" => esc_html__("Product", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: display one product", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_product',
                "class" => "trx_sc_single trx_sc_product",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "sku",
                        "heading" => esc_html__("SKU", 'trx_utils'),
                        "description" => wp_kses_data( __("Product's SKU code", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "id",
                        "heading" => esc_html__("ID", 'trx_utils'),
                        "description" => wp_kses_data( __("Product's ID", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Product extends Soccerclub_Vc_ShortCodeSingle {}


            // WooCommerce - Best Selling Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "best_selling_products",
                "name" => esc_html__("Best Selling Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show best selling products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_best_selling_products',
                "class" => "trx_sc_single trx_sc_best_selling_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Best_Selling_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Recent Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "recent_products",
                "name" => esc_html__("Recent Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show recent products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_recent_products',
                "class" => "trx_sc_single trx_sc_recent_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"

                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Recent_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Related Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "related_products",
                "name" => esc_html__("Related Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show related products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_related_products',
                "class" => "trx_sc_single trx_sc_related_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "posts_per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Related_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Featured Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "featured_products",
                "name" => esc_html__("Featured Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show featured products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_featured_products',
                "class" => "trx_sc_single trx_sc_featured_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Featured_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Top Rated Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "top_rated_products",
                "name" => esc_html__("Top Rated Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show top rated products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_top_rated_products',
                "class" => "trx_sc_single trx_sc_top_rated_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Top_Rated_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Sale Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "sale_products",
                "name" => esc_html__("Sale Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: list products on sale", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_sale_products',
                "class" => "trx_sc_single trx_sc_sale_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Sale_Products extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Product Category
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "product_category",
                "name" => esc_html__("Products from category", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: list products in specified category(-ies)", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_product_category',
                "class" => "trx_sc_single trx_sc_product_category",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "category",
                        "heading" => esc_html__("Categories", 'trx_utils'),
                        "description" => wp_kses_data( __("Comma separated category slugs", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "operator",
                        "heading" => esc_html__("Operator", 'trx_utils'),
                        "description" => wp_kses_data( __("Categories operator", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('IN', 'trx_utils') => 'IN',
                            esc_html__('NOT IN', 'trx_utils') => 'NOT IN',
                            esc_html__('AND', 'trx_utils') => 'AND'
                        ),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Product_Category extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Products
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "products",
                "name" => esc_html__("Products", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: list all products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_products',
                "class" => "trx_sc_single trx_sc_products",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "skus",
                        "heading" => esc_html__("SKUs", 'trx_utils'),
                        "description" => wp_kses_data( __("Comma separated SKU codes of products", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "ids",
                        "heading" => esc_html__("IDs", 'trx_utils'),
                        "description" => wp_kses_data( __("Comma separated ID of products", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    )
                )
            ) );

            class WPBakeryShortCode_Products extends Soccerclub_Vc_ShortCodeSingle {}




            // WooCommerce - Product Attribute
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "product_attribute",
                "name" => esc_html__("Products by Attribute", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show products with specified attribute", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_product_attribute',
                "class" => "trx_sc_single trx_sc_product_attribute",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "per_page",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many products showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "attribute",
                        "heading" => esc_html__("Attribute", 'trx_utils'),
                        "description" => wp_kses_data( __("Attribute name", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "filter",
                        "heading" => esc_html__("Filter", 'trx_utils'),
                        "description" => wp_kses_data( __("Attribute value", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    )
                )
            ) );

            class WPBakeryShortCode_Product_Attribute extends Soccerclub_Vc_ShortCodeSingle {}



            // WooCommerce - Products Categories
            //-------------------------------------------------------------------------------------

            vc_map( array(
                "base" => "product_categories",
                "name" => esc_html__("Product Categories", 'trx_utils'),
                "description" => wp_kses_data( __("WooCommerce shortcode: show categories with products", 'trx_utils') ),
                "category" => esc_html__('WooCommerce', 'trx_utils'),
                'icon' => 'icon_trx_product_categories',
                "class" => "trx_sc_single trx_sc_product_categories",
                "content_element" => true,
                "is_container" => false,
                "show_settings_on_create" => true,
                "params" => array(
                    array(
                        "param_name" => "number",
                        "heading" => esc_html__("Number", 'trx_utils'),
                        "description" => wp_kses_data( __("How many categories showed", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "4",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "columns",
                        "heading" => esc_html__("Columns", 'trx_utils'),
                        "description" => wp_kses_data( __("How many columns per row use for categories output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "1",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "orderby",
                        "heading" => esc_html__("Order by", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array(
                            esc_html__('Date', 'trx_utils') => 'date',
                            esc_html__('Title', 'trx_utils') => 'title'
                        ),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "order",
                        "heading" => esc_html__("Order", 'trx_utils'),
                        "description" => wp_kses_data( __("Sorting order for products output", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => array_flip(soccerclub_get_sc_param('ordering')),
                        "type" => "dropdown"
                    ),
                    array(
                        "param_name" => "parent",
                        "heading" => esc_html__("Parent", 'trx_utils'),
                        "description" => wp_kses_data( __("Parent category slug", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "date",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "ids",
                        "heading" => esc_html__("IDs", 'trx_utils'),
                        "description" => wp_kses_data( __("Comma separated ID of products", 'trx_utils') ),
                        "admin_label" => true,
                        "class" => "",
                        "value" => "",
                        "type" => "textfield"
                    ),
                    array(
                        "param_name" => "hide_empty",
                        "heading" => esc_html__("Hide empty", 'trx_utils'),
                        "description" => wp_kses_data( __("Hide empty categories", 'trx_utils') ),
                        "class" => "",
                        "value" => array("Hide empty" => "1" ),
                        "type" => "checkbox"
                    )
                )
            ) );

            class WPBakeryShortCode_Products_Categories extends Soccerclub_Vc_ShortCodeSingle {}
        }
    }
}


// ---------------------------------- [trx_clients] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_clients' ) ) {
    function soccerclub_sc_clients($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => "clients-1",
            "columns" => 4,
            "slider" => "no",
            "slides_space" => 0,
            "controls" => "no",
            "interval" => "",
            "autoheight" => "no",
            "custom" => "no",
            "ids" => "",
            "cat" => "",
            "count" => 4,
            "offset" => "",
            "orderby" => "title",
            "order" => "asc",
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));

        if (empty($id)) $id = "sc_clients_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";
        if (empty($interval)) $interval = mt_rand(5000, 10000);

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        if (soccerclub_param_is_on($slider)) soccerclub_enqueue_slider('swiper');

        $columns = max(1, min(12, $columns));
        $count = max(1, (int) $count);
        if (soccerclub_param_is_off($custom) && $count < $columns) $columns = $count;
        soccerclub_storage_set('sc_clients_data', array(
                'id'=>$id,
                'style'=>$style,
                'counter'=>0,
                'columns'=>$columns,
                'slider'=>$slider,
                'css_wh'=>$ws . $hs
            )
        );

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_clients_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            . '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_clients sc_clients_style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (!empty($class) ? ' '.esc_attr($class) : '')
            .'"'
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_clients_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_clients_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_clients_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            . (soccerclub_param_is_on($slider)
                ? ('<div class="sc_slider_swiper swiper-slider-container'
                    . ' ' . esc_attr(soccerclub_get_slider_controls_classes($controls))
                    . (soccerclub_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
                    . ($hs ? ' sc_slider_height_fixed' : '')
                    . '"'
                    . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
                    . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
                    . ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
                    . ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
                    . ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
                    . ' data-slides-min-width="' . ($style=='clients-1' ? 100 : 220) . '"'
                    . '>'
                    . '<div class="slides swiper-wrapper">')
                : ($columns > 1
                    ? '<div class="sc_columns columns_wrap">'
                    : '')
            );

        $content = do_shortcode($content);

        if (soccerclub_param_is_on($custom) && $content) {
            $output .= $content;
        } else {
            global $post;

            if (!empty($ids)) {
                $posts = explode(',', $ids);
                $count = count($posts);
            }

            $args = array(
                'post_type' => 'clients',
                'post_status' => 'publish',
                'posts_per_page' => $count,
                'ignore_sticky_posts' => true,
                'order' => $order=='asc' ? 'asc' : 'desc',
            );

            if ($offset > 0 && empty($ids)) {
                $args['offset'] = $offset;
            }

            $args = soccerclub_query_add_sort_order($args, $orderby, $order);
            $args = soccerclub_query_add_posts_and_cats($args, $ids, 'clients', $cat, 'clients_group');

            $query = new WP_Query( $args );

            $post_number = 0;

            while ( $query->have_posts() ) {
                $query->the_post();
                $post_number++;
                $args = array(
                    'layout' => $style,
                    'show' => false,
                    'number' => $post_number,
                    'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
                    "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                    "orderby" => $orderby,
                    'content' => false,
                    'terms_list' => false,
                    'columns_count' => $columns,
                    'slider' => $slider,
                    'tag_id' => $id ? $id . '_' . $post_number : '',
                    'tag_class' => '',
                    'tag_animation' => '',
                    'tag_css' => '',
                    'tag_css_wh' => $ws . $hs
                );
                $post_data = soccerclub_get_post_data($args);
                $post_meta = get_post_meta($post_data['post_id'], soccerclub_storage_get('options_prefix') . '_post_options', true);
                $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
                $args['client_name'] = $post_meta['client_name'];
                $args['client_position'] = $post_meta['client_position'];
                $args['client_image'] = $post_data['post_thumb'];
                $args['client_link'] = soccerclub_param_is_on('client_show_link')
                    ? (!empty($post_meta['client_link']) ? $post_meta['client_link'] : $post_data['post_link'])
                    : '';
                $output .= soccerclub_show_post_layout($args, $post_data);
            }
            wp_reset_postdata();
        }

        if (soccerclub_param_is_on($slider)) {
            $output .= '</div>'
                . '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
                . '<div class="sc_slider_pagination_wrap"></div>'
                . '</div>';
        } else if ($columns > 1) {
            $output .= '</div>';
        }

        $output .= (!empty($link) ? '<div class="sc_clients_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_clients -->'
            . '</div><!-- /.sc_clients_wrap -->';

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_clients', $atts, $content);
    }
    add_shortcode('trx_clients', 'soccerclub_sc_clients');
}


if ( !function_exists( 'soccerclub_sc_clients_item' ) ) {
    function soccerclub_sc_clients_item($atts, $content=null) {
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts( array(
            // Individual params
            "name" => "",
            "position" => "",
            "image" => "",
            "link" => "",
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => ""
        ), $atts)));

        soccerclub_storage_inc_array('sc_clients_data', 'counter');

        $id = $id ? $id : (soccerclub_storage_get_array('sc_clients_data', 'id') ? soccerclub_storage_get_array('sc_clients_data', 'id') . '_' . soccerclub_storage_get_array('sc_clients_data', 'counter') : '');

        $descr = trim(chop(do_shortcode($content)));

        $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => soccerclub_storage_get_array('sc_clients_data', 'style')));

        if ($image > 0) {
            $attach = wp_get_attachment_image_src( $image, 'full' );
            if (isset($attach[0]) && $attach[0]!='')
                $image = $attach[0];
        }
        $image = soccerclub_get_resized_image_tag($image, $thumb_sizes['w'], $thumb_sizes['h']);

        $post_data = array(
            'post_title' => $name,
            'post_excerpt' => $descr
        );
        $args = array(
            'layout' => soccerclub_storage_get_array('sc_clients_data', 'style'),
            'number' => soccerclub_storage_get_array('sc_clients_data', 'counter'),
            'columns_count' => soccerclub_storage_get_array('sc_clients_data', 'columns'),
            'slider' => soccerclub_storage_get_array('sc_clients_data', 'slider'),
            'show' => false,
            'descr'  => 0,
            'tag_id' => $id,
            'tag_class' => $class,
            'tag_animation' => $animation,
            'tag_css' => $css,
            'tag_css_wh' => soccerclub_storage_get_array('sc_clients_data', 'css_wh'),
            'client_position' => $position,
            'client_link' => $link,
            'client_image' => $image
        );
        $output = soccerclub_show_post_layout($args, $post_data);
        return apply_filters('soccerclub_shortcode_output', $output, 'trx_clients_item', $atts, $content);
    }
    add_shortcode('trx_clients_item', 'soccerclub_sc_clients_item');
}
// ---------------------------------- [/trx_clients] ---------------------------------------



// Add [trx_clients] and [trx_clients_item] in the shortcodes list
if (!function_exists('soccerclub_clients_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_clients_reg_shortcodes');
    function soccerclub_clients_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $users = soccerclub_get_list_users();
            $members = soccerclub_get_list_posts(false, array(
                    'post_type'=>'clients',
                    'orderby'=>'title',
                    'order'=>'asc',
                    'return'=>'title'
                )
            );
            $clients_groups = soccerclub_get_list_terms(false, 'clients_group');
            $clients_styles = soccerclub_get_list_templates('clients');
            $controls 		= soccerclub_get_list_slider_controls();

            soccerclub_sc_map_after('trx_chat', array(

                // Clients
                "trx_clients" => array(
                    "title" => esc_html__("Clients", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert clients list in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "style" => array(
                            "title" => esc_html__("Clients style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select style to display clients list", 'trx_utils') ),
                            "value" => "clients-1",
                            "type" => "select",
                            "options" => $clients_styles
                        ),
                        "columns" => array(
                            "title" => esc_html__("Columns", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many columns use to show clients", 'trx_utils') ),
                            "value" => 4,
                            "min" => 2,
                            "max" => 6,
                            "step" => 1,
                            "type" => "spinner"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "slider" => array(
                            "title" => esc_html__("Slider", 'trx_utils'),
                            "desc" => wp_kses_data( __("Use slider to show clients", 'trx_utils') ),
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "controls" => array(
                            "title" => esc_html__("Controls", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "divider" => true,
                            "value" => "no",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => $controls
                        ),
                        "slides_space" => array(
                            "title" => esc_html__("Space between slides", 'trx_utils'),
                            "desc" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "max" => 100,
                            "step" => 10,
                            "type" => "spinner"
                        ),
                        "interval" => array(
                            "title" => esc_html__("Slides change interval", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 7000,
                            "step" => 500,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "autoheight" => array(
                            "title" => esc_html__("Autoheight", 'trx_utils'),
                            "desc" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "custom" => array(
                            "title" => esc_html__("Custom", 'trx_utils'),
                            "desc" => wp_kses_data( __("Allow get team members from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                            "divider" => true,
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show team members. If empty - select team members from any category (group) or from IDs list", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $clients_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 4,
                            "min" => 1,
                            "max" => 100,
                            "type" => "spinner"
                        ),
                        "offset" => array(
                            "title" => esc_html__("Offset before select posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "orderby" => array(
                            "title" => esc_html__("Post order by", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "title",
                            "type" => "select",
                            "options" => soccerclub_get_sc_param('sorting')
                        ),
                        "order" => array(
                            "title" => esc_html__("Post order", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "asc",
                            "type" => "switch",
                            "size" => "big",
                            "options" => soccerclub_get_sc_param('ordering')
                        ),
                        "ids" => array(
                            "title" => esc_html__("Post IDs list", 'trx_utils'),
                            "desc" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    ),
                    "children" => array(
                        "name" => "trx_clients_item",
                        "title" => esc_html__("Client", 'trx_utils'),
                        "desc" => wp_kses_data( __("Single client (custom parameters)", 'trx_utils') ),
                        "container" => true,
                        "params" => array(
                            "name" => array(
                                "title" => esc_html__("Name", 'trx_utils'),
                                "desc" => wp_kses_data( __("Client's name", 'trx_utils') ),
                                "divider" => true,
                                "value" => "",
                                "type" => "text"
                            ),
                            "position" => array(
                                "title" => esc_html__("Position", 'trx_utils'),
                                "desc" => wp_kses_data( __("Client's position", 'trx_utils') ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "link" => array(
                                "title" => esc_html__("Link", 'trx_utils'),
                                "desc" => wp_kses_data( __("Link on client's personal page", 'trx_utils') ),
                                "divider" => true,
                                "value" => "",
                                "type" => "text"
                            ),
                            "image" => array(
                                "title" => esc_html__("Image", 'trx_utils'),
                                "desc" => wp_kses_data( __("Client's image", 'trx_utils') ),
                                "value" => "",
                                "readonly" => false,
                                "type" => "media"
                            ),
                            "_content_" => array(
                                "title" => esc_html__("Description", 'trx_utils'),
                                "desc" => wp_kses_data( __("Client's short description", 'trx_utils') ),
                                "divider" => true,
                                "rows" => 4,
                                "value" => "",
                                "type" => "textarea"
                            ),
                            "id" => soccerclub_get_sc_param('id'),
                            "class" => soccerclub_get_sc_param('class'),
                            "animation" => soccerclub_get_sc_param('animation'),
                            "css" => soccerclub_get_sc_param('css')
                        )
                    )
                )

            ));
        }
    }
}


// Add [trx_clients] and [trx_clients_item] in the VC shortcodes list
if (!function_exists('soccerclub_clients_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_clients_reg_shortcodes_vc');
    function soccerclub_clients_reg_shortcodes_vc() {

        $clients_groups = soccerclub_get_list_terms(false, 'clients_group');
        $clients_styles = soccerclub_get_list_templates('clients');
        $controls		= soccerclub_get_list_slider_controls();

        // Clients
        vc_map( array(
            "base" => "trx_clients",
            "name" => esc_html__("Clients", 'trx_utils'),
            "description" => wp_kses_data( __("Insert clients list", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_clients',
            "class" => "trx_sc_columns trx_sc_clients",
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "as_parent" => array('only' => 'trx_clients_item'),
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Clients style", 'trx_utils'),
                    "description" => wp_kses_data( __("Select style to display clients list", 'trx_utils') ),
                    "class" => "",
                    "admin_label" => true,
                    "value" => array_flip($clients_styles),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slider",
                    "heading" => esc_html__("Slider", 'trx_utils'),
                    "description" => wp_kses_data( __("Use slider to show testimonials", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip(soccerclub_get_sc_param('yes_no')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "controls",
                    "heading" => esc_html__("Controls", 'trx_utils'),
                    "description" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip($controls),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slides_space",
                    "heading" => esc_html__("Space between slides", 'trx_utils'),
                    "description" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "interval",
                    "heading" => esc_html__("Slides change interval", 'trx_utils'),
                    "description" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "7000",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "autoheight",
                    "heading" => esc_html__("Autoheight", 'trx_utils'),
                    "description" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => array("Autoheight" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "custom",
                    "heading" => esc_html__("Custom", 'trx_utils'),
                    "description" => wp_kses_data( __("Allow get clients from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                    "class" => "",
                    "value" => array("Custom clients" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show clients. If empty - select clients from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $clients_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "columns",
                    "heading" => esc_html__("Columns", 'trx_utils'),
                    "description" => wp_kses_data( __("How many columns use to show clients", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "4",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of posts", 'trx_utils'),
                    "description" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "4",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "offset",
                    "heading" => esc_html__("Offset before select posts", 'trx_utils'),
                    "description" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "orderby",
                    "heading" => esc_html__("Post sorting", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "title",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('sorting')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "order",
                    "heading" => esc_html__("Post order", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "asc",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('ordering')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "ids",
                    "heading" => esc_html__("client's IDs list", 'trx_utils'),
                    "description" => wp_kses_data( __("Comma separated list of client's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnsView'
        ) );


        vc_map( array(
            "base" => "trx_clients_item",
            "name" => esc_html__("Client", 'trx_utils'),
            "description" => wp_kses_data( __("Client - all data pull out from it account on your site", 'trx_utils') ),
            "show_settings_on_create" => true,
            "class" => "trx_sc_collection trx_sc_column_item trx_sc_clients_item",
            "content_element" => true,
            "is_container" => true,
            'icon' => 'icon_trx_clients_item',
            "as_child" => array('only' => 'trx_clients'),
            "as_parent" => array('except' => 'trx_clients'),
            "params" => array(
                array(
                    "param_name" => "name",
                    "heading" => esc_html__("Name", 'trx_utils'),
                    "description" => wp_kses_data( __("Client's name", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "position",
                    "heading" => esc_html__("Position", 'trx_utils'),
                    "description" => wp_kses_data( __("Client's position", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Link", 'trx_utils'),
                    "description" => wp_kses_data( __("Link on client's personal page", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "image",
                    "heading" => esc_html__("Client's image", 'trx_utils'),
                    "description" => wp_kses_data( __("Clients's image", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnItemView'
        ) );

        class WPBakeryShortCode_Trx_Clients extends Soccerclub_Vc_ShortCodeColumns {}
        class WPBakeryShortCode_Trx_Clients_Item extends Soccerclub_Vc_ShortCodeCollection {}

    }
}


// ---------------------------------- [trx_matches] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_matches' ) ) {
    function soccerclub_sc_matches($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => 'matches-1',
            "cat" => "",
            "align" => "",
            "count" => 4,
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "title_next" => "",
            "subtitle_next" => "",
            "description_next" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));
        $columns = 0;

        if (empty($id)) $id = "sc_matches_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_matches_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            .'<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_matches style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            .'"'
            . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
            . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>';
        // Title, decription and subtitle for the "next matches" block
        $next = '<div class="sc_matches_next">'
            . (!empty($subtitle) && $style == 'matches-1' ? '<h6 class="sc_matches_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle_next)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_matches_title sc_item_title">' . trim(soccerclub_strmacros($title_next)) . '</h2>' : '')
            . (!empty($description) && $style == 'matches-1'? '<div class="sc_matches_descr sc_item_descr">' . trim(soccerclub_strmacros($description_next)) . '</div>' : '')
            .'<ul class="sc_matches_list">';

        // Title, decription and subtitle for the "current match" block
        $current = '<div class="sc_matches_current">'
            . (!empty($subtitle) ? '<h6 class="sc_matches_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_matches_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_matches_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            .'<ul class="sc_matches_list">';

        global $post;

        $args = array(
            'post_type' => 'matches',
            'post_status' => 'publish',
			'posts_per_page' => empty($count) ? 2 : $count,
            'ignore_sticky_posts' => true,
            'order' => 'asc'
        );
        $args = soccerclub_query_add_sort_order($args, 'date', 'asc');
        $args = soccerclub_query_add_posts_and_cats($args, '', 'matches', $cat, 'matches_group');
        $query = new WP_Query( $args );

        $post_number = 0;
        $matches = array();
        $matches['0'] = date('Y-m-d');
        $matches_ids = array();

        // Create a field matches, where index is post_id and value id match_date
        while ( $query->have_posts() ) {
            $query->the_post();
            $post_number++;
            $args = array(
                'layout' => $style,
                'orderby' => 'date'
            );
            $post_data = soccerclub_get_post_data($args);
            $post_meta = get_post_meta($post_data['post_id'], soccerclub_storage_get('options_prefix') . '_post_options', true);
            $matches[$post_data['post_id']] = $post_meta['match_date'];
        }

        if($count > $post_number) $count = $post_number;
        if($count < 2) $count = 1;

        // Sort matches by the date
        if ($post_number > 0) asort($matches);

        // Create a new field, where index is a number and value is post_id
        $N = 0;
        foreach($matches as $i => $v)
        {
            $matches_ids[$N] = $i;
            $N++;
        }

        // Get a X nearest matches
        $matches_ids = soccerclub_nearest_match($matches_ids, $count, $post_number);


        // Return matches content
        for($i = 0; $i < $count; $i++) {
			if (empty($matches_ids[$i])) continue;
            $args = array(
                'layout' => $style,
                'show' => false,
                'number' => $i,
                "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                "orderby" => 'date',
                'content' => false,
                'terms_list' => false,
                'columns_count' => $columns,
                'tag_id' => $id ? $id . '_' . $i : '',
                'tag_class' => '',
                'tag_animation' => '',
                'tag_css' => '',
                'tag_css_wh' => $ws . $hs
            );
            $post_data = soccerclub_get_post_data($args, $matches_ids[$i]);
            $post_meta = get_post_meta($matches_ids[$i], soccerclub_storage_get('options_prefix') . '_post_options', true);
            $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
            $args['name'] = $post_data['post_title'];
            $args['date'] = $post_meta['match_date'];
            $args['time'] = $post_meta['match_time'];
            $args['player_1'] = $post_meta['match_player_1'];
            $args['points_1'] = $post_meta['match_points_1'];
            $args['player_2'] = $post_meta['match_player_2'];
            $args['points_2'] = $post_meta['match_points_2'];
            $args['score'] = $post_meta['match_score'];
            $args['image'] = $post_data['post_thumb'];
            $args['link'] = soccerclub_param_is_on('match_show_link')
                ? (!empty($post_meta['match_link']) ? $post_meta['match_link'] : $post_data['post_link'])
                : '';

            if ($style == 'matches-2' && $i == ceil($count / 2)) $next .= '</ul><ul class="sc_matches_list">';
            if ($style == 'matches-3' && $i == ceil($count / 2)) $next .= '</ul><ul class="sc_matches_list">';
            if ($style == 'matches-4' && $i == ceil($count / 2)) $next .= '</ul><ul class="sc_matches_list">';
            if ($style == 'matches-1'){
                $next .= '<li class="sc_match" data-item="#'.esc_attr($id ? $id . '_' . $i : '').'">'
                    .'<div class="sc_match_date">'
                    .'<span class="day">'.date("d", strtotime($post_meta['match_date'])).'</span>'
                    .'<span class="month">'.date("F", strtotime($post_meta['match_date'])).'</span>'
                    .'</div>'
                    .'<div class="sc_match_info">'
                    .'<div class="name">'.trim($post_data['post_title']).'</div>'
                    .'<div class="time">'.trim($post_meta['match_time']).', </div>'
                    .'<div class="players">'.trim($post_meta['match_player_1']).' - '.trim($post_meta['match_player_2']).'</div>'
                    .'</div>'
                    .'</li>';
            }
            else{
                $player_obj = (intval($post_meta['match_player_1']) > 0 ? get_post($post_meta['match_player_1'], OBJECT) : trx_utils_get_post_by_title($post_meta['match_player_1'], 'players'));
                $player_photo_1 = wp_get_attachment_url(get_post_thumbnail_id($player_obj->ID));
                $player_photo_1 = soccerclub_get_resized_image_tag($player_photo_1, 40, 40);

                $player_obj = (intval($post_meta['match_player_2']) > 0 ? get_post($post_meta['match_player_2'], OBJECT) : trx_utils_get_post_by_title($post_meta['match_player_2'], 'players'));
                $player_photo_2 = wp_get_attachment_url(get_post_thumbnail_id($player_obj->ID));
                $player_photo_2 = soccerclub_get_resized_image_tag($player_photo_2, 40, 40);

                $next .= '<li class="sc_match" data-item="#'.esc_attr($id ? $id . '_' . $i : '').'">'
                    .'<div class="sc_match_date">'
                    .'<span class="day">'.date("d", strtotime($post_meta['match_date'])).'</span>'
                    .'<span class="month">'.date_i18n("F", strtotime($post_meta['match_date'])).'</span>'
                    .'</div>'
                    .'<div class="sc_match_info">'
                    .'<div class="photo">'.trim($player_photo_1).'</div>'
                    .'<div class="name">'.trim($post_meta['match_player_1']).'</div>'
                    .'<div class="vs">VS</div>'
                    .'<div class="name">'.trim($post_meta['match_player_2']).'</div>'
                    .'<div class="photo">'.trim($player_photo_2).'</div>'
                    .'</div>'
                    .'</li>';
            }

            $current .= soccerclub_show_post_layout($args, $post_data);
        }
        wp_reset_postdata();

        if($style == 'matches-1'){
            $output .= $next .'</ul></div><!-- /.sc_matches_next -->';
            $output .= $current;
        }
        else if($style == 'matches-2'){
            $output .= $current;
        }
        else if($style == 'matches-3'){
            $output .= $current;
        }
        else if($style == 'matches-4'){
            $output .= $current;
        }
        $output .= (!empty($link) ? '<div class="sc_matches_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</ul></div><!-- /.sc_matches_current -->'
            . ($style == 'matches-2' ? $next .'</ul></div><!-- /.sc_matches_next -->' : '')
            . ($style == 'matches-3' ? $next .'</ul></div><!-- /.sc_matches_next -->' : '')
            . ($style == 'matches-4' ? $next .'</ul></div><!-- /.sc_matches_next -->' : '')
            . '</div><!-- /.sc_matches -->'
            . '</div><!-- /.sc_matches_wrap -->';


        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_matches', $atts, $content);
    }
    add_shortcode('trx_matches', 'soccerclub_sc_matches');
}
// ---------------------------------- [/trx_matches] ---------------------------------------


// ---------------------------------- [trx_latest_matches] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_latest_matches' ) ) {
    function soccerclub_sc_latest_matches($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => 'matches-1',
            "cat" => "",
            "align" => "",
            "count" => 4,
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));
        $columns = 0;

        if (empty($id)) $id = "sc_latest_matches_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_latest_matches_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            .'<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_latest_matches style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            .'"'
            . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
            . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_latest_matches_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_latest_matches_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_latest_matches_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            .'<ul class="sc_latest_matches_list">';

        global $post;

        $args = array(
            'post_type' => 'matches',
            'post_status' => 'publish',
			'posts_per_page' => $count,
            'ignore_sticky_posts' => true,
            'order' => 'asc'
        );
        $args = soccerclub_query_add_sort_order($args, 'date', 'asc');
        $args = soccerclub_query_add_posts_and_cats($args, '', 'matches', $cat, 'matches_group');
        $query = new WP_Query( $args );

        $matches = array();
        $matches['0'] = date('Y-m-d');
        $matches_ids = array();

        // Create a field matches, where index is post_id and value id match_date
        while ( $query->have_posts() ) {
            $query->the_post();
            $args = array(
                'layout' => $style,
                'orderby' => 'date'
            );
            $post_data = soccerclub_get_post_data($args);
            $post_meta = get_post_meta($post_data['post_id'], soccerclub_storage_get('options_prefix') . '_post_options', true);
            $matches[$post_data['post_id']] = $post_meta['match_date'];
        }

        // Sort matches by the date
	    arsort($matches);

        // Create a new field, where index is a number and value is post_id
        $N = 0;
        $M = 0;
        foreach($matches as $i => $v)
        {
            $matches_ids[$N] = $i;
            if($i == 0) $M = $N;
            $N++;
        }

        // Create a new field with X latest matches
        $matches = array();
        for($i = 0; $i < $count; $i++)
        {
            if(array_key_exists($M + 1, $matches_ids)){
                $matches[$i] = $matches_ids[$M + 1];
                $M++;
            }
        }

        // Return matches content
        for($i = 0; $i < $count; $i++)
        {
            if(array_key_exists($i, $matches) && !empty($matches[$i])){
				$args = array(
                    'layout' => $style,
                    'show' => false,
                    'number' => $i,
                    "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                    "orderby" => 'date',
                    'content' => false,
                    'terms_list' => false,
                    'columns_count' => $columns,
                    'tag_id' => $id ? $id . '_' . $i : '',
                    'tag_class' => '',
                    'tag_animation' => '',
                    'tag_css' => '',
                    'tag_css_wh' => $ws . $hs
                );
                $post_data = soccerclub_get_post_data($args, $matches[$i]);
                $post_meta = get_post_meta($matches[$i], soccerclub_storage_get('options_prefix') . '_post_options', true);
                $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
                $args['name'] = $post_data['post_title'];
                $args['date'] = $post_meta['match_date'];
                $args['time'] = $post_meta['match_time'];
                $args['player_1'] = $post_meta['match_player_1'];
                $args['points_1'] = $post_meta['match_points_1'];
                $args['player_2'] = $post_meta['match_player_2'];
                $args['points_2'] = $post_meta['match_points_2'];
                $args['score'] = $post_meta['match_score'];
                $args['image'] = $post_data['post_thumb'];
                $args['link'] = soccerclub_param_is_on('match_show_link')
                    ? (!empty($post_meta['match_link']) ? $post_meta['match_link'] : $post_data['post_link'])
                    : '';

                $output .= soccerclub_show_post_layout($args, $post_data);
            }
        }
        wp_reset_postdata();

        $output .= 	'</ul><!-- /.sc_latest_matches_list -->'
            .(!empty($link) ? '<div class="sc_matches_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_matches -->'
            . '</div><!-- /.sc_matches_wrap -->';

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_latest_matches', $atts, $content);
    }
    add_shortcode('trx_latest_matches', 'soccerclub_sc_latest_matches');
}
// ---------------------------------- [/trx_latest_matches] ---------------------------------------



// Add [trx_matches] in the shortcodes list
if (!function_exists('soccerclub_matches_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_matches_reg_shortcodes');
    function soccerclub_matches_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
            $matches_styles = soccerclub_get_list_templates('matches');
            $controls 		= soccerclub_get_list_slider_controls();
            $players = soccerclub_get_list_posts(false, array(
                    'post_type'=>'players',
                    'orderby'=>'title',
                    'order'=>'asc',
                    'return'=>'title'
                )
            );
            soccerclub_sc_map_after('trx_chat', array(

                // Matches
                "trx_matches" => array(
                    "title" => esc_html__("Matches", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert matches list in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "style" => array(
                            "title" => esc_html__("Style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Style of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "select",
                            "options" => array(
                                'matches-1'  => esc_html__('Style 1', 'trx_utils'),
                                'matches-2' => esc_html__('Style 2', 'trx_utils'),
                                'matches-3' => esc_html__('Style 3', 'trx_utils'),
                                'matches-4' => esc_html__('Style 4', 'trx_utils')
                            ),
                            "type" => "checklist"
                        ),
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "title_next" => array(
                            "title" => esc_html__("Title (2)", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the NEXT block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle_next" => array(
                            "title" => esc_html__("Subtitle (2)", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the NEXT block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description_next" => array(
                            "title" => esc_html__("Description (2)", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the NEXT block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show team members. If empty - select team members from any category (group) or from IDs list", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of matches", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many matches will be displayed?", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the matches block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    )
                )

            ));
        }
    }
}


// Add [trx_latest_matches] in the shortcodes list
if (!function_exists('soccerclub_latest_matches_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_latest_matches_reg_shortcodes');
    function soccerclub_latest_matches_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
            $matches_styles = soccerclub_get_list_templates('matches');
            $controls 		= soccerclub_get_list_slider_controls();
            $players = soccerclub_get_list_posts(false, array(
                    'post_type'=>'players',
                    'orderby'=>'title',
                    'order'=>'asc',
                    'return'=>'title'
                )
            );
            soccerclub_sc_map_after('trx_chat', array(

                // Latest Matches
                "trx_latest_matches" => array(
                    "title" => esc_html__("Latest Matches", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert latest matches list in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show team members. If empty - select team members from any category (group) or from IDs list", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of matches", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many matches will be displayed?", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the matches block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    )
                )

            ));
        }
    }
}

// Add [trx_matches] in the VC shortcodes list
if (!function_exists('soccerclub_matches_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_matches_reg_shortcodes_vc');
    function soccerclub_matches_reg_shortcodes_vc() {

        $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
        $matches_styles = soccerclub_get_list_templates('matches');
        $controls		= soccerclub_get_list_slider_controls();
        $players = soccerclub_get_list_posts(false, array(
                'post_type'=>'players',
                'orderby'=>'title',
                'order'=>'asc',
                'return'=>'title'
            )
        );

        // Matches
        vc_map( array(
            "base" => "trx_matches",
            "name" => esc_html__("Matches", 'trx_utils'),
            "description" => wp_kses_data( __("Insert matches list", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_matches',
            "class" => "trx_sc_single trx_sc_matches",
            "content_element" => true,
            "is_container" => false,
            "show_settings_on_create" => true,
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Table style", 'trx_utils'),
                    "description" => wp_kses_data( __("Style of the block", 'trx_utils') ),
                    "class" => "",
                    "value" => array(
                        esc_html__('Style 1', 'trx_utils') => 'matches-1',
                        esc_html__('Style 2', 'trx_utils') => 'matches-2',
                        esc_html__('Style 3', 'trx_utils') => 'matches-3',
                        //esc_html__('Style 4', 'trx_utils') => 'matches-4'
                    ),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "title_next",
                    "heading" => esc_html__("Title  (2)", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the NEXT block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle_next",
                    "heading" => esc_html__("Subtitle  (2)", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the NEXT block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description_next",
                    "heading" => esc_html__("Description  (2)", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the NEXT block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show matches. If empty - select matches from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of matches", 'trx_utils'),
                    "description" => wp_kses_data( __("How many matches will be displayed?", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the matches block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxSingleView'
        ) );

        class WPBakeryShortCode_Trx_Matches extends Soccerclub_Vc_ShortCodeSingle {}
    }
}

// Add [trx_latest_matches] in the VC shortcodes list
if (!function_exists('soccerclub_latest_matches_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_latest_matches_reg_shortcodes_vc');
    function soccerclub_latest_matches_reg_shortcodes_vc() {

        $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
        $matches_styles = soccerclub_get_list_templates('matches');
        $controls		= soccerclub_get_list_slider_controls();
        $players = soccerclub_get_list_posts(false, array(
                'post_type'=>'players',
                'orderby'=>'title',
                'order'=>'asc',
                'return'=>'title'
            )
        );
        // Latest Matches
        vc_map( array(
            "base" => "trx_latest_matches",
            "name" => esc_html__("Latest Matches", 'trx_utils'),
            "description" => wp_kses_data( __("Insert latest matches list", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_matches',
            "class" => "trx_sc_single trx_sc_latest_matches",
            "content_element" => true,
            "is_container" => false,
            "show_settings_on_create" => true,
            "params" => array(
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show matches. If empty - select matches from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of matches", 'trx_utils'),
                    "description" => wp_kses_data( __("How many matches will be displayed?", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the matches block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxSingleView'
        ) );

        class WPBakeryShortCode_Trx_Latest_Matches extends Soccerclub_Vc_ShortCodeSingle {}
    }
}


// ---------------------------------- [trx_players] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_players' ) ) {
    function soccerclub_sc_players($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "slider" => "no",
            "controls" => "no",
            "slides_space" => 0,
            "interval" => "",
            "autoheight" => "no",
            "align" => "",
            "custom" => "no",
            "ids" => "",
            "cat" => "",
            "count" => 3,
            "columns" => 3,
            "offset" => "",
            "orderby" => "date",
            "order" => "desc",
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));
        $style = 'players-1';
        if (empty($id)) $id = "sc_players_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";
        if (empty($interval)) $interval = mt_rand(5000, 10000);

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $count = max(1, (int) $count);
        $columns = max(1, min(12, (int) $columns));
        if (soccerclub_param_is_off($custom) && $count < $columns) $columns = $count;

        soccerclub_storage_set('sc_players_data', array(
                'id' => $id,
                'style' => $style,
                'columns' => $columns,
                'counter' => 0,
                'slider' => $slider,
                'css_wh' => $ws . $hs
            )
        );

        if (soccerclub_param_is_on($slider)) soccerclub_enqueue_slider('swiper');

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_players_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            . '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_players sc_players_style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . ' ' . esc_attr(soccerclub_get_slider_controls_classes($controls))
            . (soccerclub_param_is_on($slider)
                ? ' sc_slider_swiper swiper-slider-container'
                . (soccerclub_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
                . ($hs ? ' sc_slider_height_fixed' : '')
                : '')
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            .'"'
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
            . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
            . ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
            . ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
            . ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
            . ' data-slides-min-width="250"'
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_players_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_players_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_players_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            . (soccerclub_param_is_on($slider)
                ? '<div class="slides swiper-wrapper">'
                : ($columns > 1
                    ? '<div class="sc_columns columns_wrap">'
                    : '')
            );


        global $post;

        if (!empty($ids)) {
            $posts = explode(',', $ids);
            $count = count($posts);
        }

        $args = array(
            'post_type' => 'players',
            'post_status' => 'publish',
            'posts_per_page' => $count,
            'ignore_sticky_posts' => true,
            'order' => $order=='asc' ? 'asc' : 'desc',
        );

        if ($offset > 0 && empty($ids)) {
            $args['offset'] = $offset;
        }

        $args = soccerclub_query_add_sort_order($args, $orderby, $order);
        $args = soccerclub_query_add_posts_and_cats($args, $ids, 'players', $cat, 'players_group');
        $query = new WP_Query( $args );

        $post_number = 0;

        while ( $query->have_posts() ) {
            $query->the_post();
            $post_number++;
            $args = array(
                'layout' => $style,
                'show' => false,
                'number' => $post_number,
                'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
                "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                "orderby" => $orderby,
                'content' => false,
                'terms_list' => false,
                "columns_count" => $columns,
                'slider' => $slider,
                'tag_id' => $id ? $id . '_' . $post_number : '',
                'tag_class' => '',
                'tag_animation' => '',
                'tag_css' => '',
                'tag_css_wh' => $ws . $hs
            );
            $post_data = soccerclub_get_post_data($args);
            $post_meta = get_post_meta($post_data['post_id'], soccerclub_storage_get('options_prefix') . '_post_options', true);
            $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
            $args['country'] = $post_meta['player_country'];
            $args['club'] = $post_meta['player_club'];
            $args['type'] = $post_meta['player_type'];
            $args['age'] = $post_meta['player_age'];
            $args['link'] = $post_data['post_link'];
            $args['photo'] = $post_data['post_thumb'];
            $mult = soccerclub_get_retina_multiplier();
            if (empty($args['photo']) && !empty($args['email'])) $args['photo'] = get_avatar($args['email'], $thumb_sizes['w']*$mult);
            $args['socials'] = '';
            if (!empty($post_meta['player_socials']) && !soccerclub_param_is_inherit($post_meta['player_socials']))
                $args['socials'] = soccerclub_do_shortcode('[trx_socials size="tiny" shape="round" socials="'.esc_attr($post_meta['player_socials']).'"][/trx_socials]');

            $output .= soccerclub_show_post_layout($args, $post_data);
        }
        wp_reset_postdata();


        if (soccerclub_param_is_on($slider)) {
            $output .= '</div>'
                . '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
                . '<div class="sc_slider_pagination_wrap"></div>';
        } else if ($columns > 1) {
            $output .= '</div>';
        }

        $output .= (!empty($link) ? '<div class="sc_players_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_players -->'
            . '</div><!-- /.sc_players_wrap -->';

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_players', $atts, $content);
    }
    add_shortcode('trx_players', 'soccerclub_sc_players');
}

// ---------------------------------- [/trx_players] ---------------------------------------



// ---------------------------------- [trx_players_table] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_players_table' ) ) {
    function soccerclub_sc_players_table($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => "1",
            "cat" => "",
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            "align" => "",
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));
        $output = '';

        if (empty($id)) $id = "sc_players_table_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_players_table_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            .'<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_players_table style_'.$style
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            .'"'
            . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
            . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . ' data-sort="asc"'
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_players_table_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_players_table_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_players_table_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '');


        $matches = array();
        $categories = '';
        $table = array();

        if(!empty($cat))
            $matches = soccerclub_get_matches_by_term($cat);
        else{
            $terms = get_terms( 'matches_group' );
            if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
                $output .= '<div class="sc_players_table_category"><div class="label">'.esc_html__('Select category', 'trx_utils').'</div><select>';
                $output .= '<option data-cat="all">'.esc_html__('All', 'trx_utils').'</option>';

                foreach ( $terms as $term ) {
                    $matches = array_merge($matches, soccerclub_get_matches_by_term($term->term_id));
                    $output .= '<option data-cat="'.$term->term_id.'">'.$term->name.'</option>';
                }

                $output .= '<select></div>';
            }
        }

        if(!empty($matches)){
            foreach ( $matches as $match ) {
                $post_meta = get_post_meta($match->object_id, soccerclub_storage_get('options_prefix') . '_post_options', true);

                $post_categories = wp_get_post_terms( $match->object_id,  'matches_group');

                foreach($post_categories as $c){
                    $cat = get_category( $c );
                    $categories .= $cat->term_id.'|' ;
                }

                $player = $post_meta['match_player_1'];
                $player_obj = (intval($player) > 0 ? get_post($player, OBJECT) : trx_utils_get_post_by_title($player, 'players'));
                $player_id = $player_obj->ID;

                if(!array_key_exists($player_id, $table))
                    $table[$player_id] = array( 0 => get_post_meta($player_id, 'points', true), 1 => $categories);

                $player = $post_meta['match_player_2'];
                $player_obj = (intval($player) > 0 ? get_post($player, OBJECT) : trx_utils_get_post_by_title($player, 'players'));
                $player_id = $player_obj->ID;

                if(!array_key_exists($player_id, $table))
                    $table[$player_id] = array( 0 => get_post_meta($player_id, 'points', true), 1 => $categories);

                $categories = '';
            }
        }

        if(!empty($table)){
            soccerclub_storage_set_array('js_vars', 'ajax_'.$id, serialize($table));
            $output .= soccerclub_get_players_table('asc', $table);
        }

        $output .= (!empty($link) ? '<div class="sc_players_table_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_players_table -->'
            . '</div><!-- /.sc_players_table_wrap -->';

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_players_table', $atts, $content);
    }
    add_shortcode('trx_players_table', 'soccerclub_sc_players_table');
}
// ---------------------------------- [/trx_players_table] ---------------------------------------



// Add [trx_players] in the shortcodes list
if (!function_exists('soccerclub_players_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_players_reg_shortcodes');
    function soccerclub_players_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $players_groups = soccerclub_get_list_terms(false, 'players_group');
            $controls	 = soccerclub_get_list_slider_controls();

            soccerclub_sc_map_after('trx_tabs', array(

                // Players
                "trx_players" => array(
                    "title" => esc_html__("Clubs", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert Clubs in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "columns" => array(
                            "title" => esc_html__("Columns", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many columns use to show Clubs", 'trx_utils') ),
                            "value" => 3,
                            "min" => 2,
                            "max" => 5,
                            "step" => 1,
                            "type" => "spinner"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "slider" => array(
                            "title" => esc_html__("Slider", 'trx_utils'),
                            "desc" => wp_kses_data( __("Use slider to show Clubs", 'trx_utils') ),
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "controls" => array(
                            "title" => esc_html__("Controls", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => $controls
                        ),
                        "slides_space" => array(
                            "title" => esc_html__("Space between slides", 'trx_utils'),
                            "desc" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "max" => 100,
                            "step" => 10,
                            "type" => "spinner"
                        ),
                        "interval" => array(
                            "title" => esc_html__("Slides change interval", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 7000,
                            "step" => 500,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "autoheight" => array(
                            "title" => esc_html__("Autoheight", 'trx_utils'),
                            "desc" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => "yes",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the players block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show players. If empty - select players from any category (group) or from IDs list", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $players_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 3,
                            "min" => 1,
                            "max" => 100,
                            "type" => "spinner"
                        ),
                        "offset" => array(
                            "title" => esc_html__("Offset before select posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "orderby" => array(
                            "title" => esc_html__("Post order by", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "title",
                            "type" => "select",
                            "options" => soccerclub_get_sc_param('sorting')
                        ),
                        "order" => array(
                            "title" => esc_html__("Post order", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "asc",
                            "type" => "switch",
                            "size" => "big",
                            "options" => soccerclub_get_sc_param('ordering')
                        ),
                        "ids" => array(
                            "title" => esc_html__("Post IDs list", 'trx_utils'),
                            "desc" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    )
                )

            ));
        }
    }
}


// Add [trx_players_table] in the shortcodes list
if (!function_exists('soccerclub_players_table_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_players_table_reg_shortcodes');
    function soccerclub_players_table_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
            $controls	 = soccerclub_get_list_slider_controls();

            soccerclub_sc_map_after('trx_tabs', array(

                // Players Table
                "trx_players_table" => array(
                    "title" => esc_html__("Clubs Table", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert Clubs table in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "style" => array(
                            "title" => esc_html__("Style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Style of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "select",
                            "options" => array(
                                '1'  => esc_html__('Style 1', 'trx_utils'),
                                '2' => esc_html__('Style 2', 'trx_utils')
                            ),
                            "type" => "checklist"
                        ),
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show players.", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the Clubs table", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    )
                )

            ));
        }
    }
}



// Add [trx_players] in the VC shortcodes list
if (!function_exists('soccerclub_players_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_players_reg_shortcodes_vc');
    function soccerclub_players_reg_shortcodes_vc() {

        $players_groups = soccerclub_get_list_terms(false, 'players_group');
        $controls	 = soccerclub_get_list_slider_controls();

        // Players
        vc_map( array(
            "base" => "trx_players",
            "name" => esc_html__("Clubs", 'trx_utils'),
            "description" => wp_kses_data( __("Insert clubs", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_players',
            "class" => "trx_sc_single trx_sc_players",
            "content_element" => true,
            "is_container" => false,
            "show_settings_on_create" => true,
            "params" => array(
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slider",
                    "heading" => esc_html__("Slider", 'trx_utils'),
                    "description" => wp_kses_data( __("Use slider to show players", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip(soccerclub_get_sc_param('yes_no')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "controls",
                    "heading" => esc_html__("Controls", 'trx_utils'),
                    "description" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip($controls),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slides_space",
                    "heading" => esc_html__("Space between slides", 'trx_utils'),
                    "description" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "interval",
                    "heading" => esc_html__("Slides change interval", 'trx_utils'),
                    "description" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "7000",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "autoheight",
                    "heading" => esc_html__("Autoheight", 'trx_utils'),
                    "description" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => array("Autoheight" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the players block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show players. If empty - select players from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $players_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "columns",
                    "heading" => esc_html__("Columns", 'trx_utils'),
                    "description" => wp_kses_data( __("How many columns use to show players", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "3",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of posts", 'trx_utils'),
                    "description" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "3",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "offset",
                    "heading" => esc_html__("Offset before select posts", 'trx_utils'),
                    "description" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "orderby",
                    "heading" => esc_html__("Post sorting", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('sorting')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "order",
                    "heading" => esc_html__("Post order", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('ordering')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "ids",
                    "heading" => esc_html__("Player's IDs list", 'trx_utils'),
                    "description" => wp_kses_data( __("Comma separated list of players's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            )
        ) );
        class WPBakeryShortCode_Trx_Players extends Soccerclub_Vc_ShortCodeSingle {}
    }
}


// Add [trx_players_table] in the VC shortcodes list
if (!function_exists('soccerclub_players_table_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_players_table_reg_shortcodes_vc');
    function soccerclub_players_table_reg_shortcodes_vc() {

        $matches_groups = soccerclub_get_list_terms(false, 'matches_group');
        $controls	 = soccerclub_get_list_slider_controls();

        // Players Table
        vc_map( array(
            "base" => "trx_players_table",
            "name" => esc_html__("Clubs Table", 'trx_utils'),
            "description" => wp_kses_data( __("Insert clubs table", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_players',
            "class" => "trx_sc_single trx_sc_players_table",
            "content_element" => true,
            "is_container" => false,
            "show_settings_on_create" => true,
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Table style", 'trx_utils'),
                    "description" => wp_kses_data( __("Style of the block", 'trx_utils') ),
                    "class" => "",
                    "value" => array(
                        esc_html__('Style 1', 'trx_utils') => '1',
                        esc_html__('Style 2', 'trx_utils') => '2'
                    ),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the players table", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show players. If empty - select players from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $matches_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            )
        ) );
        class WPBakeryShortCode_Trx_Players_Table extends Soccerclub_Vc_ShortCodeSingle {}
    }
}



// ---------------------------------- [trx_services] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_services' ) ) {
    function soccerclub_sc_services($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => "services-1",
            "columns" => 4,
            "slider" => "no",
            "slides_space" => 0,
            "controls" => "no",
            "interval" => "",
            "autoheight" => "no",
            "align" => "",
            "custom" => "no",
            "type" => "icons",	// icons | images
            "ids" => "",
            "cat" => "",
            "count" => 4,
            "offset" => "",
            "orderby" => "date",
            "order" => "desc",
            "readmore" => esc_html__('Learn more', 'trx_utils'),
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            "image" => '',
            "image_align" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));

        if (soccerclub_param_is_off($slider) && $columns > 1 && $style == 'services-5' && !empty($image)) $columns = 2;
        if (!empty($image)) {
            if ($image > 0) {
                $attach = wp_get_attachment_image_src( $image, 'full' );
                if (isset($attach[0]) && $attach[0]!='')
                    $image = $attach[0];
            }
        }

        if (empty($id)) $id = "sc_services_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";
        if (empty($interval)) $interval = mt_rand(5000, 10000);

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $columns = max(1, min(12, (int) $columns));
        $count = max(1, (int) $count);
        if (soccerclub_param_is_off($custom) && $count < $columns) $columns = $count;

        if (soccerclub_param_is_on($slider)) soccerclub_enqueue_slider('swiper');

        soccerclub_storage_set('sc_services_data', array(
                'id' => $id,
                'style' => $style,
                'type' => $type,
                'columns' => $columns,
                'counter' => 0,
                'slider' => $slider,
                'css_wh' => $ws . $hs,
                'readmore' => $readmore
            )
        );

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_services_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            . '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_services'
            . ' sc_services_style_'.esc_attr($style)
            . ' sc_services_type_'.esc_attr($type)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            . '"'
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_services_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_services_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_services_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            . (soccerclub_param_is_on($slider)
                ? ('<div class="sc_slider_swiper swiper-slider-container'
                    . ' ' . esc_attr(soccerclub_get_slider_controls_classes($controls))
                    . (soccerclub_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
                    . ($hs ? ' sc_slider_height_fixed' : '')
                    . '"'
                    . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
                    . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
                    . ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
                    . ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
                    . ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
                    . ' data-slides-min-width="250"'
                    . '>'
                    . '<div class="slides swiper-wrapper">')
                : ($columns > 1
                    ? ($style == 'services-5' && !empty($image)
                        ? '<div class="sc_service_container sc_align_'.esc_attr($image_align).'">'
                        . '<div class="sc_services_image"><img src="'.esc_url($image).'" alt="'.esc_attr__('Service', 'trx_utils').'"></div>'
                        : '')
                    . '<div class="sc_columns columns_wrap">'
                    : '')
            );

        $content = do_shortcode($content);

        if (soccerclub_param_is_on($custom) && $content) {
            $output .= $content;
        } else {
            global $post;

            if (!empty($ids)) {
                $posts = explode(',', $ids);
                $count = count($posts);
            }

            $args = array(
                'post_type' => 'services',
                'post_status' => 'publish',
                'posts_per_page' => $count,
                'ignore_sticky_posts' => true,
                'order' => $order=='asc' ? 'asc' : 'desc',
                'readmore' => $readmore
            );

            if ($offset > 0 && empty($ids)) {
                $args['offset'] = $offset;
            }

            $args = soccerclub_query_add_sort_order($args, $orderby, $order);
            $args = soccerclub_query_add_posts_and_cats($args, $ids, 'services', $cat, 'services_group');

            $query = new WP_Query( $args );

            $post_number = 0;

            while ( $query->have_posts() ) {
                $query->the_post();
                $post_number++;
                $args = array(
                    'layout' => $style,
                    'show' => false,
                    'number' => $post_number,
                    'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
                    "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                    "orderby" => $orderby,
                    'content' => false,
                    'terms_list' => false,
                    'readmore' => $readmore,
                    'tag_type' => $type,
                    'columns_count' => $columns,
                    'slider' => $slider,
                    'tag_id' => $id ? $id . '_' . $post_number : '',
                    'tag_class' => '',
                    'tag_animation' => '',
                    'tag_css' => '',
                    'tag_css_wh' => $ws . $hs
                );
                $output .= soccerclub_show_post_layout($args);
            }
            wp_reset_postdata();
        }

        if (soccerclub_param_is_on($slider)) {
            $output .= '</div>'
                . '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
                . '<div class="sc_slider_pagination_wrap"></div>'
                . '</div>';
        } else if ($columns > 1) {
            $output .= '</div>';
            if ($style == 'services-5' && !empty($image))
                $output .= '</div>';
        }

        $output .=  (!empty($link) ? '<div class="sc_services_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_services -->'
            . '</div><!-- /.sc_services_wrap -->';

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_services', $atts, $content);
    }
    add_shortcode('trx_services', 'soccerclub_sc_services');
}


if ( !function_exists( 'soccerclub_sc_services_item' ) ) {
    function soccerclub_sc_services_item($atts, $content=null) {
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts( array(
            // Individual params
            "icon" => "",
            "image" => "",
            "title" => "",
            "link" => "",
            "readmore" => "(none)",
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => ""
        ), $atts)));

        soccerclub_storage_inc_array('sc_services_data', 'counter');

        $id = $id ? $id : (soccerclub_storage_get_array('sc_services_data', 'id') ? soccerclub_storage_get_array('sc_services_data', 'id') . '_' . soccerclub_storage_get_array('sc_services_data', 'counter') : '');

        $descr = trim(chop(do_shortcode($content)));
        $readmore = $readmore=='(none)' ? soccerclub_storage_get_array('sc_services_data', 'readmore') : $readmore;

        $type = soccerclub_storage_get_array('sc_services_data', 'type');
        if (!empty($icon)) {
            $type = 'icons';
        } else if (!empty($image)) {
            $type = 'images';
            if ($image > 0) {
                $attach = wp_get_attachment_image_src( $image, 'full' );
                if (isset($attach[0]) && $attach[0]!='')
                    $image = $attach[0];
            }
            $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => soccerclub_storage_get_array('sc_services_data', 'style')));
            $image = soccerclub_get_resized_image_tag($image, $thumb_sizes['w'], $thumb_sizes['h']);
        }

        $post_data = array(
            'post_title' => $title,
            'post_excerpt' => $descr,
            'post_thumb' => $image,
            'post_icon' => $icon,
            'post_link' => $link,
            'post_protected' => false,
            'post_format' => 'standard'
        );
        $args = array(
            'layout' => soccerclub_storage_get_array('sc_services_data', 'style'),
            'number' => soccerclub_storage_get_array('sc_services_data', 'counter'),
            'columns_count' => soccerclub_storage_get_array('sc_services_data', 'columns'),
            'slider' => soccerclub_storage_get_array('sc_services_data', 'slider'),
            'show' => false,
            'descr'  => -1,		// -1 - don't strip tags, 0 - strip_tags, >0 - strip_tags and truncate string
            'readmore' => $readmore,
            'tag_type' => $type,
            'tag_id' => $id,
            'tag_class' => $class,
            'tag_animation' => $animation,
            'tag_css' => $css,
            'tag_css_wh' => soccerclub_storage_get_array('sc_services_data', 'css_wh')
        );
        $output = soccerclub_show_post_layout($args, $post_data);
        return apply_filters('soccerclub_shortcode_output', $output, 'trx_services_item', $atts, $content);
    }
    add_shortcode('trx_services_item', 'soccerclub_sc_services_item');
}
// ---------------------------------- [/trx_services] ---------------------------------------



// Add [trx_services] and [trx_services_item] in the shortcodes list
if (!function_exists('soccerclub_services_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_services_reg_shortcodes');
    function soccerclub_services_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $services_groups = soccerclub_get_list_terms(false, 'services_group');
            $services_styles = soccerclub_get_list_templates('services');
            $controls 		 = soccerclub_get_list_slider_controls();

            soccerclub_sc_map_after('trx_section', array(

                // Services
                "trx_services" => array(
                    "title" => esc_html__("Services", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert services list in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "style" => array(
                            "title" => esc_html__("Services style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select style to display services list", 'trx_utils') ),
                            "value" => "services-1",
                            "type" => "select",
                            "options" => $services_styles
                        ),
                        "image" => array(
                            "title" => esc_html__("Item's image", 'trx_utils'),
                            "desc" => wp_kses_data( __("Item's image", 'trx_utils') ),
                            "dependency" => array(
                                'style' => 'services-5'
                            ),
                            "value" => "",
                            "readonly" => false,
                            "type" => "media"
                        ),
                        "image_align" => array(
                            "title" => esc_html__("Image alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the image", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "type" => array(
                            "title" => esc_html__("Icon's type", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select type of icons: font icon or image", 'trx_utils') ),
                            "value" => "icons",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => array(
                                'icons'  => esc_html__('Icons', 'trx_utils'),
                                'images' => esc_html__('Images', 'trx_utils')
                            )
                        ),
                        "columns" => array(
                            "title" => esc_html__("Columns", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many columns use to show services list", 'trx_utils') ),
                            "value" => 4,
                            "min" => 2,
                            "max" => 6,
                            "step" => 1,
                            "type" => "spinner"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "slider" => array(
                            "title" => esc_html__("Slider", 'trx_utils'),
                            "desc" => wp_kses_data( __("Use slider to show services", 'trx_utils') ),
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "controls" => array(
                            "title" => esc_html__("Controls", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => $controls
                        ),
                        "slides_space" => array(
                            "title" => esc_html__("Space between slides", 'trx_utils'),
                            "desc" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "max" => 100,
                            "step" => 10,
                            "type" => "spinner"
                        ),
                        "interval" => array(
                            "title" => esc_html__("Slides change interval", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 7000,
                            "step" => 500,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "autoheight" => array(
                            "title" => esc_html__("Autoheight", 'trx_utils'),
                            "desc" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => "yes",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the services block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "custom" => array(
                            "title" => esc_html__("Custom", 'trx_utils'),
                            "desc" => wp_kses_data( __("Allow get services items from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                            "divider" => true,
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show services list. If empty - select services from any category (group) or from IDs list", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $services_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 4,
                            "min" => 1,
                            "max" => 100,
                            "type" => "spinner"
                        ),
                        "offset" => array(
                            "title" => esc_html__("Offset before select posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "orderby" => array(
                            "title" => esc_html__("Post order by", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "date",
                            "type" => "select",
                            "options" => soccerclub_get_sc_param('sorting')
                        ),
                        "order" => array(
                            "title" => esc_html__("Post order", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "desc",
                            "type" => "switch",
                            "size" => "big",
                            "options" => soccerclub_get_sc_param('ordering')
                        ),
                        "ids" => array(
                            "title" => esc_html__("Post IDs list", 'trx_utils'),
                            "desc" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "readmore" => array(
                            "title" => esc_html__("Read more", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the Read more link (if empty - link not showed)", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    ),
                    "children" => array(
                        "name" => "trx_services_item",
                        "title" => esc_html__("Service item", 'trx_utils'),
                        "desc" => wp_kses_data( __("Service item", 'trx_utils') ),
                        "container" => true,
                        "params" => array(
                            "title" => array(
                                "title" => esc_html__("Title", 'trx_utils'),
                                "desc" => wp_kses_data( __("Item's title", 'trx_utils') ),
                                "divider" => true,
                                "value" => "",
                                "type" => "text"
                            ),
                            "icon" => array(
                                "title" => esc_html__("Item's icon",  'trx_utils'),
                                "desc" => wp_kses_data( __('Select icon for the item from Fontello icons set',  'trx_utils') ),
                                "value" => "",
                                "type" => "icons",
                                "options" => soccerclub_get_sc_param('icons')
                            ),
                            "image" => array(
                                "title" => esc_html__("Item's image", 'trx_utils'),
                                "desc" => wp_kses_data( __("Item's image (if icon not selected)", 'trx_utils') ),
                                "dependency" => array(
                                    'icon' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "readonly" => false,
                                "type" => "media"
                            ),
                            "link" => array(
                                "title" => esc_html__("Link", 'trx_utils'),
                                "desc" => wp_kses_data( __("Link on service's item page", 'trx_utils') ),
                                "divider" => true,
                                "value" => "",
                                "type" => "text"
                            ),
                            "readmore" => array(
                                "title" => esc_html__("Read more", 'trx_utils'),
                                "desc" => wp_kses_data( __("Caption for the Read more link (if empty - link not showed)", 'trx_utils') ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "_content_" => array(
                                "title" => esc_html__("Description", 'trx_utils'),
                                "desc" => wp_kses_data( __("Item's short description", 'trx_utils') ),
                                "divider" => true,
                                "rows" => 4,
                                "value" => "",
                                "type" => "textarea"
                            ),
                            "id" => soccerclub_get_sc_param('id'),
                            "class" => soccerclub_get_sc_param('class'),
                            "animation" => soccerclub_get_sc_param('animation'),
                            "css" => soccerclub_get_sc_param('css')
                        )
                    )
                )

            ));
        }
    }
}


// Add [trx_services] and [trx_services_item] in the VC shortcodes list
if (!function_exists('soccerclub_services_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_services_reg_shortcodes_vc');
    function soccerclub_services_reg_shortcodes_vc() {

        $services_groups = soccerclub_get_list_terms(false, 'services_group');
        $services_styles = soccerclub_get_list_templates('services');
        $controls		 = soccerclub_get_list_slider_controls();

        // Services
        vc_map( array(
            "base" => "trx_services",
            "name" => esc_html__("Services", 'trx_utils'),
            "description" => wp_kses_data( __("Insert services list", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            "icon" => 'icon_trx_services',
            "class" => "trx_sc_columns trx_sc_services",
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "as_parent" => array('only' => 'trx_services_item'),
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Services style", 'trx_utils'),
                    "description" => wp_kses_data( __("Select style to display services list", 'trx_utils') ),
                    "class" => "",
                    "admin_label" => true,
                    "value" => array_flip($services_styles),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "type",
                    "heading" => esc_html__("Icon's type", 'trx_utils'),
                    "description" => wp_kses_data( __("Select type of icons: font icon or image", 'trx_utils') ),
                    "class" => "",
                    "admin_label" => true,
                    "value" => array(
                        esc_html__('Icons', 'trx_utils') => 'icons',
                        esc_html__('Images', 'trx_utils') => 'images'
                    ),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "image",
                    "heading" => esc_html__("Image", 'trx_utils'),
                    "description" => wp_kses_data( __("Item's image", 'trx_utils') ),
                    'dependency' => array(
                        'element' => 'style',
                        'value' => 'services-5'
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                array(
                    "param_name" => "image_align",
                    "heading" => esc_html__("Image alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the image", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slider",
                    "heading" => esc_html__("Slider", 'trx_utils'),
                    "description" => wp_kses_data( __("Use slider to show services", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip(soccerclub_get_sc_param('yes_no')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "controls",
                    "heading" => esc_html__("Controls", 'trx_utils'),
                    "description" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip($controls),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slides_space",
                    "heading" => esc_html__("Space between slides", 'trx_utils'),
                    "description" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "interval",
                    "heading" => esc_html__("Slides change interval", 'trx_utils'),
                    "description" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "7000",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "autoheight",
                    "heading" => esc_html__("Autoheight", 'trx_utils'),
                    "description" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => array("Autoheight" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the services block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "custom",
                    "heading" => esc_html__("Custom", 'trx_utils'),
                    "description" => wp_kses_data( __("Allow get services from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                    "class" => "",
                    "value" => array("Custom services" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show services. If empty - select services from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $services_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "columns",
                    "heading" => esc_html__("Columns", 'trx_utils'),
                    "description" => wp_kses_data( __("How many columns use to show services list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "4",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of posts", 'trx_utils'),
                    "description" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "4",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "offset",
                    "heading" => esc_html__("Offset before select posts", 'trx_utils'),
                    "description" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "orderby",
                    "heading" => esc_html__("Post sorting", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "date",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('sorting')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "order",
                    "heading" => esc_html__("Post order", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "desc",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('ordering')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "ids",
                    "heading" => esc_html__("Service's IDs list", 'trx_utils'),
                    "description" => wp_kses_data( __("Comma separated list of service's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "readmore",
                    "heading" => esc_html__("Read more", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the Read more link (if empty - link not showed)", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'default_content' => '
					[trx_services_item title="' . esc_html__( 'Service item 1', 'trx_utils') . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 2', 'trx_utils') . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 3', 'trx_utils') . '"][/trx_services_item]
					[trx_services_item title="' . esc_html__( 'Service item 4', 'trx_utils') . '"][/trx_services_item]
				',
            'js_view' => 'VcTrxColumnsView'
        ) );


        vc_map( array(
            "base" => "trx_services_item",
            "name" => esc_html__("Services item", 'trx_utils'),
            "description" => wp_kses_data( __("Custom services item - all data pull out from shortcode parameters", 'trx_utils') ),
            "show_settings_on_create" => true,
            "class" => "trx_sc_collection trx_sc_column_item trx_sc_services_item",
            "content_element" => true,
            "is_container" => true,
            'icon' => 'icon_trx_services_item',
            "as_child" => array('only' => 'trx_services'),
            "as_parent" => array('except' => 'trx_services'),
            "params" => array(
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Item's title", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "icon",
                    "heading" => esc_html__("Icon", 'trx_utils'),
                    "description" => wp_kses_data( __("Select icon for the item from Fontello icons set", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => soccerclub_get_sc_param('icons'),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "image",
                    "heading" => esc_html__("Image", 'trx_utils'),
                    "description" => wp_kses_data( __("Item's image (if icon is empty)", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Link", 'trx_utils'),
                    "description" => wp_kses_data( __("Link on item's page", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "readmore",
                    "heading" => esc_html__("Read more", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the Read more link (if empty - link not showed)", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnItemView'
        ) );

        class WPBakeryShortCode_Trx_Services extends Soccerclub_Vc_ShortCodeColumns {}
        class WPBakeryShortCode_Trx_Services_Item extends Soccerclub_Vc_ShortCodeCollection {}

    }
}

// ---------------------------------- [trx_team] ---------------------------------------

if ( !function_exists( 'soccerclub_sc_team' ) ) {
    function soccerclub_sc_team($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => "team-1",
            "slider" => "no",
            "controls" => "no",
            "slides_space" => 0,
            "interval" => "",
            "autoheight" => "no",
            "align" => "",
            "custom" => "no",
            "ids" => "",
            "cat" => "",
            "count" => 3,
            "columns" => 3,
            "offset" => "",
            "orderby" => "title",
            "order" => "asc",
            "title" => "",
            "subtitle" => "",
            "description" => "",
            "link_caption" => esc_html__('Learn more', 'trx_utils'),
            "link" => '',
            "scheme" => '',
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));

        if (empty($id)) $id = "sc_team_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";
        if (empty($interval)) $interval = mt_rand(5000, 10000);

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $count = max(1, (int) $count);
        $columns = max(1, min(12, (int) $columns));
        if (soccerclub_param_is_off($custom) && $count < $columns) $columns = $count;

        soccerclub_storage_set('sc_team_data', array(
                'id' => $id,
                'style' => $style,
                'columns' => $columns,
                'counter' => 0,
                'slider' => $slider,
                'css_wh' => $ws . $hs
            )
        );

        if (soccerclub_param_is_on($slider)) soccerclub_enqueue_slider('swiper');

        $output = '<div' . ($id ? ' id="'.esc_attr($id).'_wrap"' : '')
            . ' class="sc_team_wrap'
            . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
            .'">'
            . '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_team sc_team_style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (soccerclub_param_is_on($slider)
                ?
                : '')
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            .'"'
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_team_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_team_title sc_item_title'.(empty($description) ? ' sc_item_title_wo_desc' : '').'">' . trim($title) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_team_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            . (soccerclub_param_is_on($slider)
                ? ('<div class="sc_slider_swiper swiper-slider-container'
                    . ' ' . esc_attr(soccerclub_get_slider_controls_classes($controls))
                    . (soccerclub_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
                    . ($hs ? ' sc_slider_height_fixed' : '')
                    . '"'
                    . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
                    . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
                    . ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
                    . ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
                    . ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
                    . ' data-slides-min-width="250"'
                    . '>'
                    . '<div class="slides swiper-wrapper">')
                : ($columns > 1
                    ? '<div class="sc_columns columns_wrap">'
                    : '')
            );

        $content = do_shortcode($content);

        if (soccerclub_param_is_on($custom) && $content) {
            $output .= $content;
        } else {
            global $post;

            if (!empty($ids)) {
                $posts = explode(',', $ids);
                $count = count($posts);
            }

            $args = array(
                'post_type' => 'team',
                'post_status' => 'publish',
                'posts_per_page' => $count,
                'ignore_sticky_posts' => true,
                'order' => $order=='asc' ? 'asc' : 'desc',
            );

            if ($offset > 0 && empty($ids)) {
                $args['offset'] = $offset;
            }

            $args = soccerclub_query_add_sort_order($args, $orderby, $order);
            $args = soccerclub_query_add_posts_and_cats($args, $ids, 'team', $cat, 'team_group');
            $query = new WP_Query( $args );

            $post_number = 0;

            while ( $query->have_posts() ) {
                $query->the_post();
                $post_number++;
                $args = array(
                    'layout' => $style,
                    'show' => false,
                    'number' => $post_number,
                    'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
                    "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                    "orderby" => $orderby,
                    'content' => false,
                    'terms_list' => false,
                    "columns_count" => $columns,
                    'slider' => $slider,
                    'tag_id' => $id ? $id . '_' . $post_number : '',
                    'tag_class' => '',
                    'tag_animation' => '',
                    'tag_css' => '',
                    'tag_css_wh' => $ws . $hs
                );
                $post_data = soccerclub_get_post_data($args);
                $post_meta = get_post_meta($post_data['post_id'], 'soccerclub_team_data', true);
                $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
                $args['position'] = $post_meta['team_member_position'];
                $args['link'] = !empty($post_meta['team_member_link']) ? $post_meta['team_member_link'] : $post_data['post_link'];
                $args['email'] = $post_meta['team_member_email'];
                $args['photo'] = $post_data['post_thumb'];
                $mult = soccerclub_get_retina_multiplier();
                if (empty($args['photo']) && !empty($args['email'])) $args['photo'] = get_avatar($args['email'], $thumb_sizes['w']*$mult);
                $args['socials'] = '';
                $soc_list = $post_meta['team_member_socials'];
                if (is_array($soc_list) && count($soc_list)>0) {
                    $soc_str = '';
                    foreach ($soc_list as $sn=>$sl) {
                        if (!empty($sl))
                            $soc_str .= (!empty($soc_str) ? '|' : '') . ($sn) . '=' . ($sl);
                    }
                    if (!empty($soc_str))
                        $args['socials'] = soccerclub_do_shortcode('[trx_socials size="tiny" shape="round" socials="'.esc_attr($soc_str).'"][/trx_socials]');
                }

                $output .= soccerclub_show_post_layout($args, $post_data);
            }
            wp_reset_postdata();
        }

        if (soccerclub_param_is_on($slider)) {
            $output .= '</div>'
                . '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
                . '<div class="sc_slider_pagination_wrap"></div>'
                . '</div>';
        } else if ($columns > 1) {
            $output .= '</div>';
        }

        $output .= (!empty($link) ? '<div class="sc_team_button sc_item_button">'.soccerclub_do_shortcode('[trx_button link="'.esc_url($link).'" icon="icon-right"]'.esc_html($link_caption).'[/trx_button]').'</div>' : '')
            . '</div><!-- /.sc_team -->'
            . '</div><!-- /.sc_team_wrap -->';

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_team', $atts, $content);
    }
    add_shortcode('trx_team', 'soccerclub_sc_team');
}


if ( !function_exists( 'soccerclub_sc_team_item' ) ) {
    function soccerclub_sc_team_item($atts, $content=null) {
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts( array(
            // Individual params
            "user" => "",
            "member" => "",
            "name" => "",
            "position" => "",
            "photo" => "",
            "email" => "",
            "link" => "",
            "socials" => "",
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => ""
        ), $atts)));

        soccerclub_storage_inc_array('sc_team_data', 'counter');

        $id = $id ? $id : (soccerclub_storage_get_array('sc_team_data', 'id') ? soccerclub_storage_get_array('sc_team_data', 'id') . '_' . soccerclub_storage_get_array('sc_team_data', 'counter') : '');

        $descr = trim(chop(do_shortcode($content)));

        $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => soccerclub_storage_get_array('sc_team_data', 'style')));

        if (!empty($socials)) $socials = soccerclub_do_shortcode('[trx_socials size="tiny" shape="round" socials="'.esc_attr($socials).'"][/trx_socials]');

        if (!empty($user) && $user!='none' && ($user_obj = get_user_by('login', $user)) != false) {
            $meta = get_user_meta($user_obj->ID);
            if (empty($email))		$email = $user_obj->data->user_email;
            if (empty($name))		$name = $user_obj->data->display_name;
            if (empty($position))	$position = isset($meta['user_position'][0]) ? $meta['user_position'][0] : '';
            if (empty($descr))		$descr = isset($meta['description'][0]) ? $meta['description'][0] : '';
            if (empty($socials))	$socials = soccerclub_show_user_socials(array('author_id'=>$user_obj->ID, 'echo'=>false));
        }

        if (!empty($member) && $member!='none' && ($member_obj = (intval($member) > 0 ? get_post($member, OBJECT) : trx_utils_get_post_by_title($member, 'team'))) != null) {
            if (empty($name))		$name = $member_obj->post_title;
            if (empty($descr))		$descr = $member_obj->post_excerpt;
            $post_meta = get_post_meta($member_obj->ID, 'soccerclub_team_data', true);
            if (empty($position))	$position = $post_meta['team_member_position'];
            if (empty($link))		$link = !empty($post_meta['team_member_link']) ? $post_meta['team_member_link'] : get_permalink($member_obj->ID);
            if (empty($email))		$email = $post_meta['team_member_email'];
            if (empty($photo)) 		$photo = wp_get_attachment_url(get_post_thumbnail_id($member_obj->ID));
            if (empty($socials)) {
                $socials = '';
                $soc_list = $post_meta['team_member_socials'];
                if (is_array($soc_list) && count($soc_list)>0) {
                    $soc_str = '';
                    foreach ($soc_list as $sn=>$sl) {
                        if (!empty($sl))
                            $soc_str .= (!empty($soc_str) ? '|' : '') . ($sn) . '=' . ($sl);
                    }
                    if (!empty($soc_str))
                        $socials = soccerclub_do_shortcode('[trx_socials size="tiny" shape="round" socials="'.esc_attr($soc_str).'"][/trx_socials]');
                }
            }
        }
        if (empty($photo)) {
            $mult = soccerclub_get_retina_multiplier();
            if (!empty($email)) $photo = get_avatar($email, $thumb_sizes['w']*$mult);
        } else {
            if ($photo > 0) {
                $attach = wp_get_attachment_image_src( $photo, 'full' );
                if (isset($attach[0]) && $attach[0]!='')
                    $photo = $attach[0];
            }
            $photo = soccerclub_get_resized_image_tag($photo, $thumb_sizes['w'], $thumb_sizes['h']);
        }
        $post_data = array(
            'post_title' => $name,
            'post_excerpt' => $descr
        );
        $args = array(
            'layout' => soccerclub_storage_get_array('sc_team_data', 'style'),
            'number' => soccerclub_storage_get_array('sc_team_data', 'counter'),
            'columns_count' => soccerclub_storage_get_array('sc_team_data', 'columns'),
            'slider' => soccerclub_storage_get_array('sc_team_data', 'slider'),
            'show' => false,
            'descr'  => 0,
            'tag_id' => $id,
            'tag_class' => $class,
            'tag_animation' => $animation,
            'tag_css' => $css,
            'tag_css_wh' => soccerclub_storage_get_array('sc_team_data', 'css_wh'),
            'position' => $position,
            'link' => $link,
            'email' => $email,
            'photo' => $photo,
            'socials' => $socials
        );
        $output = soccerclub_show_post_layout($args, $post_data);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_team_item', $atts, $content);
    }
    add_shortcode('trx_team_item', 'soccerclub_sc_team_item');
}
// ---------------------------------- [/trx_team] ---------------------------------------



// Add [trx_team] and [trx_team_item] in the shortcodes list
if (!function_exists('soccerclub_team_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_team_reg_shortcodes');
    function soccerclub_team_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $users = soccerclub_get_list_users();
            $members = soccerclub_get_list_posts(false, array(
                    'post_type'=>'team',
                    'orderby'=>'title',
                    'order'=>'asc',
                    'return'=>'title'
                )
            );
            $team_groups = soccerclub_get_list_terms(false, 'team_group');
            $team_styles = soccerclub_get_list_templates('team');
            $controls	 = soccerclub_get_list_slider_controls();

            soccerclub_sc_map_after('trx_tabs', array(

                // Team
                "trx_team" => array(
                    "title" => esc_html__("Team", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert team in your page (post)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "style" => array(
                            "title" => esc_html__("Team style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select style to display team members", 'trx_utils') ),
                            "value" => "1",
                            "type" => "select",
                            "options" => $team_styles
                        ),
                        "columns" => array(
                            "title" => esc_html__("Columns", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many columns use to show team members", 'trx_utils') ),
                            "value" => 3,
                            "min" => 2,
                            "max" => 5,
                            "step" => 1,
                            "type" => "spinner"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "slider" => array(
                            "title" => esc_html__("Slider", 'trx_utils'),
                            "desc" => wp_kses_data( __("Use slider to show team members", 'trx_utils') ),
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "controls" => array(
                            "title" => esc_html__("Controls", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => $controls
                        ),
                        "slides_space" => array(
                            "title" => esc_html__("Space between slides", 'trx_utils'),
                            "desc" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "max" => 100,
                            "step" => 10,
                            "type" => "spinner"
                        ),
                        "interval" => array(
                            "title" => esc_html__("Slides change interval", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 7000,
                            "step" => 500,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "autoheight" => array(
                            "title" => esc_html__("Autoheight", 'trx_utils'),
                            "desc" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => "yes",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the team block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "custom" => array(
                            "title" => esc_html__("Custom", 'trx_utils'),
                            "desc" => wp_kses_data( __("Allow get team members from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                            "divider" => true,
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show team members. If empty - select team members from any category (group) or from IDs list", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $team_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 3,
                            "min" => 1,
                            "max" => 100,
                            "type" => "spinner"
                        ),
                        "offset" => array(
                            "title" => esc_html__("Offset before select posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "orderby" => array(
                            "title" => esc_html__("Post order by", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "title",
                            "type" => "select",
                            "options" => soccerclub_get_sc_param('sorting')
                        ),
                        "order" => array(
                            "title" => esc_html__("Post order", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "asc",
                            "type" => "switch",
                            "size" => "big",
                            "options" => soccerclub_get_sc_param('ordering')
                        ),
                        "ids" => array(
                            "title" => esc_html__("Post IDs list", 'trx_utils'),
                            "desc" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link" => array(
                            "title" => esc_html__("Button URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "link_caption" => array(
                            "title" => esc_html__("Button caption", 'trx_utils'),
                            "desc" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    ),
                    "children" => array(
                        "name" => "trx_team_item",
                        "title" => esc_html__("Member", 'trx_utils'),
                        "desc" => wp_kses_data( __("Team member", 'trx_utils') ),
                        "container" => true,
                        "params" => array(
                            "user" => array(
                                "title" => esc_html__("Registerd user", 'trx_utils'),
                                "desc" => wp_kses_data( __("Select one of registered users (if present) or put name, position, etc. in fields below", 'trx_utils') ),
                                "value" => "",
                                "type" => "select",
                                "options" => $users
                            ),
                            "member" => array(
                                "title" => esc_html__("Team member", 'trx_utils'),
                                "desc" => wp_kses_data( __("Select one of team members (if present) or put name, position, etc. in fields below", 'trx_utils') ),
                                "value" => "",
                                "type" => "select",
                                "options" => $members
                            ),
                            "link" => array(
                                "title" => esc_html__("Link", 'trx_utils'),
                                "desc" => wp_kses_data( __("Link on team member's personal page", 'trx_utils') ),
                                "divider" => true,
                                "value" => "",
                                "type" => "text"
                            ),
                            "name" => array(
                                "title" => esc_html__("Name", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's name", 'trx_utils') ),
                                "divider" => true,
                                "dependency" => array(
                                    'user' => array('is_empty', 'none'),
                                    'member' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "position" => array(
                                "title" => esc_html__("Position", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's position", 'trx_utils') ),
                                "dependency" => array(
                                    'user' => array('is_empty', 'none'),
                                    'member' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "email" => array(
                                "title" => esc_html__("E-mail", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's e-mail", 'trx_utils') ),
                                "dependency" => array(
                                    'user' => array('is_empty', 'none'),
                                    'member' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "photo" => array(
                                "title" => esc_html__("Photo", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's photo (avatar)", 'trx_utils') ),
                                "dependency" => array(
                                    'user' => array('is_empty', 'none'),
                                    'member' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "readonly" => false,
                                "type" => "media"
                            ),
                            "socials" => array(
                                "title" => esc_html__("Socials", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's socials icons: name=url|name=url... For example: facebook=http://facebook.com/myaccount|twitter=http://twitter.com/myaccount", 'trx_utils') ),
                                "dependency" => array(
                                    'user' => array('is_empty', 'none'),
                                    'member' => array('is_empty', 'none')
                                ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "_content_" => array(
                                "title" => esc_html__("Description", 'trx_utils'),
                                "desc" => wp_kses_data( __("Team member's short description", 'trx_utils') ),
                                "divider" => true,
                                "rows" => 4,
                                "value" => "",
                                "type" => "textarea"
                            ),
                            "id" => soccerclub_get_sc_param('id'),
                            "class" => soccerclub_get_sc_param('class'),
                            "animation" => soccerclub_get_sc_param('animation'),
                            "css" => soccerclub_get_sc_param('css')
                        )
                    )
                )

            ));
        }
    }
}


// Add [trx_team] and [trx_team_item] in the VC shortcodes list
if (!function_exists('soccerclub_team_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_team_reg_shortcodes_vc');
    function soccerclub_team_reg_shortcodes_vc() {

        $users = soccerclub_get_list_users();
        $members = soccerclub_get_list_posts(false, array(
                'post_type'=>'team',
                'orderby'=>'title',
                'order'=>'asc',
                'return'=>'title'
            )
        );
        $team_groups = soccerclub_get_list_terms(false, 'team_group');
        $team_styles = soccerclub_get_list_templates('team');
        $controls	 = soccerclub_get_list_slider_controls();

        // Team
        vc_map( array(
            "base" => "trx_team",
            "name" => esc_html__("Team", 'trx_utils'),
            "description" => wp_kses_data( __("Insert team members", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_team',
            "class" => "trx_sc_columns trx_sc_team",
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "as_parent" => array('only' => 'trx_team_item'),
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Team style", 'trx_utils'),
                    "description" => wp_kses_data( __("Select style to display team members", 'trx_utils') ),
                    "class" => "",
                    "admin_label" => true,
                    "value" => array_flip($team_styles),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slider",
                    "heading" => esc_html__("Slider", 'trx_utils'),
                    "description" => wp_kses_data( __("Use slider to show team members", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip(soccerclub_get_sc_param('yes_no')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "controls",
                    "heading" => esc_html__("Controls", 'trx_utils'),
                    "description" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip($controls),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slides_space",
                    "heading" => esc_html__("Space between slides", 'trx_utils'),
                    "description" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "interval",
                    "heading" => esc_html__("Slides change interval", 'trx_utils'),
                    "description" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "7000",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "autoheight",
                    "heading" => esc_html__("Autoheight", 'trx_utils'),
                    "description" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => array("Autoheight" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the team block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "custom",
                    "heading" => esc_html__("Custom", 'trx_utils'),
                    "description" => wp_kses_data( __("Allow get team members from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                    "class" => "",
                    "value" => array("Custom members" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select category to show team members. If empty - select team members from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $team_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "columns",
                    "heading" => esc_html__("Columns", 'trx_utils'),
                    "description" => wp_kses_data( __("How many columns use to show team members", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "3",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of posts", 'trx_utils'),
                    "description" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "3",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "offset",
                    "heading" => esc_html__("Offset before select posts", 'trx_utils'),
                    "description" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "orderby",
                    "heading" => esc_html__("Post sorting", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "title",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('sorting')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "order",
                    "heading" => esc_html__("Post order", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "asc",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('ordering')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "ids",
                    "heading" => esc_html__("Team member's IDs list", 'trx_utils'),
                    "description" => wp_kses_data( __("Comma separated list of team members's ID. If set - parameters above (category, count, order, etc.)  are ignored!", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Button URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link_caption",
                    "heading" => esc_html__("Button caption", 'trx_utils'),
                    "description" => wp_kses_data( __("Caption for the button at the bottom of the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'default_content' => '
					[trx_team_item user="' . esc_html__( 'Member 1', 'trx_utils') . '"][/trx_team_item]
					[trx_team_item user="' . esc_html__( 'Member 2', 'trx_utils') . '"][/trx_team_item]
					[trx_team_item user="' . esc_html__( 'Member 4', 'trx_utils') . '"][/trx_team_item]
				',
            'js_view' => 'VcTrxColumnsView'
        ) );


        vc_map( array(
            "base" => "trx_team_item",
            "name" => esc_html__("Team member", 'trx_utils'),
            "description" => wp_kses_data( __("Team member - all data pull out from it account on your site", 'trx_utils') ),
            "show_settings_on_create" => true,
            "class" => "trx_sc_collection trx_sc_column_item trx_sc_team_item",
            "content_element" => true,
            "is_container" => true,
            'icon' => 'icon_trx_team_item',
            "as_child" => array('only' => 'trx_team'),
            "as_parent" => array('except' => 'trx_team'),
            "params" => array(
                array(
                    "param_name" => "user",
                    "heading" => esc_html__("Registered user", 'trx_utils'),
                    "description" => wp_kses_data( __("Select one of registered users (if present) or put name, position, etc. in fields below", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => array_flip($users),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "member",
                    "heading" => esc_html__("Team member", 'trx_utils'),
                    "description" => wp_kses_data( __("Select one of team members (if present) or put name, position, etc. in fields below", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => array_flip($members),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Link", 'trx_utils'),
                    "description" => wp_kses_data( __("Link on team member's personal page", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "name",
                    "heading" => esc_html__("Name", 'trx_utils'),
                    "description" => wp_kses_data( __("Team member's name", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "position",
                    "heading" => esc_html__("Position", 'trx_utils'),
                    "description" => wp_kses_data( __("Team member's position", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "email",
                    "heading" => esc_html__("E-mail", 'trx_utils'),
                    "description" => wp_kses_data( __("Team member's e-mail", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "photo",
                    "heading" => esc_html__("Member's Photo", 'trx_utils'),
                    "description" => wp_kses_data( __("Team member's photo (avatar)", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                array(
                    "param_name" => "socials",
                    "heading" => esc_html__("Socials", 'trx_utils'),
                    "description" => wp_kses_data( __("Team member's socials icons: name=url|name=url... For example: facebook=http://facebook.com/myaccount|twitter=http://twitter.com/myaccount", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnItemView'
        ) );

        class WPBakeryShortCode_Trx_Team extends Soccerclub_Vc_ShortCodeColumns {}
        class WPBakeryShortCode_Trx_Team_Item extends Soccerclub_Vc_ShortCodeCollection {}

    }
}



// ---------------------------------- [trx_testimonials] ---------------------------------------

if (!function_exists('soccerclub_sc_testimonials')) {
    function soccerclub_sc_testimonials($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "style" => "testimonials-1",
            "columns" => 1,
            "slider" => "yes",
            "slides_space" => 0,
            "controls" => "no",
            "interval" => "",
            "autoheight" => "no",
            "align" => "",
            "custom" => "no",
            "ids" => "",
            "cat" => "",
            "count" => "3",
            "offset" => "",
            "orderby" => "date",
            "order" => "desc",
            "scheme" => "",
            "bg_color" => "",
            "bg_image" => "",
            "bg_overlay" => "",
            "bg_texture" => "",
            "title" => "",
            "subtitle" => "",
            "description" => "",
            // Common params
            "id" => "",
            "class" => "",
            "animation" => "",
            "css" => "",
            "width" => "",
            "height" => "",
            "top" => "",
            "bottom" => "",
            "left" => "",
            "right" => ""
        ), $atts)));

        if (empty($id)) $id = "sc_testimonials_".str_replace('.', '', mt_rand());
        if (empty($width)) $width = "100%";
        if (!empty($height) && soccerclub_param_is_on($autoheight)) $autoheight = "no";
        if (empty($interval)) $interval = mt_rand(5000, 10000);

        if ($bg_image > 0) {
            $attach = wp_get_attachment_image_src( $bg_image, 'full' );
            if (isset($attach[0]) && $attach[0]!='')
                $bg_image = $attach[0];
        }

        if ($bg_overlay > 0) {
            if ($bg_color=='') $bg_color = soccerclub_get_scheme_color('bg');
            $rgb = soccerclub_hex2rgb($bg_color);
        }

        $class .= ($class ? ' ' : '') . soccerclub_get_css_position_as_classes($top, $right, $bottom, $left);

        $ws = soccerclub_get_css_dimensions_from_values($width);
        $hs = soccerclub_get_css_dimensions_from_values('', $height);
        $css .= ($hs) . ($ws);

        $count = max(1, (int) $count);
        $columns = max(1, min(12, (int) $columns));
        if (soccerclub_param_is_off($custom) && $count < $columns) $columns = $count;

        soccerclub_storage_set('sc_testimonials_data', array(
                'id' => $id,
                'style' => $style,
                'columns' => $columns,
                'counter' => 0,
                'slider' => $slider,
                'css_wh' => $ws . $hs
            )
        );

        if (soccerclub_param_is_on($slider)) soccerclub_enqueue_slider('swiper');

        $output = ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || soccerclub_strlen($bg_texture)>2 || ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme))
                ? '<div class="sc_testimonials_wrap sc_section'
                . ($scheme && !soccerclub_param_is_off($scheme) && !soccerclub_param_is_inherit($scheme) ? ' scheme_'.esc_attr($scheme) : '')
                . '"'
                .' style="'
                . ($bg_color !== '' && $bg_overlay==0 ? 'background-color:' . esc_attr($bg_color) . ';' : '')
                . ($bg_image !== '' ? 'background-image:url(' . esc_url($bg_image) . ');' : '')
                . '"'
                . (!soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
                . '>'
                . '<div class="sc_section_overlay'.($bg_texture>0 ? ' texture_bg_'.esc_attr($bg_texture) : '') . '"'
                . ' style="' . ($bg_overlay>0 ? 'background-color:rgba('.(int)$rgb['r'].','.(int)$rgb['g'].','.(int)$rgb['b'].','.min(1, max(0, $bg_overlay)).');' : '')
                . (soccerclub_strlen($bg_texture)>2 ? 'background-image:url('.esc_url($bg_texture).');' : '')
                . '"'
                . ($bg_overlay > 0 ? ' data-overlay="'.esc_attr($bg_overlay).'" data-bg_color="'.esc_attr($bg_color).'"' : '')
                . '>'
                : '')
            . '<div' . ($id ? ' id="'.esc_attr($id).'"' : '')
            . ' class="sc_testimonials sc_testimonials_style_'.esc_attr($style)
            . ' ' . esc_attr(soccerclub_get_template_property($style, 'container_classes'))
            . (!empty($class) ? ' '.esc_attr($class) : '')
            . ($align!='' && $align!='none' ? ' align'.esc_attr($align) : '')
            . '"'
            . ($bg_color=='' && $bg_image=='' && $bg_overlay==0 && ($bg_texture=='' || $bg_texture=='0') && !soccerclub_param_is_off($animation) ? ' data-animation="'.esc_attr(soccerclub_get_animation_classes($animation)).'"' : '')
            . ($css!='' ? ' style="'.esc_attr($css).'"' : '')
            . '>'
            . (!empty($subtitle) ? '<h6 class="sc_testimonials_subtitle sc_item_subtitle">' . trim(soccerclub_strmacros($subtitle)) . '</h6>' : '')
            . (!empty($title) ? '<h2 class="sc_testimonials_title sc_item_title">' . trim(soccerclub_strmacros($title)) . '</h2>' : '')
            . (!empty($description) ? '<div class="sc_testimonials_descr sc_item_descr">' . trim(soccerclub_strmacros($description)) . '</div>' : '')
            . (soccerclub_param_is_on($slider)
                ? ('<div class="sc_slider_swiper swiper-slider-container'
                    . ' ' . esc_attr(soccerclub_get_slider_controls_classes($controls))
                    . (soccerclub_param_is_on($autoheight) ? ' sc_slider_height_auto' : '')
                    . ($hs ? ' sc_slider_height_fixed' : '')
                    . '"'
                    . (!empty($width) && soccerclub_strpos($width, '%')===false ? ' data-old-width="' . esc_attr($width) . '"' : '')
                    . (!empty($height) && soccerclub_strpos($height, '%')===false ? ' data-old-height="' . esc_attr($height) . '"' : '')
                    . ((int) $interval > 0 ? ' data-interval="'.esc_attr($interval).'"' : '')
                    . ($columns > 1 ? ' data-slides-per-view="' . esc_attr($columns) . '"' : '')
                    . ($slides_space > 0 ? ' data-slides-space="' . esc_attr($slides_space) . '"' : '')
                    . ' data-slides-min-width="250"'
                    . '>'
                    . '<div class="slides swiper-wrapper">')
                : ($columns > 1
                    ? '<div class="sc_columns columns_wrap">'
                    : '')
            );

        $content = do_shortcode($content);

        if (soccerclub_param_is_on($custom) && $content) {
            $output .= $content;
        } else {
            global $post;

            if (!empty($ids)) {
                $posts = explode(',', $ids);
                $count = count($posts);
            }

            $args = array(
                'post_type' => 'testimonial',
                'post_status' => 'publish',
                'posts_per_page' => $count,
                'ignore_sticky_posts' => true,
                'order' => $order=='asc' ? 'asc' : 'desc',
            );

            if ($offset > 0 && empty($ids)) {
                $args['offset'] = $offset;
            }

            $args = soccerclub_query_add_sort_order($args, $orderby, $order);
            $args = soccerclub_query_add_posts_and_cats($args, $ids, 'testimonial', $cat, 'testimonial_group');

            $query = new WP_Query( $args );

            $post_number = 0;

            while ( $query->have_posts() ) {
                $query->the_post();
                $post_number++;
                $args = array(
                    'layout' => $style,
                    'show' => false,
                    'number' => $post_number,
                    'posts_on_page' => ($count > 0 ? $count : $query->found_posts),
                    "descr" => soccerclub_get_custom_option('post_excerpt_maxlength'.($columns > 1 ? '_masonry' : '')),
                    "orderby" => $orderby,
                    'content' => false,
                    'terms_list' => false,
                    'columns_count' => $columns,
                    'slider' => $slider,
                    'tag_id' => $id ? $id . '_' . $post_number : '',
                    'tag_class' => '',
                    'tag_animation' => '',
                    'tag_css' => '',
                    'tag_css_wh' => $ws . $hs
                );
                $post_data = soccerclub_get_post_data($args);
                $post_data['post_content'] = wpautop($post_data['post_content']);	// Add <p> around text and paragraphs. Need separate call because 'content'=>false (see above)
                $post_meta = get_post_meta($post_data['post_id'], 'soccerclub_testimonial_data', true);
                $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => $style));
                $args['author'] = $post_meta['testimonial_author'];
                $args['position'] = $post_meta['testimonial_position'];
                $args['link'] = !empty($post_meta['testimonial_link']) ? $post_meta['testimonial_link'] : '';
                $args['email'] = $post_meta['testimonial_email'];
                $args['photo'] = $post_data['post_thumb'];
                $mult = soccerclub_get_retina_multiplier();
                if (empty($args['photo']) && !empty($args['email'])) $args['photo'] = get_avatar($args['email'], $thumb_sizes['w']*$mult);
                $output .= soccerclub_show_post_layout($args, $post_data);
            }
            wp_reset_postdata();
        }

        if (soccerclub_param_is_on($slider)) {
            $output .= '</div>'
                . '<div class="sc_slider_controls_wrap"><a class="sc_slider_prev" href="#"></a><a class="sc_slider_next" href="#"></a></div>'
                . '<div class="sc_slider_pagination_wrap"></div>'
                . '</div>';
        } else if ($columns > 1) {
            $output .= '</div>';
        }

        $output .= '</div>'
            . ($bg_color!='' || $bg_image!='' || $bg_overlay>0 || $bg_texture>0 || soccerclub_strlen($bg_texture)>2
                ?  '</div></div>'
                : '');

        // Add template specific scripts and styles
        do_action('soccerclub_action_blog_scripts', $style);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_testimonials', $atts, $content);
    }
    add_shortcode('trx_testimonials', 'soccerclub_sc_testimonials');
}


if (!function_exists('soccerclub_sc_testimonials_item')) {
    function soccerclub_sc_testimonials_item($atts, $content=null){
        if (soccerclub_in_shortcode_blogger()) return '';
        extract(soccerclub_html_decode(shortcode_atts(array(
            // Individual params
            "author" => "",
            "position" => "",
            "link" => "",
            "photo" => "",
            "email" => "",
            // Common params
            "id" => "",
            "class" => "",
            "css" => "",
        ), $atts)));

        soccerclub_storage_inc_array('sc_testimonials_data', 'counter');

        $id = $id ? $id : (soccerclub_storage_get_array('sc_testimonials_data', 'id') ? soccerclub_storage_get_array('sc_testimonials_data', 'id') . '_' . soccerclub_storage_get_array('sc_testimonials_data', 'counter') : '');

        $thumb_sizes = soccerclub_get_thumb_sizes(array('layout' => soccerclub_storage_get_array('sc_testimonials_data', 'style')));

        if (empty($photo)) {
            if (!empty($email))
                $mult = soccerclub_get_retina_multiplier();
            $photo = get_avatar($email, $thumb_sizes['w']*$mult);
        } else {
            if ($photo > 0) {
                $attach = wp_get_attachment_image_src( $photo, 'full' );
                if (isset($attach[0]) && $attach[0]!='')
                    $photo = $attach[0];
            }
            $photo = soccerclub_get_resized_image_tag($photo, $thumb_sizes['w'], $thumb_sizes['h']);
        }

        $post_data = array(
            'post_content' => do_shortcode($content)
        );
        $args = array(
            'layout' => soccerclub_storage_get_array('sc_testimonials_data', 'style'),
            'number' => soccerclub_storage_get_array('sc_testimonials_data', 'counter'),
            'columns_count' => soccerclub_storage_get_array('sc_testimonials_data', 'columns'),
            'slider' => soccerclub_storage_get_array('sc_testimonials_data', 'slider'),
            'show' => false,
            'descr'  => 0,
            'tag_id' => $id,
            'tag_class' => $class,
            'tag_animation' => '',
            'tag_css' => $css,
            'tag_css_wh' => soccerclub_storage_get_array('sc_testimonials_data', 'css_wh'),
            'author' => $author,
            'position' => $position,
            'link' => $link,
            'email' => $email,
            'photo' => $photo
        );
        $output = soccerclub_show_post_layout($args, $post_data);

        return apply_filters('soccerclub_shortcode_output', $output, 'trx_testimonials_item', $atts, $content);
    }
    add_shortcode('trx_testimonials_item', 'soccerclub_sc_testimonials_item');
}
// ---------------------------------- [/trx_testimonials] ---------------------------------------



// Add [trx_testimonials] and [trx_testimonials_item] in the shortcodes list
if (!function_exists('soccerclub_testimonials_reg_shortcodes')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list',	'soccerclub_testimonials_reg_shortcodes');
    function soccerclub_testimonials_reg_shortcodes() {
        if (soccerclub_storage_isset('shortcodes')) {

            $testimonials_groups = soccerclub_get_list_terms(false, 'testimonial_group');
            $testimonials_styles = soccerclub_get_list_templates('testimonials');
            $controls = soccerclub_get_list_slider_controls();

            soccerclub_sc_map_before('trx_title', array(

                // Testimonials
                "trx_testimonials" => array(
                    "title" => esc_html__("Testimonials", 'trx_utils'),
                    "desc" => wp_kses_data( __("Insert testimonials into post (page)", 'trx_utils') ),
                    "decorate" => true,
                    "container" => false,
                    "params" => array(
                        "title" => array(
                            "title" => esc_html__("Title", 'trx_utils'),
                            "desc" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "subtitle" => array(
                            "title" => esc_html__("Subtitle", 'trx_utils'),
                            "desc" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "description" => array(
                            "title" => esc_html__("Description", 'trx_utils'),
                            "desc" => wp_kses_data( __("Short description for the block", 'trx_utils') ),
                            "value" => "",
                            "type" => "textarea"
                        ),
                        "style" => array(
                            "title" => esc_html__("Testimonials style", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select style to display testimonials", 'trx_utils') ),
                            "value" => "testimonials-1",
                            "type" => "select",
                            "options" => $testimonials_styles
                        ),
                        "columns" => array(
                            "title" => esc_html__("Columns", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many columns use to show testimonials", 'trx_utils') ),
                            "value" => 1,
                            "min" => 1,
                            "max" => 6,
                            "step" => 1,
                            "type" => "spinner"
                        ),
                        "slider" => array(
                            "title" => esc_html__("Slider", 'trx_utils'),
                            "desc" => wp_kses_data( __("Use slider to show testimonials", 'trx_utils') ),
                            "value" => "yes",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "controls" => array(
                            "title" => esc_html__("Controls", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => $controls
                        ),
                        "slides_space" => array(
                            "title" => esc_html__("Space between slides", 'trx_utils'),
                            "desc" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "max" => 100,
                            "step" => 10,
                            "type" => "spinner"
                        ),
                        "interval" => array(
                            "title" => esc_html__("Slides change interval", 'trx_utils'),
                            "desc" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => 7000,
                            "step" => 500,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "autoheight" => array(
                            "title" => esc_html__("Autoheight", 'trx_utils'),
                            "desc" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                            "dependency" => array(
                                'slider' => array('yes')
                            ),
                            "value" => "yes",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "align" => array(
                            "title" => esc_html__("Alignment", 'trx_utils'),
                            "desc" => wp_kses_data( __("Alignment of the testimonials block", 'trx_utils') ),
                            "divider" => true,
                            "value" => "",
                            "type" => "checklist",
                            "dir" => "horizontal",
                            "options" => soccerclub_get_sc_param('align')
                        ),
                        "custom" => array(
                            "title" => esc_html__("Custom", 'trx_utils'),
                            "desc" => wp_kses_data( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                            "divider" => true,
                            "value" => "no",
                            "type" => "switch",
                            "options" => soccerclub_get_sc_param('yes_no')
                        ),
                        "cat" => array(
                            "title" => esc_html__("Categories", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "divider" => true,
                            "value" => "",
                            "type" => "select",
                            "style" => "list",
                            "multiple" => true,
                            "options" => soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $testimonials_groups)
                        ),
                        "count" => array(
                            "title" => esc_html__("Number of posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 3,
                            "min" => 1,
                            "max" => 100,
                            "type" => "spinner"
                        ),
                        "offset" => array(
                            "title" => esc_html__("Offset before select posts", 'trx_utils'),
                            "desc" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => 0,
                            "min" => 0,
                            "type" => "spinner"
                        ),
                        "orderby" => array(
                            "title" => esc_html__("Post order by", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "date",
                            "type" => "select",
                            "options" => soccerclub_get_sc_param('sorting')
                        ),
                        "order" => array(
                            "title" => esc_html__("Post order", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "desc",
                            "type" => "switch",
                            "size" => "big",
                            "options" => soccerclub_get_sc_param('ordering')
                        ),
                        "ids" => array(
                            "title" => esc_html__("Post IDs list", 'trx_utils'),
                            "desc" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                            "dependency" => array(
                                'custom' => array('no')
                            ),
                            "value" => "",
                            "type" => "text"
                        ),
                        "scheme" => array(
                            "title" => esc_html__("Color scheme", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                            "value" => "",
                            "type" => "checklist",
                            "options" => soccerclub_get_sc_param('schemes')
                        ),
                        "bg_color" => array(
                            "title" => esc_html__("Background color", 'trx_utils'),
                            "desc" => wp_kses_data( __("Any background color for this section", 'trx_utils') ),
                            "value" => "",
                            "type" => "color"
                        ),
                        "bg_image" => array(
                            "title" => esc_html__("Background image URL", 'trx_utils'),
                            "desc" => wp_kses_data( __("Select or upload image or write URL from other site for the background", 'trx_utils') ),
                            "readonly" => false,
                            "value" => "",
                            "type" => "media"
                        ),
                        "bg_overlay" => array(
                            "title" => esc_html__("Overlay", 'trx_utils'),
                            "desc" => wp_kses_data( __("Overlay color opacity (from 0.0 to 1.0)", 'trx_utils') ),
                            "min" => "0",
                            "max" => "1",
                            "step" => "0.1",
                            "value" => "0",
                            "type" => "spinner"
                        ),
                        "bg_texture" => array(
                            "title" => esc_html__("Texture", 'trx_utils'),
                            "desc" => wp_kses_data( __("Predefined texture style from 1 to 11. 0 - without texture.", 'trx_utils') ),
                            "min" => "0",
                            "max" => "11",
                            "step" => "1",
                            "value" => "0",
                            "type" => "spinner"
                        ),
                        "width" => soccerclub_shortcodes_width(),
                        "height" => soccerclub_shortcodes_height(),
                        "top" => soccerclub_get_sc_param('top'),
                        "bottom" => soccerclub_get_sc_param('bottom'),
                        "left" => soccerclub_get_sc_param('left'),
                        "right" => soccerclub_get_sc_param('right'),
                        "id" => soccerclub_get_sc_param('id'),
                        "class" => soccerclub_get_sc_param('class'),
                        "animation" => soccerclub_get_sc_param('animation'),
                        "css" => soccerclub_get_sc_param('css')
                    ),
                    "children" => array(
                        "name" => "trx_testimonials_item",
                        "title" => esc_html__("Item", 'trx_utils'),
                        "desc" => wp_kses_data( __("Testimonials item (custom parameters)", 'trx_utils') ),
                        "container" => true,
                        "params" => array(
                            "author" => array(
                                "title" => esc_html__("Author", 'trx_utils'),
                                "desc" => wp_kses_data( __("Name of the testimonmials author", 'trx_utils') ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "link" => array(
                                "title" => esc_html__("Link", 'trx_utils'),
                                "desc" => wp_kses_data( __("Link URL to the testimonmials author page", 'trx_utils') ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "email" => array(
                                "title" => esc_html__("E-mail", 'trx_utils'),
                                "desc" => wp_kses_data( __("E-mail of the testimonmials author (to get gravatar)", 'trx_utils') ),
                                "value" => "",
                                "type" => "text"
                            ),
                            "photo" => array(
                                "title" => esc_html__("Photo", 'trx_utils'),
                                "desc" => wp_kses_data( __("Select or upload photo of testimonmials author or write URL of photo from other site", 'trx_utils') ),
                                "value" => "",
                                "type" => "media"
                            ),
                            "_content_" => array(
                                "title" => esc_html__("Testimonials text", 'trx_utils'),
                                "desc" => wp_kses_data( __("Current testimonials text", 'trx_utils') ),
                                "divider" => true,
                                "rows" => 4,
                                "value" => "",
                                "type" => "textarea"
                            ),
                            "id" => soccerclub_get_sc_param('id'),
                            "class" => soccerclub_get_sc_param('class'),
                            "css" => soccerclub_get_sc_param('css')
                        )
                    )
                )

            ));
        }
    }
}


// Add [trx_testimonials] and [trx_testimonials_item] in the VC shortcodes list
if (!function_exists('soccerclub_testimonials_reg_shortcodes_vc')) {
    //Handler of add_filter('soccerclub_action_shortcodes_list_vc',	'soccerclub_testimonials_reg_shortcodes_vc');
    function soccerclub_testimonials_reg_shortcodes_vc() {

        $testimonials_groups = soccerclub_get_list_terms(false, 'testimonial_group');
        $testimonials_styles = soccerclub_get_list_templates('testimonials');
        $controls			 = soccerclub_get_list_slider_controls();

        // Testimonials
        vc_map( array(
            "base" => "trx_testimonials",
            "name" => esc_html__("Testimonials", 'trx_utils'),
            "description" => wp_kses_data( __("Insert testimonials slider", 'trx_utils') ),
            "category" => esc_html__('Content', 'trx_utils'),
            'icon' => 'icon_trx_testimonials',
            "class" => "trx_sc_columns trx_sc_testimonials",
            "content_element" => true,
            "is_container" => true,
            "show_settings_on_create" => true,
            "as_parent" => array('only' => 'trx_testimonials_item'),
            "params" => array(
                array(
                    "param_name" => "style",
                    "heading" => esc_html__("Testimonials style", 'trx_utils'),
                    "description" => wp_kses_data( __("Select style to display testimonials", 'trx_utils') ),
                    "class" => "",
                    "admin_label" => true,
                    "value" => array_flip($testimonials_styles),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slider",
                    "heading" => esc_html__("Slider", 'trx_utils'),
                    "description" => wp_kses_data( __("Use slider to show testimonials", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    "class" => "",
                    "std" => "yes",
                    "value" => array_flip(soccerclub_get_sc_param('yes_no')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "controls",
                    "heading" => esc_html__("Controls", 'trx_utils'),
                    "description" => wp_kses_data( __("Slider controls style and position", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "std" => "no",
                    "value" => array_flip($controls),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "slides_space",
                    "heading" => esc_html__("Space between slides", 'trx_utils'),
                    "description" => wp_kses_data( __("Size of space (in px) between slides", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "interval",
                    "heading" => esc_html__("Slides change interval", 'trx_utils'),
                    "description" => wp_kses_data( __("Slides change interval (in milliseconds: 1000ms = 1s)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => "7000",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "autoheight",
                    "heading" => esc_html__("Autoheight", 'trx_utils'),
                    "description" => wp_kses_data( __("Change whole slider's height (make it equal current slide's height)", 'trx_utils') ),
                    "group" => esc_html__('Slider', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'slider',
                        'value' => 'yes'
                    ),
                    "class" => "",
                    "value" => array("Autoheight" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "align",
                    "heading" => esc_html__("Alignment", 'trx_utils'),
                    "description" => wp_kses_data( __("Alignment of the testimonials block", 'trx_utils') ),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('align')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "custom",
                    "heading" => esc_html__("Custom", 'trx_utils'),
                    "description" => wp_kses_data( __("Allow get testimonials from inner shortcodes (custom) or get it from specified group (cat)", 'trx_utils') ),
                    "class" => "",
                    "value" => array("Custom slides" => "yes" ),
                    "type" => "checkbox"
                ),
                array(
                    "param_name" => "title",
                    "heading" => esc_html__("Title", 'trx_utils'),
                    "description" => wp_kses_data( __("Title for the block", 'trx_utils') ),
                    "admin_label" => true,
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "subtitle",
                    "heading" => esc_html__("Subtitle", 'trx_utils'),
                    "description" => wp_kses_data( __("Subtitle for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "description",
                    "heading" => esc_html__("Description", 'trx_utils'),
                    "description" => wp_kses_data( __("Description for the block", 'trx_utils') ),
                    "group" => esc_html__('Captions', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textarea"
                ),
                array(
                    "param_name" => "cat",
                    "heading" => esc_html__("Categories", 'trx_utils'),
                    "description" => wp_kses_data( __("Select categories (groups) to show testimonials. If empty - select testimonials from any category (group) or from IDs list", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => array_flip(soccerclub_array_merge(array(0 => esc_html__('- Select category -', 'trx_utils')), $testimonials_groups)),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "columns",
                    "heading" => esc_html__("Columns", 'trx_utils'),
                    "description" => wp_kses_data( __("How many columns use to show testimonials", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "1",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "count",
                    "heading" => esc_html__("Number of posts", 'trx_utils'),
                    "description" => wp_kses_data( __("How many posts will be displayed? If used IDs - this parameter ignored.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "3",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "offset",
                    "heading" => esc_html__("Offset before select posts", 'trx_utils'),
                    "description" => wp_kses_data( __("Skip posts before select next part.", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "0",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "orderby",
                    "heading" => esc_html__("Post sorting", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts sorting method", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "date",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('sorting')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "order",
                    "heading" => esc_html__("Post order", 'trx_utils'),
                    "description" => wp_kses_data( __("Select desired posts order", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "std" => "desc",
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('ordering')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "ids",
                    "heading" => esc_html__("Post IDs list", 'trx_utils'),
                    "description" => wp_kses_data( __("Comma separated list of posts ID. If set - parameters above are ignored!", 'trx_utils') ),
                    "group" => esc_html__('Query', 'trx_utils'),
                    'dependency' => array(
                        'element' => 'custom',
                        'is_empty' => true
                    ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "scheme",
                    "heading" => esc_html__("Color scheme", 'trx_utils'),
                    "description" => wp_kses_data( __("Select color scheme for this block", 'trx_utils') ),
                    "group" => esc_html__('Colors and Images', 'trx_utils'),
                    "class" => "",
                    "value" => array_flip(soccerclub_get_sc_param('schemes')),
                    "type" => "dropdown"
                ),
                array(
                    "param_name" => "bg_color",
                    "heading" => esc_html__("Background color", 'trx_utils'),
                    "description" => wp_kses_data( __("Any background color for this section", 'trx_utils') ),
                    "group" => esc_html__('Colors and Images', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "colorpicker"
                ),
                array(
                    "param_name" => "bg_image",
                    "heading" => esc_html__("Background image URL", 'trx_utils'),
                    "description" => wp_kses_data( __("Select background image from library for this section", 'trx_utils') ),
                    "group" => esc_html__('Colors and Images', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                array(
                    "param_name" => "bg_overlay",
                    "heading" => esc_html__("Overlay", 'trx_utils'),
                    "description" => wp_kses_data( __("Overlay color opacity (from 0.0 to 1.0)", 'trx_utils') ),
                    "group" => esc_html__('Colors and Images', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "bg_texture",
                    "heading" => esc_html__("Texture", 'trx_utils'),
                    "description" => wp_kses_data( __("Texture style from 1 to 11. Empty or 0 - without texture.", 'trx_utils') ),
                    "group" => esc_html__('Colors and Images', 'trx_utils'),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                soccerclub_vc_width(),
                soccerclub_vc_height(),
                soccerclub_get_vc_param('margin_top'),
                soccerclub_get_vc_param('margin_bottom'),
                soccerclub_get_vc_param('margin_left'),
                soccerclub_get_vc_param('margin_right'),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('animation'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnsView'
        ) );


        vc_map( array(
            "base" => "trx_testimonials_item",
            "name" => esc_html__("Testimonial", 'trx_utils'),
            "description" => wp_kses_data( __("Single testimonials item", 'trx_utils') ),
            "show_settings_on_create" => true,
            "class" => "trx_sc_collection trx_sc_column_item trx_sc_testimonials_item",
            "content_element" => true,
            "is_container" => true,
            'icon' => 'icon_trx_testimonials_item',
            "as_child" => array('only' => 'trx_testimonials'),
            "as_parent" => array('except' => 'trx_testimonials'),
            "params" => array(
                array(
                    "param_name" => "author",
                    "heading" => esc_html__("Author", 'trx_utils'),
                    "description" => wp_kses_data( __("Name of the testimonmials author", 'trx_utils') ),
                    "admin_label" => true,
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "link",
                    "heading" => esc_html__("Link", 'trx_utils'),
                    "description" => wp_kses_data( __("Link URL to the testimonmials author page", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "email",
                    "heading" => esc_html__("E-mail", 'trx_utils'),
                    "description" => wp_kses_data( __("E-mail of the testimonmials author", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "textfield"
                ),
                array(
                    "param_name" => "photo",
                    "heading" => esc_html__("Photo", 'trx_utils'),
                    "description" => wp_kses_data( __("Select or upload photo of testimonmials author or write URL of photo from other site", 'trx_utils') ),
                    "class" => "",
                    "value" => "",
                    "type" => "attach_image"
                ),
                soccerclub_get_vc_param('id'),
                soccerclub_get_vc_param('class'),
                soccerclub_get_vc_param('css')
            ),
            'js_view' => 'VcTrxColumnItemView'
        ) );

        class WPBakeryShortCode_Trx_Testimonials extends Soccerclub_Vc_ShortCodeColumns {}
        class WPBakeryShortCode_Trx_Testimonials_Item extends Soccerclub_Vc_ShortCodeCollection {}

    }
}

// SoccerClub shortcodes builder settings
require_once trx_utils_get_file_dir ('/shortcodes/shortcodes_settings.php');

// VC shortcodes settings
if ( class_exists('WPBakeryShortCode') ) {
    require_once trx_utils_get_file_dir ('/shortcodes/shortcodes_vc.php');
}

// SoccerClub shortcodes implementation
soccerclub_autoload_folder( 'shortcodes/trx_basic' );
soccerclub_autoload_folder( 'shortcodes/trx_optional' );

?>